# Tests using the module in development

[Jupyter notebook version of this page](test.ipynb)
Read the module swifttools, which is symlinked to xrt_prods



```python
%load_ext autoreload
%autoreload 2
```


```python
import swifttools.ukssdc.query as uq
import pandas as pd
```


```python
help(swifttools.ukssdc.data.download)
```


```python
dir(swifttools.ukssdc.query)
```

## ObsData

Basic test of a simple query and downloading a subset of the data


```python
q = swifttools.ukssdc.query.ObsQuery(silent=False, verbose=False)
```


```python
q.metadata
```


```python
q.addCol('*')
```


```python
q.addConeSearch(name='GK Per', radius=300)
#q.addConeSearch(ra=52.8000, dec=43.9043, radius=300)
#q.maxRows = 1
```


```python
q.submit()
```


```python
q.haveResults
```


```python
len(q.results)
```


```python
q.resolverDetails
```


```python
q.results
```


```python
# Optional, if we want to check what we have to customise the subset 

[Jupyter notebook version of this page](test.ipynb)
q.results['xrt_expo_pc']
```


```python
# Optional, if we want to verify how a subet works

[Jupyter notebook version of this page](test.ipynb)
a = q.results['xrt_expo_pc']<500

```

The following cell downloads quite a lot of data, so it's commented out. It would download all of the observations found.


```python
q.downloadObsData(destDir="/tmp/APIDemo_download", clobber=True)
```

We can specify a subset to download instead, although even a simple subset here is a lot to download, so again it's commented out.


```python
# q.downloadObsData(subset=q.results['xrt_expo_pc']<500, destDir="/tmp/phil", clobber=True)

[Jupyter notebook version of this page](test.ipynb)
```

Subsets can be composites, as demonstated below. This "only" gets 18 datasets, so I'll leave it active.


```python
ss1 = q.results['xrt_expo_pc']<500
ss2 = q.results['xrt_expo_pc']>10
subset = ss1&ss2
q.downloadObsData(subset=subset, destDir="/tmp/phil", clobber=True)
```

### Other things that can be tried and played with


```python
q.results.keys()
```


```python
for c in q.results.columns:
    print(c)
```


```python
q.results.iloc[0]['decl_s']
```


```python
q.unlock()
```


```python
q.addFilter(['xrt_expo_pc', '<', '10000'])
q.addFilter(['xrt_expo_pc', '<', '2000'])
```


```python
q.showFilters()
```


```python
q.removeFilter(0)
```


```python
q.submit()
```


```python
q.results
```


```python
q.defaultCols
```


```python
q.getMetadata()
```


```python
q.unlock()
```


```python
q.metadata.loc[q.metadata['Class'].str.contains('BASIC')]['ColName'].tolist()
```


```python
q.removeAllCols()
```


```python
q.addCol(['target_id', 'obsid', 'xrt_expo_pc'])
```

## SXPS


```python
q2 = uq.SXPSQuery(silent=False, verbose=False, cat='LSXPS')
```


```python
q2.table = 'transients'
```


```python
q2.metadata
```


```python
q2.defaultCols
```


```python
q2.addCol(q2.defaultCols)
```


```python
q2.removeCol('LSXPS_ID')
```


```python
q2.addConeSearch(name='GK Per', radius=30)
q2.maxRows=1000
```


```python
q2.submit()
```


```python
q2.results
```


```python
# q2.getSourceInfo(byID=True)  # This will give an error as we removed ID above:

[Jupyter notebook version of this page](test.ipynb)
q2.getSourceInfo()
```


```python
q2.sourceInfo
```


```python
info2 = q2.getSourceInfo(subset=q2.results['Err90']<6.2, returnData=True)
```


```python
info2.keys()
```


```python
q2.unlock()
q2.table='Datasets'
q2.addConeSearch(name='GK Per', radius=30)
q2.ObsIDAsString=True
```


```python
q2.submit()
```


```python
q2.results
```


```python
q2.downloadObsData(instruments=['xrt'], destDir='/tmp/philSXPSObs', clobber=True)
```


```python
q2.getDatasetInfo(byObsID=False)
```


```python
q2.datasetInfo.keys()
```


```python
q2.datasetInfo[30842027]['Total_sources']
```


```python
#q2.table='datasets'
q2.metadata
```

## Access tests


```python
import swifttools.ukssdc.data as ud
```

### Obs data


```python
obs = "00282445000"
source = "italy"
dirs = ["xrt", "auxil"]
```

Try getting by targetID


```python
olist = ud.download._getObsList(282445)
```


```python
olist
```


```python

```


```python
source = "uk"
instruments = ["xrt"]
ud.downloadObsDataByTarget(282445,
                   source=source,
                   instruments=instruments,
                   destDir='/tmp/APIDemo_data',
                   noAuxil=True,
                   clobber=True,
                   silent=False,
                   verbose=True)
```


```python

```


```python

```

## Skip or edit:
These next 3 cells (related to z) will not work unless the line `# from .download import getFileList # noqa` in 
`data/__init__.py` is uncommented.


```python
z = ud.getFileList(obs,dirs,source, verbose=True)
```


```python
z['fileList']['files']
```


```python
z['url']
```


```python
obs = "00282445000"
source = "uk"
instruments = ["xrt", "bat"]
```


```python
ud.downloadObsData(obs,
                   source=source,
                   instruments=instruments,
                   destDir='/tmp/phil',
                   noAuxil = True,
                   clobber=True,
                   silent=False,
                   verbose=True)
```

### SXPS
#### Sources


```python
info = ud.getSXPSSourceInfo(sourceID=68122)
info
```


```python
info['CrossMatch']
```


```python
info['NonDetections']

```


```python

```


```python

```


```python
info = ud.getSXPSSourceInfo(sourceID=1143)
info
```


```python

```


```python

```


```python
info = ud.getSXPSSourceInfo(sourceName='LSXPS J232337.7+584812')
info
```


```python
info = ud.getSXPSSourceInfo(sourceName=['LSXPS J232337.7+584812', 'LSXPS J232336.6+584800'])
info
```


```python
# Should give an error:

[Jupyter notebook version of this page](test.ipynb)
info = ud.getSXPSSourceInfo(sourceName='LSXPS J232337.7+584812', sourceID=1433)
```

##### Spectrum


```python
import swifttools.ukssdc.data as ud
```


```python
info = ud.getSXPSSpectra(catalogue='2SXPS', sourceID=[51117, 51118])
```


```python
info
```


```python
ud.saveSXPSSpectra(info,
                   destDir="/tmp/philSpec",
                   clobber=True, 
                   silent=False, 
                   extract=True,
                   verbose=True,
                   skipErrors=False,
                   removeTar=True)
```

#### Datasets


```python
dsInfo = ud.getSXPSDatasetInfo(ObsID='00282445001', verbose=False)
```


```python
dsInfo['Hard_sources']
```


```python
tmp = pd.DataFrame(dsInfo['Total_sources'])
```


```python
len(tmp['DetectionDetails_band0'][0])
```


```python
dsInfo
```


```python
a = "https://www.swift.ac.uk/2SXPS/SourceSpectra/source51117/interval0.tar.gz"
import os.path
os.path.basename(a)
```


```python
import swifttools.ukssdc.data.GRB as udg



data = udg.getBurstAnalyser(GRBName="GRB 201013A",
                                returnData=True,
                                saveData=False)
```


```python
data
```




    {'Instruments': ['BAT', 'BAT_NoEvolution', 'XRT', 'UVOT'],
     'BAT': {'HRData':        Time  TimePos  TimeNeg        HR     HRPos     HRNeg   ECF_XRTBand  \
      0  -215.568    23.88   -23.88  1.457744  5.746180 -5.746180  1.469556e-07   
      1   -24.488    23.92   -23.92  0.975023  1.761095 -1.761095  1.005992e-06   
      2    -0.428     0.14    -0.14  1.766082  0.400998 -0.400998  6.445159e-08   
      3    -0.188     0.10    -0.10  2.190595  0.413010 -0.413010  2.634057e-08   
      4    -0.048     0.04    -0.04  2.421296  0.552121 -0.552121  1.742665e-08   
      ..      ...      ...      ...       ...       ...       ...           ...   
      83    7.812     0.10    -0.10  1.215590  0.292271 -0.292271  3.360225e-07   
      84    8.592     0.68    -0.68  1.118462  0.256073 -0.256073  5.016495e-07   
      85   29.992    20.72   -20.72  1.621385  0.722003 -0.722003  9.261551e-08   
      86  112.872    20.72   -20.72  0.326495  1.041229 -1.041229  1.120180e-03   
      87  858.792    20.72   -20.72  0.421534  0.765571 -0.765571  1.837580e-04   
      
          ECF_XRTBandPos  ECF_XRTBandNeg   ECF_BATBand  ...  ECF_BATBandNeg  \
      0     2.045085e+23   -1.468156e-07  2.586909e-07  ...   -2.372653e-07   
      1     2.045085e+23   -9.954903e-07  3.118125e-07  ...   -1.571576e-07   
      2     1.324292e-07   -3.691165e-08  2.281995e-07  ...   -3.436470e-08   
      3     3.636942e-08   -1.343418e-08  1.919938e-07  ...   -2.914643e-08   
      4     3.339662e-08   -1.000845e-08  1.750320e-07  ...   -3.388627e-08   
      ..             ...             ...           ...  ...             ...   
      83    1.007671e-06   -2.093564e-07  2.847554e-07  ...   -3.126703e-08   
      84    1.449489e-06   -3.107691e-07  2.955954e-07  ...   -2.813149e-08   
      85    1.456033e-06   -7.266977e-08  2.420956e-07  ...   -6.157395e-08   
      86    2.045085e+23   -1.119985e-03  3.814297e-07  ...   -1.132404e-07   
      87    2.045085e+23   -1.833819e-04  3.717537e-07  ...   -8.383805e-08   
      
             Gamma   GammaPos  GammaNeg  ECF_Density  ECF_DensityPos  \
      0   1.255057  18.231662 -2.905123     0.004733     7538.397454   
      1   1.971329  17.515390 -1.833497     0.011933     7538.390254   
      2   0.915177   0.456382 -0.362488     0.002881        0.002681   
      3   0.533546   0.370137 -0.307107     0.001572        0.001259   
      4   0.355699   0.459029 -0.366748     0.001165        0.001303   
      ..       ...        ...       ...          ...             ...   
      83  1.577677   0.491350 -0.382546     0.007320        0.006061   
      84  1.726027   0.465669 -0.366711     0.008848        0.006551   
      85  1.066538   1.049646 -0.652690     0.003611        0.010519   
      86  3.977098  15.509622 -2.608968     0.084318     7538.317869   
      87  3.499771  15.986948 -1.879888     0.056260     7538.345928   
      
          ECF_DensityNeg  ECF_ObservedDensity  ECF_ObservedDensityPos  \
      0        -0.004712             0.002379               -0.002379   
      1        -0.011138             0.001894                0.000521   
      2        -0.001258             0.002502                0.000024   
      3        -0.000641             0.002524               -0.000019   
      4        -0.000558             0.002491                0.000030   
      ..             ...                  ...                     ...   
      83       -0.002970             0.002189                0.000219   
      84       -0.003378             0.002084                0.000240   
      85       -0.002324             0.002458                0.000047   
      86       -0.078782             0.000530                0.001789   
      87       -0.048528             0.000763                0.001397   
      
          ECF_ObservedDensityNeg  
      0                -0.001220  
      1                -0.001894  
      2                -0.000185  
      3                -0.000074  
      4                -0.000148  
      ..                     ...  
      83               -0.000374  
      84               -0.000370  
      85               -0.000682  
      86               -0.000530  
      87               -0.000763  
      
      [88 rows x 21 columns],
      'SNR4': {'ObservedFlux':         Time  TimePos  TimeNeg          Flux   FluxPos   FluxNeg  \
       0   -215.568    23.88   -23.88  6.171864e-06  0.000005 -0.000005   
       1   -167.808    23.88   -23.88 -3.536856e-06  0.000005 -0.000005   
       2   -120.048    23.88   -23.88  3.970237e-07  0.000005 -0.000005   
       3    -72.288    23.88   -23.88 -5.232095e-07  0.000004 -0.000004   
       4    -24.528    23.88   -23.88  2.463154e-06  0.000004 -0.000004   
       ..       ...      ...      ...           ...       ...       ...   
       215  692.772    20.74   -20.74  1.239714e-06  0.000001 -0.000001   
       216  734.252    20.74   -20.74 -1.843700e-06  0.000001 -0.000001   
       217  775.732    20.74   -20.74 -2.820657e-07  0.000001 -0.000001   
       218  817.212    20.74   -20.74 -6.711728e-07  0.000001 -0.000001   
       219  858.692    20.74   -20.74  2.321854e-06  0.000001 -0.000001   
       
            FluxPosWithECFErr  FluxNegWithECFErr     Gamma   GammaPos  GammaNeg  \
       0             0.000008          -0.000006  1.255057  18.231662 -2.905123   
       1            -0.000006           0.000005  1.434087  14.358402 -2.226665   
       2             0.000005          -0.000005  1.613118  12.641135 -1.717817   
       3            -0.000004           0.000004  1.792149  13.903136 -1.555094   
       4             0.000004          -0.000005  1.971179  17.511724 -1.833113   
       ..                 ...                ...       ...        ...       ...   
       215           0.000002          -0.000002  3.606010  12.899198 -1.572613   
       216          -0.000003           0.000002  3.579466  13.567159 -1.625472   
       217          -0.000001           0.000001  3.552922  14.311350 -1.695630   
       218          -0.000002           0.000001  3.526379  15.120521 -1.781044   
       219           0.000004          -0.000003  3.499835  15.984805 -1.879636   
       
                 ECF    ECFPos    ECFNeg  BadBin  
       0    0.002379 -0.002379 -0.001220    True  
       1    0.002247  0.001693 -0.001031    True  
       2    0.002123  0.001101 -0.001193    True  
       3    0.002005  0.000650 -0.001525    True  
       4    0.001894  0.000521 -0.001894    True  
       ..        ...       ...       ...     ...  
       215  0.000704  0.001133 -0.000569    True  
       216  0.000718  0.001168 -0.000610    True  
       217  0.000733  0.001224 -0.000656    True  
       218  0.000748  0.001301 -0.000707    True  
       219  0.000763  0.001397 -0.000763    True  
       
       [220 rows x 15 columns],
       'Density':         Time  TimePos  TimeNeg      Flux   FluxPos   FluxNeg  \
       0   -215.568    23.88   -23.88  0.000012  0.000010 -0.000010   
       1   -167.808    23.88   -23.88 -0.000009  0.000013 -0.000013   
       2   -120.048    23.88   -23.88  0.000001  0.000016 -0.000016   
       3    -72.288    23.88   -23.88 -0.000002  0.000020 -0.000020   
       4    -24.528    23.88   -23.88  0.000016  0.000026 -0.000026   
       ..       ...      ...      ...       ...       ...       ...   
       215  692.772    20.74   -20.74  0.000108  0.000112 -0.000112   
       216  734.252    20.74   -20.74 -0.000155  0.000110 -0.000110   
       217  775.732    20.74   -20.74 -0.000023  0.000107 -0.000107   
       218  817.212    20.74   -20.74 -0.000052  0.000105 -0.000105   
       219  858.692    20.74   -20.74  0.000171  0.000102 -0.000102   
       
            FluxPosWithECFErr  FluxNegWithECFErr     Gamma   GammaPos  GammaNeg  \
       0            19.557086          -0.000016  1.255057  18.231662 -2.905123   
       1           -11.310830           0.000015  1.434087  14.358402 -2.226665   
       2             1.204314          -0.000016  1.613118  12.641135 -1.717817   
       3            -1.529345           0.000021  1.792149  13.903136 -1.555094   
       4             9.799804          -0.000030  1.971179  17.511724 -1.833113   
       ..                 ...                ...       ...        ...       ...   
       215          11.503893          -0.000136  3.606010  12.899198 -1.572613   
       216         -17.407297           0.000158  3.579466  13.567159 -1.625472   
       217          -2.707486           0.000108  3.552922  14.311350 -1.695630   
       218          -6.541562           0.000113  3.526379  15.120521 -1.781044   
       219          22.942664          -0.000180  3.499835  15.984805 -1.879636   
       
                 ECF       ECFPos    ECFNeg  BadBin  
       0    0.004733  7538.397454 -0.004712    True  
       1    0.005964  7186.458888 -0.004665    True  
       2    0.007515  6438.842527 -0.005127    True  
       3    0.009469  5860.853417 -0.007034    True  
       4    0.011931  7535.354362 -0.011133    True  
       ..        ...          ...       ...     ...  
       215  0.061561  6528.752230 -0.043222    True  
       216  0.060191  6778.430813 -0.044259    True  
       217  0.058852  7032.106861 -0.045526    True  
       218  0.057543  7286.151456 -0.046964    True  
       219  0.056263  7537.744214 -0.048524    True  
       
       [220 rows x 15 columns],
       'XRTBand':         Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0   -215.568    23.88   -23.88  3.812513e-10  3.197835e-10 -3.197835e-10   
       1   -167.808    23.88   -23.88 -3.740882e-10  5.154968e-10 -5.154968e-10   
       2   -120.048    23.88   -23.88  7.190098e-11  8.329024e-10 -8.329024e-10   
       3    -72.288    23.88   -23.88 -1.622391e-10  1.343343e-09 -1.343343e-09   
       4    -24.528    23.88   -23.88  1.307776e-09  2.186713e-09 -2.186713e-09   
       ..       ...      ...      ...           ...           ...           ...   
       215  692.772    20.74   -20.74  4.841592e-07  5.003263e-07 -5.003263e-07   
       216  734.252    20.74   -20.74 -6.381462e-07  4.530718e-07 -4.530718e-07   
       217  775.732    20.74   -20.74 -8.652532e-08  4.081259e-07 -4.081259e-07   
       218  817.212    20.74   -20.74 -1.824695e-07  3.693360e-07 -3.693360e-07   
       219  858.692    20.74   -20.74  5.594405e-07  3.342459e-07 -3.342459e-07   
       
            FluxPosWithECFErr  FluxNegWithECFErr     Gamma   GammaPos  GammaNeg  \
       0         5.305624e+20      -4.973301e-10  1.255057  18.231662 -2.905123   
       1        -3.909352e+20       5.940341e-10  1.434087  14.358402 -2.226665   
       2         5.057107e+19      -8.344351e-10  1.613118  12.641135 -1.717817   
       3        -6.165710e+19       1.349336e-09  1.792149  13.903136 -1.555094   
       4         2.658029e+20      -2.540820e-09  1.971179  17.511724 -1.833113   
       ..                 ...                ...       ...        ...       ...   
       215       4.193655e+20      -6.348479e-07  3.606010  12.899198 -1.572613   
       216      -5.919499e+20       7.057376e-07  3.579466  13.567159 -1.625472   
       217      -8.559131e+19       4.153884e-07  3.552922  14.311350 -1.695630   
       218      -1.917635e+20       4.075264e-07  3.526379  15.120521 -1.781044   
       219       6.225308e+20      -6.506388e-07  3.499835  15.984805 -1.879636   
       
                     ECF        ECFPos        ECFNeg  BadBin  
       0    1.469556e-07  2.045085e+23 -1.468156e-07    True  
       1    2.376810e-07  2.483849e+23 -1.875548e-07    True  
       2    3.844172e-07  2.703773e+23 -2.702794e-07    True  
       3    6.217434e-07  2.362864e+23 -4.868082e-07    True  
       4    1.005587e-06  2.043836e+23 -9.948812e-07    True  
       ..            ...           ...           ...     ...  
       215  2.747727e-04  2.380006e+23 -2.217750e-04    True  
       216  2.484952e-04  2.305063e+23 -2.107061e-04    True  
       217  2.247307e-04  2.223049e+23 -2.008621e-04    True  
       218  2.032390e-04  2.135908e+23 -1.918517e-04    True  
       219  1.838025e-04  2.045306e+23 -1.834018e-04    True  
       
       [220 rows x 15 columns],
       'BATBand':         Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0   -215.568    23.88   -23.88  6.711294e-10  5.629256e-10 -5.629256e-10   
       1   -167.808    23.88   -23.88 -4.266134e-10  5.878769e-10 -5.878769e-10   
       2   -120.048    23.88   -23.88  5.312033e-11  6.153470e-10 -6.153470e-10   
       3    -72.288    23.88   -23.88 -7.765101e-11  6.429518e-10 -6.429518e-10   
       4    -24.528    23.88   -23.88  4.054994e-10  6.780297e-10 -6.780297e-10   
       ..       ...      ...      ...           ...           ...           ...   
       215  692.772    20.74   -20.74  6.588002e-10  6.807989e-10 -6.807989e-10   
       216  734.252    20.74   -20.74 -9.587838e-10  6.807184e-10 -6.807184e-10   
       217  775.732    20.74   -20.74 -1.435419e-10  6.770639e-10 -6.770639e-10   
       218  817.212    20.74   -20.74 -3.342417e-10  6.765379e-10 -6.765379e-10   
       219  858.692    20.74   -20.74  1.131512e-09  6.760386e-10 -6.760386e-10   
       
            FluxPosWithECFErr  FluxNegWithECFErr     Gamma   GammaPos  GammaNeg  \
       0         7.072410e-10      -8.341344e-10  1.255057  18.231662 -2.905123   
       1        -6.234844e-10       6.592560e-10  1.434087  14.358402 -2.226665   
       2         6.156541e-10      -6.159746e-10  1.613118  12.641135 -1.717817   
       3        -6.434107e-10       6.438677e-10  1.792149  13.903136 -1.555094   
       4         6.934658e-10      -7.081502e-10  1.971179  17.511724 -1.833113   
       ..                 ...                ...       ...        ...       ...   
       215       6.847462e-10      -6.918986e-10  3.606010  12.899198 -1.572613   
       216      -6.900421e-10       7.057485e-10  3.579466  13.567159 -1.625472   
       217      -6.773009e-10       6.776913e-10  3.552922  14.311350 -1.695630   
       218      -6.779780e-10       6.802942e-10  3.526379  15.120521 -1.781044   
       219       6.942909e-10      -7.225837e-10  3.499835  15.984805 -1.879636   
       
                     ECF        ECFPos        ECFNeg  BadBin  
       0    2.586909e-07  1.650295e-07 -2.372653e-07    True  
       1    2.710535e-07  1.319556e-07 -1.895668e-07    True  
       2    2.840069e-07  1.039530e-07 -1.486287e-07    True  
       3    2.975793e-07  9.310490e-08 -1.315669e-07    True  
       4    3.118003e-07  1.118801e-07 -1.571186e-07    True  
       ..            ...           ...           ...     ...  
       215  3.738859e-07  4.166650e-08 -7.005300e-08    True  
       216  3.733520e-07  4.402226e-08 -7.254094e-08    True  
       217  3.728189e-07  4.654054e-08 -7.572567e-08    True  
       218  3.722866e-07  4.919405e-08 -7.951716e-08    True  
       219  3.717550e-07  5.195988e-08 -8.382710e-08    True  
       
       [220 rows x 15 columns],
       'Datasets': ['ObservedFlux', 'Density', 'XRTBand', 'BATBand']},
      'SNR4_sinceT0': {'ObservedFlux':         Time  TimePos  TimeNeg          Flux   FluxPos   FluxNeg  \
       0      0.021     0.02    -0.02  6.737252e-03  0.000512 -0.000512   
       1      0.061     0.02    -0.02  5.484209e-03  0.000509 -0.000509   
       2      0.101     0.02    -0.02  7.472067e-03  0.000562 -0.000562   
       3      0.141     0.02    -0.02  6.074374e-03  0.000557 -0.000557   
       4      0.181     0.02    -0.02  7.800982e-03  0.000572 -0.000572   
       ..       ...      ...      ...           ...       ...       ...   
       194  689.661    20.98   -20.98  8.847628e-07  0.000001 -0.000001   
       195  731.621    20.98   -20.98 -1.422917e-06  0.000001 -0.000001   
       196  773.581    20.98   -20.98 -1.122218e-07  0.000001 -0.000001   
       197  815.541    20.98   -20.98 -5.914371e-07  0.000001 -0.000001   
       198  857.501    20.98   -20.98  2.213297e-06  0.000001 -0.000001   
       
            FluxPosWithECFErr  FluxNegWithECFErr     Gamma   GammaPos  GammaNeg  \
       0             0.000543          -0.000519  0.657245   0.333172 -0.274442   
       1             0.000524          -0.000559  0.896075   0.276994 -0.226687   
       2             0.000597          -0.000783  1.003555   0.348898 -0.283475   
       3             0.000558          -0.000596  0.574969   0.317210 -0.262267   
       4             0.000604          -0.000593  0.614495   0.287972 -0.234359   
       ..                 ...                ...       ...        ...       ...   
       194           0.000002          -0.000001  3.608001  12.852515 -1.569399   
       195          -0.000003           0.000002  3.581150  13.522402 -1.621585   
       196          -0.000001           0.000001  3.554299  14.271071 -1.691599   
       197          -0.000002           0.000001  3.527448  15.086797 -1.777335   
       198           0.000004          -0.000003  3.500597  15.959301 -1.876640   
       
                 ECF    ECFPos    ECFNeg  BadBin  
       0    0.002525  0.000068 -0.000033   False  
       1    0.002490  0.000055 -0.000104   False  
       2    0.002457  0.000067 -0.000179   False  
       3    0.002501  0.000015 -0.000087   False  
       4    0.002519  0.000062 -0.000050   False  
       ..        ...       ...       ...     ...  
       194  0.000703  0.001131 -0.000566    True  
       195  0.000717  0.001165 -0.000607    True  
       196  0.000732  0.001220 -0.000654    True  
       197  0.000747  0.001297 -0.000705    True  
       198  0.000762  0.001394 -0.000761    True  
       
       [199 rows x 15 columns],
       'Density':         Time  TimePos  TimeNeg      Flux   FluxPos   FluxNeg  \
       0      0.021     0.02    -0.02  0.005121  0.000389 -0.000389   
       1      0.061     0.02    -0.02  0.006123  0.000568 -0.000568   
       2      0.101     0.02    -0.02  0.009918  0.000745 -0.000745   
       3      0.141     0.02    -0.02  0.004045  0.000371 -0.000371   
       4      0.181     0.02    -0.02  0.005536  0.000406 -0.000406   
       ..       ...      ...      ...       ...       ...       ...   
       194  689.661    20.98   -20.98  0.000078  0.000112 -0.000112   
       195  731.621    20.98   -20.98 -0.000120  0.000109 -0.000109   
       196  773.581    20.98   -20.98 -0.000009  0.000106 -0.000106   
       197  815.541    20.98   -20.98 -0.000046  0.000104 -0.000104   
       198  857.501    20.98   -20.98  0.000163  0.000102 -0.000102   
       
            FluxPosWithECFErr  FluxNegWithECFErr     Gamma   GammaPos  GammaNeg  \
       0             0.003573          -0.001852  0.657245   0.333172 -0.274442   
       1             0.003386          -0.001815  0.896075   0.276994 -0.226687   
       2             0.006526          -0.003446  1.003555   0.348898 -0.283475   
       3             0.002853          -0.001460  0.574969   0.317210 -0.262267   
       4             0.003464          -0.001719  0.614495   0.287972 -0.234359   
       ..                 ...                ...       ...        ...       ...   
       194           8.199369          -0.000124  3.608001  12.852515 -1.569399   
       195         -13.419968           0.000140  3.581150  13.522402 -1.621585   
       196          -1.076299           0.000107  3.554299  14.271071 -1.691599   
       197          -5.761040           0.000110  3.527448  15.086797 -1.777335   
       198          21.861883          -0.000174  3.500597  15.959301 -1.876640   
       
                 ECF       ECFPos    ECFNeg  BadBin  
       0    0.001920     0.001331 -0.000679   False  
       1    0.002780     0.001516 -0.000782   False  
       2    0.003261     0.002132 -0.001106   False  
       3    0.001665     0.001165 -0.000581   False  
       4    0.001787     0.001111 -0.000539   False  
       ..        ...          ...       ...     ...  
       194  0.061665  6510.309122 -0.043155    True  
       195  0.060277  6762.432242 -0.044185    True  
       196  0.058921  7018.915507 -0.045455    True  
       197  0.057595  7275.948223 -0.046903    True  
       198  0.056299  7530.575735 -0.048478    True  
       
       [199 rows x 15 columns],
       'XRTBand':         Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0      0.021     0.02    -0.02  9.377868e-08  7.125183e-09 -7.125183e-09   
       1      0.061     0.02    -0.02  1.362142e-07  1.264528e-08 -1.264528e-08   
       2      0.101     0.02    -0.02  2.432211e-07  1.827992e-08 -1.827992e-08   
       3      0.141     0.02    -0.02  7.072106e-08  6.481935e-09 -6.481935e-09   
       4      0.181     0.02    -0.02  9.860656e-08  7.233019e-09 -7.233019e-09   
       ..       ...      ...      ...           ...           ...           ...   
       194  689.661    20.98   -20.98  3.486796e-07  5.020344e-07 -5.020344e-07   
       195  731.621    20.98   -20.98 -4.962900e-07  4.528317e-07 -4.528317e-07   
       196  773.581    20.98   -20.98 -3.464090e-08  4.079304e-07 -4.079304e-07   
       197  815.541    20.98   -20.98 -1.615760e-07  3.684883e-07 -3.684883e-07   
       198  857.501    20.98   -20.98  5.351362e-07  3.334466e-07 -3.334466e-07   
       
            FluxPosWithECFErr  FluxNegWithECFErr     Gamma   GammaPos  GammaNeg  \
       0         1.209251e-07      -4.307026e-08  0.657245   0.333172 -0.274442   
       1         1.555983e-07      -5.256383e-08  0.896075   0.276994 -0.226687   
       2         3.686918e-07      -1.153110e-07  1.003555   0.348898 -0.283475   
       3         8.516802e-08      -3.131746e-08  0.574969   0.317210 -0.262267   
       4         1.146867e-07      -3.814263e-08  0.614495   0.287972 -0.234359   
       ..                 ...                ...       ...        ...       ...   
       194       3.004127e+20      -5.750516e-07  3.608001  12.852515 -1.569399   
       195      -4.584265e+20       6.172513e-07  3.581150  13.522402 -1.621585   
       196      -3.415619e+19       4.090972e-07  3.554299  14.271071 -1.691599   
       197      -1.694036e+20       3.986775e-07  3.527448  15.086797 -1.777335   
       198       5.945346e+20      -6.288092e-07  3.500597  15.959301 -1.876640   
       
                     ECF        ECFPos        ECFNeg  BadBin  
       0    3.515106e-08  4.524760e-08 -1.592158e-08   False  
       1    6.184749e-08  7.041508e-08 -2.316547e-08   False  
       2    7.997716e-08  1.210860e-07 -3.743765e-08   False  
       3    2.911742e-08  3.496385e-08 -1.261488e-08   False  
       4    3.183665e-08  3.695466e-08 -1.209149e-08   False  
       ..            ...           ...           ...     ...  
       194  2.768520e-04  2.385280e+23 -2.226685e-04    True  
       195  2.500846e-04  2.310049e+23 -2.113669e-04    True  
       196  2.259052e-04  2.227443e+23 -2.013493e-04    True  
       197  2.040636e-04  2.139496e+23 -1.922024e-04    True  
       198  1.843338e-04  2.047943e+23 -1.836385e-04    True  
       
       [199 rows x 15 columns],
       'BATBand':         Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0      0.021     0.02    -0.02  5.427668e-07  4.123872e-08 -4.123872e-08   
       1      0.061     0.02    -0.02  4.963665e-07  4.607958e-08 -4.607958e-08   
       2      0.101     0.02    -0.02  7.143265e-07  5.368707e-08 -5.368707e-08   
       3      0.141     0.02    -0.02  4.724508e-07  4.330246e-08 -4.330246e-08   
       4      0.181     0.02    -0.02  6.166816e-07  4.523502e-08 -4.523502e-08   
       ..       ...      ...      ...           ...           ...           ...   
       194  689.661    20.98   -20.98  4.709387e-10  6.780651e-10 -6.780651e-10   
       195  731.621    20.98   -20.98 -7.409798e-10  6.760949e-10 -6.760949e-10   
       196  773.581    20.98   -20.98 -5.717326e-11  6.732710e-10 -6.732710e-10   
       197  815.541    20.98   -20.98 -2.947906e-10  6.722959e-10 -6.722959e-10   
       198  857.501    20.98   -20.98  1.079280e-09  6.725058e-10 -6.725058e-10   
       
            FluxPosWithECFErr  FluxNegWithECFErr     Gamma   GammaPos  GammaNeg  \
       0         9.136069e-08      -8.014363e-08  0.657245   0.333172 -0.274442   
       1         7.160602e-08      -6.605581e-08  0.896075   0.276994 -0.226687   
       2         1.022432e-07      -9.404761e-08  1.003555   0.348898 -0.283475   
       3         8.762068e-08      -7.593011e-08  0.574969   0.317210 -0.262267   
       4         9.462797e-08      -8.226825e-08  0.614495   0.287972 -0.234359   
       ..                 ...                ...       ...        ...       ...   
       194       6.800763e-10      -6.837556e-10  3.608001  12.852515 -1.569399   
       195      -6.816765e-10       6.911769e-10  3.581150  13.522402 -1.621585   
       196      -6.733086e-10       6.733706e-10  3.554299  14.271071 -1.691599   
       197      -6.734184e-10       6.752256e-10  3.527448  15.086797 -1.777335   
       198       6.891641e-10      -7.150544e-10  3.500597  15.959301 -1.876640   
       
                     ECF        ECFPos        ECFNeg  BadBin  
       0    2.034452e-07  3.055759e-08 -2.575813e-08   False  
       1    2.253731e-07  2.488608e-08 -2.148957e-08   False  
       2    2.348884e-07  2.861225e-08 -2.539127e-08   False  
       3    1.945184e-07  3.136198e-08 -2.567997e-08   False  
       4    1.991052e-07  2.683524e-08 -2.218595e-08   False  
       ..            ...           ...           ...     ...  
       194  3.739259e-07  4.149723e-08 -6.989691e-08    True  
       195  3.733858e-07  4.386770e-08 -7.236150e-08    True  
       196  3.728465e-07  4.640641e-08 -7.554483e-08    True  
       197  3.723080e-07  4.908484e-08 -7.935382e-08    True  
       198  3.717703e-07  5.187908e-08 -8.369689e-08    True  
       
       [199 rows x 15 columns],
       'Datasets': ['ObservedFlux', 'Density', 'XRTBand', 'BATBand']},
      'SNR5': {'ObservedFlux':         Time  TimePos  TimeNeg          Flux   FluxPos   FluxNeg  \
       0   -215.568    23.88   -23.88  6.171864e-06  0.000005 -0.000005   
       1   -167.808    23.88   -23.88 -3.536856e-06  0.000005 -0.000005   
       2   -120.048    23.88   -23.88  3.970237e-07  0.000005 -0.000005   
       3    -72.288    23.88   -23.88 -5.232095e-07  0.000004 -0.000004   
       4    -24.488    23.92   -23.92  3.018422e-06  0.000004 -0.000004   
       ..       ...      ...      ...           ...       ...       ...   
       187  693.432    20.68   -20.68  1.205771e-06  0.000001 -0.000001   
       188  734.792    20.68   -20.68 -1.684039e-06  0.000001 -0.000001   
       189  776.152    20.68   -20.68 -3.997169e-07  0.000001 -0.000001   
       190  817.512    20.68   -20.68 -6.052343e-07  0.000001 -0.000001   
       191  858.872    20.68   -20.68  2.340526e-06  0.000001 -0.000001   
       
            FluxPosWithECFErr  FluxNegWithECFErr     Gamma   GammaPos  GammaNeg  \
       0             0.000008          -0.000006  1.255057  18.231662 -2.905123   
       1            -0.000006           0.000005  1.434087  14.358402 -2.226665   
       2             0.000005          -0.000005  1.613118  12.641135 -1.717817   
       3            -0.000004           0.000004  1.792149  13.903136 -1.555094   
       4             0.000004          -0.000005  1.971329  17.515390 -1.833497   
       ..                 ...                ...       ...        ...       ...   
       187           0.000002          -0.000002  3.605588  12.909167 -1.573309   
       188          -0.000003           0.000002  3.579121  13.576383 -1.626279   
       189          -0.000001           0.000001  3.552654  14.319236 -1.696422   
       190          -0.000002           0.000001  3.526187  15.126585 -1.781713   
       191           0.000005          -0.000003  3.499771  15.986948 -1.879888   
       
                 ECF    ECFPos    ECFNeg  BadBin  
       0    0.002379 -0.002379 -0.001220    True  
       1    0.002247  0.001693 -0.001031    True  
       2    0.002123  0.001101 -0.001193    True  
       3    0.002005  0.000650 -0.001525    True  
       4    0.001894  0.000521 -0.001894    True  
       ..        ...       ...       ...     ...  
       187  0.000704  0.001133 -0.000570    True  
       188  0.000718  0.001168 -0.000611    True  
       189  0.000733  0.001224 -0.000657    True  
       190  0.000748  0.001301 -0.000708    True  
       191  0.000763  0.001397 -0.000763    True  
       
       [192 rows x 15 columns],
       'Density':         Time  TimePos  TimeNeg      Flux   FluxPos   FluxNeg  \
       0   -215.568    23.88   -23.88  0.000012  0.000010 -0.000010   
       1   -167.808    23.88   -23.88 -0.000009  0.000013 -0.000013   
       2   -120.048    23.88   -23.88  0.000001  0.000016 -0.000016   
       3    -72.288    23.88   -23.88 -0.000002  0.000020 -0.000020   
       4    -24.488    23.92   -23.92  0.000019  0.000026 -0.000026   
       ..       ...      ...      ...       ...       ...       ...   
       187  693.432    20.68   -20.68  0.000105  0.000112 -0.000112   
       188  734.792    20.68   -20.68 -0.000141  0.000110 -0.000110   
       189  776.152    20.68   -20.68 -0.000032  0.000107 -0.000107   
       190  817.512    20.68   -20.68 -0.000047  0.000105 -0.000105   
       191  858.872    20.68   -20.68  0.000173  0.000102 -0.000102   
       
            FluxPosWithECFErr  FluxNegWithECFErr     Gamma   GammaPos  GammaNeg  \
       0            19.557086          -0.000016  1.255057  18.231662 -2.905123   
       1           -11.310830           0.000015  1.434087  14.358402 -2.226665   
       2             1.204314          -0.000016  1.613118  12.641135 -1.717817   
       3            -1.529345           0.000021  1.792149  13.903136 -1.555094   
       4            12.014384          -0.000031  1.971329  17.515390 -1.833497   
       ..                 ...                ...       ...        ...       ...   
       187          11.192036          -0.000134  3.605588  12.909167 -1.573309   
       188         -15.903380           0.000151  3.579121  13.576383 -1.626279   
       189          -3.837413           0.000110  3.552654  14.319236 -1.696422   
       190          -5.899516           0.000111  3.526187  15.126585 -1.781713   
       191          23.127880          -0.000181  3.499771  15.986948 -1.879888   
       
                 ECF       ECFPos    ECFNeg  BadBin  
       0    0.004733  7538.397454 -0.004712    True  
       1    0.005964  7186.458888 -0.004665    True  
       2    0.007515  6438.842527 -0.005127    True  
       3    0.009469  5860.853417 -0.007034    True  
       4    0.011933  7538.390254 -0.011138    True  
       ..        ...          ...       ...     ...  
       187  0.061539  6532.671178 -0.043236    True  
       188  0.060174  6781.716425 -0.044274    True  
       189  0.058839  7034.682688 -0.045539    True  
       190  0.057534  7287.982850 -0.046975    True  
       191  0.056260  7538.345928 -0.048528    True  
       
       [192 rows x 15 columns],
       'XRTBand':         Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0   -215.568    23.88   -23.88  3.812513e-10  3.197835e-10 -3.197835e-10   
       1   -167.808    23.88   -23.88 -3.740882e-10  5.154968e-10 -5.154968e-10   
       2   -120.048    23.88   -23.88  7.190098e-11  8.329024e-10 -8.329024e-10   
       3    -72.288    23.88   -23.88 -1.622391e-10  1.343343e-09 -1.343343e-09   
       4    -24.488    23.92   -23.92  1.603309e-09  2.186667e-09 -2.186667e-09   
       ..       ...      ...      ...           ...           ...           ...   
       187  693.432    20.68   -20.68  4.699993e-07  5.003216e-07 -5.003216e-07   
       188  734.792    20.68   -20.68 -5.819685e-07  4.531987e-07 -4.531987e-07   
       189  776.152    20.68   -20.68 -1.224657e-07  4.081298e-07 -4.081298e-07   
       190  817.512    20.68   -20.68 -1.643994e-07  3.697653e-07 -3.697653e-07   
       191  858.872    20.68   -20.68  5.637752e-07  3.345536e-07 -3.345536e-07   
       
            FluxPosWithECFErr  FluxNegWithECFErr     Gamma   GammaPos  GammaNeg  \
       0         5.305624e+20      -4.973301e-10  1.255057  18.231662 -2.905123   
       1        -3.909352e+20       5.940341e-10  1.434087  14.358402 -2.226665   
       2         5.057107e+19      -8.344351e-10  1.613118  12.641135 -1.717817   
       3        -6.165710e+19       1.349336e-09  1.792149  13.903136 -1.555094   
       4         3.259374e+20      -2.701615e-09  1.971329  17.515390 -1.833497   
       ..                 ...                ...       ...        ...       ...   
       187       4.075593e+20      -6.280459e-07  3.605588  12.909167 -1.573309   
       188      -5.403052e+20       6.702422e-07  3.579121  13.576383 -1.626279   
       189      -1.212202e+20       4.225686e-07  3.552654  14.319236 -1.696422   
       190      -1.728465e+20       4.010350e-07  3.526187  15.126585 -1.781713   
       191       6.274385e+20      -6.545755e-07  3.499771  15.986948 -1.879888   
       
                     ECF        ECFPos        ECFNeg  BadBin  
       0    1.469556e-07  2.045085e+23 -1.468156e-07    True  
       1    2.376810e-07  2.483849e+23 -1.875548e-07    True  
       2    3.844172e-07  2.703773e+23 -2.702794e-07    True  
       3    6.217434e-07  2.362864e+23 -4.868082e-07    True  
       4    1.005992e-06  2.045085e+23 -9.954903e-07    True  
       ..            ...           ...           ...     ...  
       187  2.743336e-04  2.378880e+23 -2.215867e-04    True  
       188  2.481702e-04  2.304036e+23 -2.105711e-04    True  
       189  2.245021e-04  2.222189e+23 -2.007673e-04    True  
       190  2.030913e-04  2.135264e+23 -1.917889e-04    True  
       191  1.837580e-04  2.045085e+23 -1.833819e-04    True  
       
       [192 rows x 15 columns],
       'BATBand':         Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0   -215.568    23.88   -23.88  6.711294e-10  5.629256e-10 -5.629256e-10   
       1   -167.808    23.88   -23.88 -4.266134e-10  5.878769e-10 -5.878769e-10   
       2   -120.048    23.88   -23.88  5.312033e-11  6.153470e-10 -6.153470e-10   
       3    -72.288    23.88   -23.88 -7.765101e-11  6.429518e-10 -6.429518e-10   
       4    -24.488    23.92   -23.92  4.969542e-10  6.777691e-10 -6.777691e-10   
       ..       ...      ...      ...           ...           ...           ...   
       187  693.432    20.68   -20.68  6.405418e-10  6.818667e-10 -6.818667e-10   
       188  734.792    20.68   -20.68 -8.755082e-10  6.817880e-10 -6.817880e-10   
       189  776.152    20.68   -20.68 -2.033694e-10  6.777499e-10 -6.777499e-10   
       190  817.512    20.68   -20.68 -3.013574e-10  6.778098e-10 -6.778098e-10   
       191  858.872    20.68   -20.68  1.140552e-09  6.768225e-10 -6.768225e-10   
       
            FluxPosWithECFErr  FluxNegWithECFErr     Gamma   GammaPos  GammaNeg  \
       0         7.072410e-10      -8.341344e-10  1.255057  18.231662 -2.905123   
       1        -6.234844e-10       6.592560e-10  1.434087  14.358402 -2.226665   
       2         6.156541e-10      -6.159746e-10  1.613118  12.641135 -1.717817   
       3        -6.434107e-10       6.438677e-10  1.792149  13.903136 -1.555094   
       4         7.008432e-10      -7.225696e-10  1.971329  17.515390 -1.833497   
       ..                 ...                ...       ...        ...       ...   
       187       6.855996e-10      -6.923585e-10  3.605588  12.909167 -1.573309   
       188      -6.895706e-10       7.027108e-10  3.579121  13.576383 -1.626279   
       189      -6.782258e-10       6.790088e-10  3.552654  14.319236 -1.696422   
       190      -6.789795e-10       6.808615e-10  3.526187  15.126585 -1.781713   
       191       6.953477e-10      -7.240509e-10  3.499771  15.986948 -1.879888   
       
                     ECF        ECFPos        ECFNeg  BadBin  
       0    2.586909e-07  1.650295e-07 -2.372653e-07    True  
       1    2.710535e-07  1.319556e-07 -1.895668e-07    True  
       2    2.840069e-07  1.039530e-07 -1.486287e-07    True  
       3    2.975793e-07  9.310490e-08 -1.315669e-07    True  
       4    3.118125e-07  1.119079e-07 -1.571576e-07    True  
       ..            ...           ...           ...     ...  
       187  3.738774e-07  4.170255e-08 -7.008669e-08    True  
       188  3.733451e-07  4.405407e-08 -7.257811e-08    True  
       189  3.728135e-07  4.656677e-08 -7.576117e-08    True  
       190  3.722827e-07  4.921367e-08 -7.954657e-08    True  
       191  3.717537e-07  5.196666e-08 -8.383805e-08    True  
       
       [192 rows x 15 columns],
       'Datasets': ['ObservedFlux', 'Density', 'XRTBand', 'BATBand']},
      'SNR5_sinceT0': {'ObservedFlux':         Time  TimePos  TimeNeg          Flux   FluxPos   FluxNeg  \
       0      0.021     0.02    -0.02  6.737252e-03  0.000512 -0.000512   
       1      0.061     0.02    -0.02  5.484209e-03  0.000509 -0.000509   
       2      0.101     0.02    -0.02  7.472067e-03  0.000562 -0.000562   
       3      0.141     0.02    -0.02  6.074374e-03  0.000557 -0.000557   
       4      0.181     0.02    -0.02  7.800982e-03  0.000572 -0.000572   
       ..       ...      ...      ...           ...       ...       ...   
       175  693.881    20.64   -20.64  1.198916e-06  0.000001 -0.000001   
       176  735.161    20.64   -20.64 -1.532316e-06  0.000001 -0.000001   
       177  776.441    20.64   -20.64 -6.328970e-07  0.000001 -0.000001   
       178  817.721    20.64   -20.64 -5.101064e-07  0.000001 -0.000001   
       179  859.001    20.64   -20.64  2.248531e-06  0.000001 -0.000001   
       
            FluxPosWithECFErr  FluxNegWithECFErr     Gamma   GammaPos  GammaNeg  \
       0             0.000543          -0.000519  0.657245   0.333172 -0.274442   
       1             0.000524          -0.000559  0.896075   0.276994 -0.226687   
       2             0.000597          -0.000783  1.003555   0.348898 -0.283475   
       3             0.000558          -0.000596  0.574969   0.317210 -0.262267   
       4             0.000604          -0.000593  0.614495   0.287972 -0.234359   
       ..                 ...                ...       ...        ...       ...   
       175           0.000002          -0.000002  3.605300  12.915961 -1.573785   
       176          -0.000003           0.000002  3.578884  13.582694 -1.626831   
       177          -0.000002           0.000001  3.552469  14.324666 -1.696968   
       178          -0.000002           0.000001  3.526053  15.130811 -1.782179   
       179           0.000004          -0.000003  3.499771  15.986948 -1.879888   
       
                 ECF    ECFPos    ECFNeg  BadBin  
       0    0.002525  0.000068 -0.000033   False  
       1    0.002490  0.000055 -0.000104   False  
       2    0.002457  0.000067 -0.000179   False  
       3    0.002501  0.000015 -0.000087   False  
       4    0.002519  0.000062 -0.000050   False  
       ..        ...       ...       ...     ...  
       175  0.000704  0.001133 -0.000570    True  
       176  0.000718  0.001169 -0.000611    True  
       177  0.000733  0.001225 -0.000657    True  
       178  0.000748  0.001302 -0.000708    True  
       179  0.000763  0.001397 -0.000763    True  
       
       [180 rows x 15 columns],
       'Density':         Time  TimePos  TimeNeg      Flux   FluxPos   FluxNeg  \
       0      0.021     0.02    -0.02  0.005121  0.000389 -0.000389   
       1      0.061     0.02    -0.02  0.006123  0.000568 -0.000568   
       2      0.101     0.02    -0.02  0.009918  0.000745 -0.000745   
       3      0.141     0.02    -0.02  0.004045  0.000371 -0.000371   
       4      0.181     0.02    -0.02  0.005536  0.000406 -0.000406   
       ..       ...      ...      ...       ...       ...       ...   
       175  693.881    20.64   -20.64  0.000105  0.000112 -0.000112   
       176  735.161    20.64   -20.64 -0.000128  0.000110 -0.000110   
       177  776.441    20.64   -20.64 -0.000051  0.000107 -0.000107   
       178  817.721    20.64   -20.64 -0.000039  0.000105 -0.000105   
       179  859.001    20.64   -20.64  0.000166  0.000103 -0.000103   
       
            FluxPosWithECFErr  FluxNegWithECFErr     Gamma   GammaPos  GammaNeg  \
       0             0.003573          -0.001852  0.657245   0.333172 -0.274442   
       1             0.003386          -0.001815  0.896075   0.276994 -0.226687   
       2             0.006526          -0.003446  1.003555   0.348898 -0.283475   
       3             0.002853          -0.001460  0.574969   0.317210 -0.262267   
       4             0.003464          -0.001719  0.614495   0.287972 -0.234359   
       ..                 ...                ...       ...        ...       ...   
       175          11.130522          -0.000134  3.605300  12.915961 -1.573785   
       176         -14.472754           0.000145  3.578884  13.582694 -1.626831   
       177          -6.076693           0.000114  3.552469  14.324666 -1.696968   
       178          -4.972621           0.000110  3.526053  15.130811 -1.782179   
       179          22.218832          -0.000176  3.499771  15.986948 -1.879888   
       
                 ECF       ECFPos    ECFNeg  BadBin  
       0    0.001920     0.001331 -0.000679   False  
       1    0.002780     0.001516 -0.000782   False  
       2    0.003261     0.002132 -0.001106   False  
       3    0.001665     0.001165 -0.000581   False  
       4    0.001787     0.001111 -0.000539   False  
       ..        ...          ...       ...     ...  
       175  0.061524  6535.338472 -0.043246    True  
       176  0.060162  6783.961970 -0.044284    True  
       177  0.058830  7036.455118 -0.045549    True  
       178  0.057527  7289.258643 -0.046983    True  
       179  0.056260  7538.345928 -0.048528    True  
       
       [180 rows x 15 columns],
       'XRTBand':         Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0      0.021     0.02    -0.02  9.377868e-08  7.125183e-09 -7.125183e-09   
       1      0.061     0.02    -0.02  1.362142e-07  1.264528e-08 -1.264528e-08   
       2      0.101     0.02    -0.02  2.432211e-07  1.827992e-08 -1.827992e-08   
       3      0.141     0.02    -0.02  7.072106e-08  6.481935e-09 -6.481935e-09   
       4      0.181     0.02    -0.02  9.860656e-08  7.233019e-09 -7.233019e-09   
       ..       ...      ...      ...           ...           ...           ...   
       175  693.881    20.64   -20.64  4.667172e-07  5.000962e-07 -5.000962e-07   
       176  735.161    20.64   -20.64 -5.289677e-07  4.532082e-07 -4.532082e-07   
       177  776.441    20.64   -20.64 -1.937446e-07  4.082669e-07 -4.082669e-07   
       178  817.721    20.64   -20.64 -1.384756e-07  3.699810e-07 -3.699810e-07   
       179  859.001    20.64   -20.64  5.416159e-07  3.347945e-07 -3.347945e-07   
       
            FluxPosWithECFErr  FluxNegWithECFErr     Gamma   GammaPos  GammaNeg  \
       0         1.209251e-07      -4.307026e-08  0.657245   0.333172 -0.274442   
       1         1.555983e-07      -5.256383e-08  0.896075   0.276994 -0.226687   
       2         3.686918e-07      -1.153110e-07  1.003555   0.348898 -0.283475   
       3         8.516802e-08      -3.131746e-08  0.574969   0.317210 -0.262267   
       4         1.146867e-07      -3.814263e-08  0.614495   0.287972 -0.234359   
       ..                 ...                ...       ...        ...       ...   
       175       4.050232e+20      -6.263830e-07  3.605300  12.915961 -1.573785   
       176      -4.913882e+20       6.379864e-07  3.578884  13.582694 -1.626831   
       177      -1.918575e+20       4.435357e-07  3.552469  14.324666 -1.696968   
       178      -1.456338e+20       3.924233e-07  3.526053  15.130811 -1.782179   
       179       6.027768e+20      -6.357954e-07  3.499771  15.986948 -1.879888   
       
                     ECF        ECFPos        ECFNeg  BadBin  
       0    3.515106e-08  4.524760e-08 -1.592158e-08   False  
       1    6.184749e-08  7.041508e-08 -2.316547e-08   False  
       2    7.997716e-08  1.210860e-07 -3.743765e-08   False  
       3    2.911742e-08  3.496385e-08 -1.261488e-08   False  
       4    3.183665e-08  3.695466e-08 -1.209149e-08   False  
       ..            ...           ...           ...     ...  
       175  2.740352e-04  2.378113e+23 -2.214589e-04    True  
       176  2.479484e-04  2.303334e+23 -2.104789e-04    True  
       177  2.243450e-04  2.221597e+23 -2.007020e-04    True  
       178  2.029884e-04  2.134814e+23 -1.917451e-04    True  
       179  1.837580e-04  2.045085e+23 -1.833819e-04    True  
       
       [180 rows x 15 columns],
       'BATBand':         Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0      0.021     0.02    -0.02  5.427668e-07  4.123872e-08 -4.123872e-08   
       1      0.061     0.02    -0.02  4.963665e-07  4.607958e-08 -4.607958e-08   
       2      0.101     0.02    -0.02  7.143265e-07  5.368707e-08 -5.368707e-08   
       3      0.141     0.02    -0.02  4.724508e-07  4.330246e-08 -4.330246e-08   
       4      0.181     0.02    -0.02  6.166816e-07  4.523502e-08 -4.523502e-08   
       ..       ...      ...      ...           ...           ...           ...   
       175  693.881    20.64   -20.64  6.367514e-10  6.822909e-10 -6.822909e-10   
       176  735.161    20.64   -20.64 -7.964760e-10  6.824036e-10 -6.824036e-10   
       177  776.441    20.64   -20.64 -3.219591e-10  6.784458e-10 -6.784458e-10   
       178  817.721    20.64   -20.64 -2.539638e-10  6.785438e-10 -6.785438e-10   
       179  859.001    20.64   -20.64  1.095722e-09  6.773100e-10 -6.773100e-10   
       
            FluxPosWithECFErr  FluxNegWithECFErr     Gamma   GammaPos  GammaNeg  \
       0         9.136069e-08      -8.014363e-08  0.657245   0.333172 -0.274442   
       1         7.160602e-08      -6.605581e-08  0.896075   0.276994 -0.226687   
       2         1.022432e-07      -9.404761e-08  1.003555   0.348898 -0.283475   
       3         8.762068e-08      -7.593011e-08  0.574969   0.317210 -0.262267   
       4         9.462797e-08      -8.226825e-08  0.614495   0.287972 -0.234359   
       ..                 ...                ...       ...        ...       ...   
       175       6.859821e-10      -6.926606e-10  3.605300  12.915961 -1.573785   
       176      -6.888515e-10       6.997613e-10  3.578884  13.582694 -1.626831   
       177      -6.796376e-10       6.815954e-10  3.552469  14.324666 -1.696968   
       178      -6.793743e-10       6.807113e-10  3.526053  15.130811 -1.782179   
       179       6.944130e-10      -7.209792e-10  3.499771  15.986948 -1.879888   
       
                     ECF        ECFPos        ECFNeg  BadBin  
       0    2.034452e-07  3.055759e-08 -2.575813e-08   False  
       1    2.253731e-07  2.488608e-08 -2.148957e-08   False  
       2    2.348884e-07  2.861225e-08 -2.539127e-08   False  
       3    1.945184e-07  3.136198e-08 -2.567997e-08   False  
       4    1.991052e-07  2.683524e-08 -2.218595e-08   False  
       ..            ...           ...           ...     ...  
       175  3.738716e-07  4.172710e-08 -7.010971e-08    True  
       176  3.733403e-07  4.407582e-08 -7.260359e-08    True  
       177  3.728098e-07  4.658483e-08 -7.578564e-08    True  
       178  3.722801e-07  4.922735e-08 -7.956708e-08    True  
       179  3.717537e-07  5.196666e-08 -8.383805e-08    True  
       
       [180 rows x 15 columns],
       'Datasets': ['ObservedFlux', 'Density', 'XRTBand', 'BATBand']},
      'SNR6': {'ObservedFlux':         Time  TimePos  TimeNeg          Flux   FluxPos   FluxNeg  \
       0   -215.568    23.88   -23.88  6.171864e-06  0.000005 -0.000005   
       1   -167.808    23.88   -23.88 -3.536856e-06  0.000005 -0.000005   
       2   -120.048    23.88   -23.88  3.970237e-07  0.000005 -0.000005   
       3    -72.288    23.88   -23.88 -5.232095e-07  0.000004 -0.000004   
       4    -24.468    23.94   -23.94  3.531508e-06  0.000004 -0.000004   
       ..       ...      ...      ...           ...       ...       ...   
       168  692.912    20.72   -20.72  1.282414e-06  0.000001 -0.000001   
       169  734.352    20.72   -20.72 -1.955556e-06  0.000001 -0.000001   
       170  775.792    20.72   -20.72 -3.226486e-07  0.000001 -0.000001   
       171  817.232    20.72   -20.72 -5.874072e-07  0.000001 -0.000001   
       172  858.672    20.72   -20.72  2.311804e-06  0.000001 -0.000001   
       
            FluxPosWithECFErr  FluxNegWithECFErr     Gamma   GammaPos  GammaNeg  \
       0             0.000008          -0.000006  1.255057  18.231662 -2.905123   
       1            -0.000006           0.000005  1.434087  14.358402 -2.226665   
       2             0.000005          -0.000005  1.613118  12.641135 -1.717817   
       3            -0.000004           0.000004  1.792149  13.903136 -1.555094   
       4             0.000004          -0.000005  1.970451  17.500830 -1.831973   
       ..                 ...                ...       ...        ...       ...   
       168           0.000002          -0.000002  3.605920  12.901311 -1.572760   
       169          -0.000003           0.000002  3.579402  13.568866 -1.625621   
       170          -0.000001           0.000001  3.552884  14.312477 -1.695743   
       171          -0.000002           0.000001  3.526366  15.120925 -1.781089   
       172           0.000004          -0.000003  3.499848  15.984376 -1.879585   
       
                 ECF    ECFPos    ECFNeg  BadBin  
       0    0.002379 -0.002379 -0.001220    True  
       1    0.002247  0.001693 -0.001031    True  
       2    0.002123  0.001101 -0.001193    True  
       3    0.002005  0.000650 -0.001525    True  
       4    0.001894  0.000520 -0.001893    True  
       ..        ...       ...       ...     ...  
       168  0.000704  0.001133 -0.000569    True  
       169  0.000718  0.001168 -0.000610    True  
       170  0.000733  0.001224 -0.000656    True  
       171  0.000748  0.001301 -0.000707    True  
       172  0.000763  0.001397 -0.000763    True  
       
       [173 rows x 15 columns],
       'Density':         Time  TimePos  TimeNeg      Flux   FluxPos   FluxNeg  \
       0   -215.568    23.88   -23.88  0.000012  0.000010 -0.000010   
       1   -167.808    23.88   -23.88 -0.000009  0.000013 -0.000013   
       2   -120.048    23.88   -23.88  0.000001  0.000016 -0.000016   
       3    -72.288    23.88   -23.88 -0.000002  0.000020 -0.000020   
       4    -24.468    23.94   -23.94  0.000022  0.000026 -0.000026   
       ..       ...      ...      ...       ...       ...       ...   
       168  692.912    20.72   -20.72  0.000112  0.000112 -0.000112   
       169  734.352    20.72   -20.72 -0.000164  0.000110 -0.000110   
       170  775.792    20.72   -20.72 -0.000026  0.000107 -0.000107   
       171  817.232    20.72   -20.72 -0.000045  0.000105 -0.000105   
       172  858.672    20.72   -20.72  0.000171  0.000102 -0.000102   
       
            FluxPosWithECFErr  FluxNegWithECFErr     Gamma   GammaPos  GammaNeg  \
       0            19.557086          -0.000016  1.255057  18.231662 -2.905123   
       1           -11.310830           0.000015  1.434087  14.358402 -2.226665   
       2             1.204314          -0.000016  1.613118  12.641135 -1.717817   
       3            -1.529345           0.000021  1.792149  13.903136 -1.555094   
       4            14.025132          -0.000033  1.970451  17.500830 -1.831973   
       ..                 ...                ...       ...        ...       ...   
       168          11.900831          -0.000137  3.605920  12.901311 -1.572760   
       169         -18.464141           0.000163  3.579402  13.568866 -1.625621   
       170          -3.097103           0.000109  3.552884  14.312477 -1.695743   
       171          -5.725184           0.000111  3.526366  15.120925 -1.781089   
       172          22.843214          -0.000179  3.499848  15.984376 -1.879585   
       
                 ECF       ECFPos    ECFNeg  BadBin  
       0    0.004733  7538.397454 -0.004712    True  
       1    0.005964  7186.458888 -0.004665    True  
       2    0.007515  6438.842527 -0.005127    True  
       3    0.009469  5860.853417 -0.007034    True  
       4    0.011919  7523.230815 -0.011115    True  
       ..        ...          ...       ...     ...  
       168  0.061557  6529.583343 -0.043225    True  
       169  0.060188  6779.039210 -0.044262    True  
       170  0.058850  7032.474835 -0.045527    True  
       171  0.057542  7286.273553 -0.046965    True  
       172  0.056263  7537.623869 -0.048524    True  
       
       [173 rows x 15 columns],
       'XRTBand':         Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0   -215.568    23.88   -23.88  3.812513e-10  3.197835e-10 -3.197835e-10   
       1   -167.808    23.88   -23.88 -3.740882e-10  5.154968e-10 -5.154968e-10   
       2   -120.048    23.88   -23.88  7.190098e-11  8.329024e-10 -8.329024e-10   
       3    -72.288    23.88   -23.88 -1.622391e-10  1.343343e-09 -1.343343e-09   
       4    -24.468    23.94   -23.94  1.871134e-09  2.181665e-09 -2.181665e-09   
       ..       ...      ...      ...           ...           ...           ...   
       168  692.912    20.72   -20.72  5.006313e-07  5.003966e-07 -5.003966e-07   
       169  734.352    20.72   -20.72 -6.766650e-07  4.531892e-07 -4.531892e-07   
       170  775.792    20.72   -20.72 -9.895708e-08  4.082726e-07 -4.082726e-07   
       171  817.232    20.72   -20.72 -1.596871e-07  3.695044e-07 -3.695044e-07   
       172  858.672    20.72   -20.72  5.570514e-07  3.344258e-07 -3.344258e-07   
       
            FluxPosWithECFErr  FluxNegWithECFErr     Gamma   GammaPos  GammaNeg  \
       0         5.305624e+20      -4.973301e-10  1.255057  18.231662 -2.905123   
       1        -3.909352e+20       5.940341e-10  1.434087  14.358402 -2.226665   
       2         5.057107e+19      -8.344351e-10  1.613118  12.641135 -1.717817   
       3        -6.165710e+19       1.349336e-09  1.792149  13.903136 -1.555094   
       4         3.800676e+20      -2.860488e-09  1.970451  17.500830 -1.831973   
       ..                 ...                ...       ...        ...       ...   
       168       4.337368e+20      -6.432119e-07  3.605920  12.901311 -1.572760   
       169      -6.277807e+20       7.312087e-07  3.579402  13.568866 -1.625621   
       170      -9.789769e+19       4.177447e-07  3.552884  14.312477 -1.695743   
       171      -1.678255e+20       3.990705e-07  3.526366  15.120925 -1.781089   
       172       6.198556e+20      -6.486746e-07  3.499848  15.984376 -1.879585   
       
                     ECF        ECFPos        ECFNeg  BadBin  
       0    1.469556e-07  2.045085e+23 -1.468156e-07    True  
       1    2.376810e-07  2.483849e+23 -1.875548e-07    True  
       2    3.844172e-07  2.703773e+23 -2.702794e-07    True  
       3    6.217434e-07  2.362864e+23 -4.868082e-07    True  
       4    1.003696e-06  2.038723e+23 -9.923936e-07    True  
       ..            ...           ...           ...     ...  
       168  2.746795e-04  2.379767e+23 -2.217350e-04    True  
       169  2.484350e-04  2.304873e+23 -2.106811e-04    True  
       170  2.246981e-04  2.222926e+23 -2.008486e-04    True  
       171  2.032291e-04  2.135865e+23 -1.918475e-04    True  
       172  1.838114e-04  2.045351e+23 -1.834058e-04    True  
       
       [173 rows x 15 columns],
       'BATBand':         Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0   -215.568    23.88   -23.88  6.711294e-10  5.629256e-10 -5.629256e-10   
       1   -167.808    23.88   -23.88 -4.266134e-10  5.878769e-10 -5.878769e-10   
       2   -120.048    23.88   -23.88  5.312033e-11  6.153470e-10 -6.153470e-10   
       3    -72.288    23.88   -23.88 -7.765101e-11  6.429518e-10 -6.429518e-10   
       4    -24.468    23.94   -23.94  5.811434e-10  6.775890e-10 -6.775890e-10   
       ..       ...      ...      ...           ...           ...           ...   
       168  692.912    20.72   -20.72  6.814418e-10  6.811222e-10 -6.811222e-10   
       169  734.352    20.72   -20.72 -1.016899e-09  6.810574e-10 -6.810574e-10   
       170  775.792    20.72   -20.72 -1.641892e-10  6.774043e-10 -6.774043e-10   
       171  817.232    20.72   -20.72 -2.925237e-10  6.768786e-10 -6.768786e-10   
       172  858.672    20.72   -20.72  1.126626e-09  6.763700e-10 -6.763700e-10   
       
            FluxPosWithECFErr  FluxNegWithECFErr     Gamma   GammaPos  GammaNeg  \
       0         7.072410e-10      -8.341344e-10  1.255057  18.231662 -2.905123   
       1        -6.234844e-10       6.592560e-10  1.434087  14.358402 -2.226665   
       2         6.156541e-10      -6.159746e-10  1.613118  12.641135 -1.717817   
       3        -6.434107e-10       6.438677e-10  1.792149  13.903136 -1.555094   
       4         7.089117e-10      -7.380901e-10  1.970451  17.500830 -1.831973   
       ..                 ...                ...       ...        ...       ...   
       168       6.853442e-10      -6.929882e-10  3.605920  12.901311 -1.572760   
       169      -6.915345e-10       7.091436e-10  3.579402  13.568866 -1.625621   
       170      -6.777144e-10       6.782249e-10  3.552884  14.312477 -1.695743   
       171      -6.779815e-10       6.797563e-10  3.526366  15.120925 -1.781089   
       172       6.944574e-10      -7.225032e-10  3.499848  15.984376 -1.879585   
       
                     ECF        ECFPos        ECFNeg  BadBin  
       0    2.586909e-07  1.650295e-07 -2.372653e-07    True  
       1    2.710535e-07  1.319556e-07 -1.895668e-07    True  
       2    2.840069e-07  1.039530e-07 -1.486287e-07    True  
       3    2.975793e-07  9.310490e-08 -1.315669e-07    True  
       4    3.117316e-07  1.117859e-07 -1.569862e-07    True  
       ..            ...           ...           ...     ...  
       168  3.738841e-07  4.167414e-08 -7.006013e-08    True  
       169  3.733507e-07  4.402815e-08 -7.254781e-08    True  
       170  3.728181e-07  4.654429e-08 -7.573074e-08    True  
       171  3.722863e-07  4.919535e-08 -7.951912e-08    True  
       172  3.717553e-07  5.195852e-08 -8.382491e-08    True  
       
       [173 rows x 15 columns],
       'Datasets': ['ObservedFlux', 'Density', 'XRTBand', 'BATBand']},
      'SNR6_sinceT0': {'ObservedFlux':         Time  TimePos  TimeNeg          Flux   FluxPos   FluxNeg  \
       0      0.021     0.02    -0.02  6.737252e-03  0.000512 -0.000512   
       1      0.061     0.02    -0.02  5.484209e-03  0.000509 -0.000509   
       2      0.101     0.02    -0.02  7.472067e-03  0.000562 -0.000562   
       3      0.141     0.02    -0.02  6.074374e-03  0.000557 -0.000557   
       4      0.181     0.02    -0.02  7.800982e-03  0.000572 -0.000572   
       ..       ...      ...      ...           ...       ...       ...   
       151  693.041    20.72   -20.72  1.249978e-06  0.000001 -0.000001   
       152  734.481    20.72   -20.72 -1.845054e-06  0.000001 -0.000001   
       153  775.921    20.72   -20.72 -3.358172e-07  0.000001 -0.000001   
       154  817.361    20.72   -20.72 -5.958255e-07  0.000001 -0.000001   
       155  858.801    20.72   -20.72  2.365946e-06  0.000001 -0.000001   
       
            FluxPosWithECFErr  FluxNegWithECFErr     Gamma   GammaPos  GammaNeg  \
       0             0.000543          -0.000519  0.657245   0.333172 -0.274442   
       1             0.000524          -0.000559  0.896075   0.276994 -0.226687   
       2             0.000597          -0.000783  1.003555   0.348898 -0.283475   
       3             0.000558          -0.000596  0.574969   0.317210 -0.262267   
       4             0.000604          -0.000593  0.614495   0.287972 -0.234359   
       ..                 ...                ...       ...        ...       ...   
       151           0.000002          -0.000002  3.605838  12.903259 -1.572896   
       152          -0.000003           0.000002  3.579320  13.571069 -1.625814   
       153          -0.000001           0.000001  3.552801  14.314898 -1.695986   
       154          -0.000002           0.000001  3.526283  15.123532 -1.781376   
       155           0.000005          -0.000003  3.499771  15.986948 -1.879888   
       
                 ECF    ECFPos    ECFNeg  BadBin  
       0    0.002525  0.000068 -0.000033   False  
       1    0.002490  0.000055 -0.000104   False  
       2    0.002457  0.000067 -0.000179   False  
       3    0.002501  0.000015 -0.000087   False  
       4    0.002519  0.000062 -0.000050   False  
       ..        ...       ...       ...     ...  
       151  0.000704  0.001133 -0.000569    True  
       152  0.000718  0.001168 -0.000610    True  
       153  0.000733  0.001224 -0.000656    True  
       154  0.000748  0.001301 -0.000707    True  
       155  0.000763  0.001397 -0.000763    True  
       
       [156 rows x 15 columns],
       'Density':         Time  TimePos  TimeNeg      Flux   FluxPos   FluxNeg  \
       0      0.021     0.02    -0.02  0.005121  0.000389 -0.000389   
       1      0.061     0.02    -0.02  0.006123  0.000568 -0.000568   
       2      0.101     0.02    -0.02  0.009918  0.000745 -0.000745   
       3      0.141     0.02    -0.02  0.004045  0.000371 -0.000371   
       4      0.181     0.02    -0.02  0.005536  0.000406 -0.000406   
       ..       ...      ...      ...       ...       ...       ...   
       151  693.041    20.72   -20.72  0.000109  0.000112 -0.000112   
       152  734.481    20.72   -20.72 -0.000155  0.000110 -0.000110   
       153  775.921    20.72   -20.72 -0.000027  0.000107 -0.000107   
       154  817.361    20.72   -20.72 -0.000046  0.000105 -0.000105   
       155  858.801    20.72   -20.72  0.000174  0.000102 -0.000102   
       
            FluxPosWithECFErr  FluxNegWithECFErr     Gamma   GammaPos  GammaNeg  \
       0             0.003573          -0.001852  0.657245   0.333172 -0.274442   
       1             0.003386          -0.001815  0.896075   0.276994 -0.226687   
       2             0.006526          -0.003446  1.003555   0.348898 -0.283475   
       3             0.002853          -0.001460  0.574969   0.317210 -0.262267   
       4             0.003464          -0.001719  0.614495   0.287972 -0.234359   
       ..                 ...                ...       ...        ...       ...   
       151          11.600459          -0.000136  3.605838  12.903259 -1.572896   
       152         -17.421714           0.000158  3.579320  13.571069 -1.625814   
       153          -3.223669           0.000109  3.552801  14.314898 -1.695986   
       154          -5.807496           0.000111  3.526283  15.123532 -1.781376   
       155          23.379069          -0.000182  3.499771  15.986948 -1.879888   
       
                 ECF       ECFPos    ECFNeg  BadBin  
       0    0.001920     0.001331 -0.000679   False  
       1    0.002780     0.001516 -0.000782   False  
       2    0.003261     0.002132 -0.001106   False  
       3    0.001665     0.001165 -0.000581   False  
       4    0.001787     0.001111 -0.000539   False  
       ..        ...          ...       ...     ...  
       151  0.061552  6530.349239 -0.043228    True  
       152  0.060184  6779.824076 -0.044265    True  
       153  0.058846  7033.265980 -0.045532    True  
       154  0.057538  7287.061065 -0.046969    True  
       155  0.056260  7538.345928 -0.048528    True  
       
       [156 rows x 15 columns],
       'XRTBand':         Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0      0.021     0.02    -0.02  9.377868e-08  7.125183e-09 -7.125183e-09   
       1      0.061     0.02    -0.02  1.362142e-07  1.264528e-08 -1.264528e-08   
       2      0.101     0.02    -0.02  2.432211e-07  1.827992e-08 -1.827992e-08   
       3      0.141     0.02    -0.02  7.072106e-08  6.481935e-09 -6.481935e-09   
       4      0.181     0.02    -0.02  9.860656e-08  7.233019e-09 -7.233019e-09   
       ..       ...      ...      ...           ...           ...           ...   
       151  693.041    20.72   -20.72  4.877859e-07  5.002515e-07 -5.002515e-07   
       152  734.481    20.72   -20.72 -6.381892e-07  4.530925e-07 -4.530925e-07   
       153  775.921    20.72   -20.72 -1.029573e-07  4.080717e-07 -4.080717e-07   
       154  817.361    20.72   -20.72 -1.619148e-07  3.694782e-07 -3.694782e-07   
       155  858.801    20.72   -20.72  5.698983e-07  3.342628e-07 -3.342628e-07   
       
            FluxPosWithECFErr  FluxNegWithECFErr     Gamma   GammaPos  GammaNeg  \
       0         1.209251e-07      -4.307026e-08  0.657245   0.333172 -0.274442   
       1         1.555983e-07      -5.256383e-08  0.896075   0.276994 -0.226687   
       2         3.686918e-07      -1.153110e-07  1.003555   0.348898 -0.283475   
       3         8.516802e-08      -3.131746e-08  0.574969   0.317210 -0.262267   
       4         1.146867e-07      -3.814263e-08  0.614495   0.287972 -0.234359   
       ..                 ...                ...       ...        ...       ...   
       151       4.227008e+20      -6.366695e-07  3.605838  12.903259 -1.572896   
       152      -5.922066e+20       7.058963e-07  3.579320  13.571069 -1.625814   
       153      -1.018748e+20       4.183237e-07  3.552801  14.314898 -1.695986   
       154      -1.701978e+20       3.998555e-07  3.526283  15.123532 -1.781376   
       155       6.342530e+20      -6.596876e-07  3.499771  15.986948 -1.879888   
       
                     ECF        ECFPos        ECFNeg  BadBin  
       0    3.515106e-08  4.524760e-08 -1.592158e-08   False  
       1    6.184749e-08  7.041508e-08 -2.316547e-08   False  
       2    7.997716e-08  1.210860e-07 -3.743765e-08   False  
       3    2.911742e-08  3.496385e-08 -1.261488e-08   False  
       4    3.183665e-08  3.695466e-08 -1.209149e-08   False  
       ..            ...           ...           ...     ...  
       151  2.745936e-04  2.379547e+23 -2.216982e-04    True  
       152  2.483573e-04  2.304628e+23 -2.106488e-04    True  
       153  2.246278e-04  2.222662e+23 -2.008194e-04    True  
       154  2.031656e-04  2.135588e+23 -1.918205e-04    True  
       155  1.837580e-04  2.045085e+23 -1.833819e-04    True  
       
       [156 rows x 15 columns],
       'BATBand':         Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0      0.021     0.02    -0.02  5.427668e-07  4.123872e-08 -4.123872e-08   
       1      0.061     0.02    -0.02  4.963665e-07  4.607958e-08 -4.607958e-08   
       2      0.101     0.02    -0.02  7.143265e-07  5.368707e-08 -5.368707e-08   
       3      0.141     0.02    -0.02  4.724508e-07  4.330246e-08 -4.330246e-08   
       4      0.181     0.02    -0.02  6.166816e-07  4.523502e-08 -4.523502e-08   
       ..       ...      ...      ...           ...           ...           ...   
       151  693.041    20.72   -20.72  6.641617e-10  6.811347e-10 -6.811347e-10   
       152  734.481    20.72   -20.72 -9.593730e-10  6.811220e-10 -6.811220e-10   
       153  775.921    20.72   -20.72 -1.708789e-10  6.772796e-10 -6.772796e-10   
       154  817.361    20.72   -20.72 -2.966960e-10  6.770392e-10 -6.770392e-10   
       155  858.801    20.72   -20.72  1.152939e-09  6.762342e-10 -6.762342e-10   
       
            FluxPosWithECFErr  FluxNegWithECFErr     Gamma   GammaPos  GammaNeg  \
       0         9.136069e-08      -8.014363e-08  0.657245   0.333172 -0.274442   
       1         7.160602e-08      -6.605581e-08  0.896075   0.276994 -0.226687   
       2         1.022432e-07      -9.404761e-08  1.003555   0.348898 -0.283475   
       3         8.762068e-08      -7.593011e-08  0.574969   0.317210 -0.262267   
       4         9.462797e-08      -8.226825e-08  0.614495   0.287972 -0.234359   
       ..                 ...                ...       ...        ...       ...   
       151       6.851472e-10      -6.924133e-10  3.605838  12.903259 -1.572896   
       152      -6.904574e-10       7.061790e-10  3.579320  13.571069 -1.625814   
       153      -6.776156e-10       6.781688e-10  3.552801  14.314898 -1.695986   
       154      -6.781739e-10       6.799997e-10  3.526283  15.123532 -1.781376   
       155       6.951744e-10      -7.244988e-10  3.499771  15.986948 -1.879888   
       
                     ECF        ECFPos        ECFNeg  BadBin  
       0    2.034452e-07  3.055759e-08 -2.575813e-08   False  
       1    2.253731e-07  2.488608e-08 -2.148957e-08   False  
       2    2.348884e-07  2.861225e-08 -2.539127e-08   False  
       3    1.945184e-07  3.136198e-08 -2.567997e-08   False  
       4    1.991052e-07  2.683524e-08 -2.218595e-08   False  
       ..            ...           ...           ...     ...  
       151  3.738824e-07  4.168118e-08 -7.006671e-08    True  
       152  3.733491e-07  4.403575e-08 -7.255669e-08    True  
       153  3.728165e-07  4.655234e-08 -7.574164e-08    True  
       154  3.722847e-07  4.920379e-08 -7.953176e-08    True  
       155  3.717537e-07  5.196666e-08 -8.383805e-08    True  
       
       [156 rows x 15 columns],
       'Datasets': ['ObservedFlux', 'Density', 'XRTBand', 'BATBand']},
      'SNR7': {'ObservedFlux':         Time  TimePos  TimeNeg          Flux   FluxPos   FluxNeg  \
       0   -215.568    23.88   -23.88  6.171864e-06  0.000005 -0.000005   
       1   -167.808    23.88   -23.88 -3.536856e-06  0.000005 -0.000005   
       2   -120.048    23.88   -23.88  3.970237e-07  0.000005 -0.000005   
       3    -72.288    23.88   -23.88 -5.232095e-07  0.000004 -0.000004   
       4    -24.468    23.94   -23.94  3.531508e-06  0.000004 -0.000004   
       ..       ...      ...      ...           ...       ...       ...   
       148  693.652    20.66   -20.66  1.070736e-06  0.000001 -0.000001   
       149  734.972    20.66   -20.66 -1.563458e-06  0.000001 -0.000001   
       150  776.292    20.66   -20.66 -5.014013e-07  0.000001 -0.000001   
       151  817.612    20.66   -20.66 -5.300486e-07  0.000001 -0.000001   
       152  858.932    20.66   -20.66  2.311826e-06  0.000001 -0.000001   
       
            FluxPosWithECFErr  FluxNegWithECFErr     Gamma   GammaPos  GammaNeg  \
       0             0.000008          -0.000006  1.255057  18.231662 -2.905123   
       1            -0.000006           0.000005  1.434087  14.358402 -2.226665   
       2             0.000005          -0.000005  1.613118  12.641135 -1.717817   
       3            -0.000004           0.000004  1.792149  13.903136 -1.555094   
       4             0.000004          -0.000005  1.970451  17.500830 -1.831973   
       ..                 ...                ...       ...        ...       ...   
       148           0.000002          -0.000002  3.605447  12.912494 -1.573542   
       149          -0.000003           0.000002  3.579005  13.579461 -1.626548   
       150          -0.000002           0.000001  3.552564  14.321866 -1.696687   
       151          -0.000002           0.000001  3.526123  15.128607 -1.781935   
       152           0.000004          -0.000003  3.499771  15.986948 -1.879888   
       
                 ECF    ECFPos    ECFNeg  BadBin  
       0    0.002379 -0.002379 -0.001220    True  
       1    0.002247  0.001693 -0.001031    True  
       2    0.002123  0.001101 -0.001193    True  
       3    0.002005  0.000650 -0.001525    True  
       4    0.001894  0.000520 -0.001893    True  
       ..        ...       ...       ...     ...  
       148  0.000704  0.001133 -0.000570    True  
       149  0.000718  0.001169 -0.000611    True  
       150  0.000733  0.001225 -0.000657    True  
       151  0.000748  0.001301 -0.000708    True  
       152  0.000763  0.001397 -0.000763    True  
       
       [153 rows x 15 columns],
       'Density':         Time  TimePos  TimeNeg      Flux   FluxPos   FluxNeg  \
       0   -215.568    23.88   -23.88  0.000012  0.000010 -0.000010   
       1   -167.808    23.88   -23.88 -0.000009  0.000013 -0.000013   
       2   -120.048    23.88   -23.88  0.000001  0.000016 -0.000016   
       3    -72.288    23.88   -23.88 -0.000002  0.000020 -0.000020   
       4    -24.468    23.94   -23.94  0.000022  0.000026 -0.000026   
       ..       ...      ...      ...       ...       ...       ...   
       148  693.652    20.66   -20.66  0.000094  0.000112 -0.000112   
       149  734.972    20.66   -20.66 -0.000131  0.000110 -0.000110   
       150  776.292    20.66   -20.66 -0.000040  0.000107 -0.000107   
       151  817.612    20.66   -20.66 -0.000041  0.000105 -0.000105   
       152  858.932    20.66   -20.66  0.000170  0.000102 -0.000102   
       
            FluxPosWithECFErr  FluxNegWithECFErr     Gamma   GammaPos  GammaNeg  \
       0            19.557086          -0.000016  1.255057  18.231662 -2.905123   
       1           -11.310830           0.000015  1.434087  14.358402 -2.226665   
       2             1.204314          -0.000016  1.613118  12.641135 -1.717817   
       3            -1.529345           0.000021  1.792149  13.903136 -1.555094   
       4            14.025132          -0.000033  1.970451  17.500830 -1.831973   
       ..                 ...                ...       ...        ...       ...   
       148           9.939557          -0.000130  3.605447  12.912494 -1.573542   
       149         -14.765747           0.000146  3.579005  13.579461 -1.626548   
       150          -4.813875           0.000111  3.552564  14.321866 -1.696687   
       151          -5.166824           0.000110  3.526123  15.128607 -1.781935   
       152          22.844288          -0.000179  3.499771  15.986948 -1.879888   
       
                 ECF       ECFPos    ECFNeg  BadBin  
       0    0.004733  7538.397454 -0.004712    True  
       1    0.005964  7186.458888 -0.004665    True  
       2    0.007515  6438.842527 -0.005127    True  
       3    0.009469  5860.853417 -0.007034    True  
       4    0.011919  7523.230815 -0.011115    True  
       ..        ...          ...       ...     ...  
       148  0.061532  6533.977970 -0.043241    True  
       149  0.060168  6782.811775 -0.044279    True  
       150  0.058834  7035.541303 -0.045544    True  
       151  0.057530  7288.593285 -0.046979    True  
       152  0.056260  7538.345928 -0.048528    True  
       
       [153 rows x 15 columns],
       'XRTBand':         Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0   -215.568    23.88   -23.88  3.812513e-10  3.197835e-10 -3.197835e-10   
       1   -167.808    23.88   -23.88 -3.740882e-10  5.154968e-10 -5.154968e-10   
       2   -120.048    23.88   -23.88  7.190098e-11  8.329024e-10 -8.329024e-10   
       3    -72.288    23.88   -23.88 -1.622391e-10  1.343343e-09 -1.343343e-09   
       4    -24.468    23.94   -23.94  1.871134e-09  2.181665e-09 -2.181665e-09   
       ..       ...      ...      ...           ...           ...           ...   
       148  693.652    20.66   -20.66  4.170967e-07  5.001933e-07 -5.001933e-07   
       149  734.972    20.66   -20.66 -5.400151e-07  4.532733e-07 -4.532733e-07   
       150  776.292    20.66   -20.66 -1.535573e-07  4.081460e-07 -4.081460e-07   
       151  817.612    20.66   -20.66 -1.439348e-07  3.699309e-07 -3.699309e-07   
       152  858.932    20.66   -20.66  5.568622e-07  3.346365e-07 -3.346365e-07   
       
            FluxPosWithECFErr  FluxNegWithECFErr     Gamma   GammaPos  GammaNeg  \
       0         5.305624e+20      -4.973301e-10  1.255057  18.231662 -2.905123   
       1        -3.909352e+20       5.940341e-10  1.434087  14.358402 -2.226665   
       2         5.057107e+19      -8.344351e-10  1.613118  12.641135 -1.717817   
       3        -6.165710e+19       1.349336e-09  1.792149  13.903136 -1.555094   
       4         3.800676e+20      -2.860488e-09  1.970451  17.500830 -1.831973   
       ..                 ...                ...       ...        ...       ...   
       148       3.618206e+20      -6.031187e-07  3.605447  12.912494 -1.573542   
       149      -5.014994e+20       6.445908e-07  3.579005  13.579461 -1.626548   
       150      -1.520275e+20       4.306363e-07  3.552564  14.321866 -1.696687   
       151      -1.513518e+20       3.941183e-07  3.526123  15.128607 -1.781935   
       152       6.197449e+20      -6.486982e-07  3.499771  15.986948 -1.879888   
       
                     ECF        ECFPos        ECFNeg  BadBin  
       0    1.469556e-07  2.045085e+23 -1.468156e-07    True  
       1    2.376810e-07  2.483849e+23 -1.875548e-07    True  
       2    3.844172e-07  2.703773e+23 -2.702794e-07    True  
       3    6.217434e-07  2.362864e+23 -4.868082e-07    True  
       4    1.003696e-06  2.038723e+23 -9.923936e-07    True  
       ..            ...           ...           ...     ...  
       148  2.741873e-04  2.378504e+23 -2.215241e-04    True  
       149  2.480620e-04  2.303694e+23 -2.105261e-04    True  
       150  2.244260e-04  2.221902e+23 -2.007357e-04    True  
       151  2.030421e-04  2.135049e+23 -1.917679e-04    True  
       152  1.837580e-04  2.045085e+23 -1.833819e-04    True  
       
       [153 rows x 15 columns],
       'BATBand':         Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0   -215.568    23.88   -23.88  6.711294e-10  5.629256e-10 -5.629256e-10   
       1   -167.808    23.88   -23.88 -4.266134e-10  5.878769e-10 -5.878769e-10   
       2   -120.048    23.88   -23.88  5.312033e-11  6.153470e-10 -6.153470e-10   
       3    -72.288    23.88   -23.88 -7.765101e-11  6.429518e-10 -6.429518e-10   
       4    -24.468    23.94   -23.94  5.811434e-10  6.775890e-10 -6.775890e-10   
       ..       ...      ...      ...           ...           ...           ...   
       148  693.652    20.66   -20.66  5.687419e-10  6.820503e-10 -6.820503e-10   
       149  734.972    20.66   -20.66 -8.127432e-10  6.821935e-10 -6.821935e-10   
       150  776.292    20.66   -20.66 -2.550861e-10  6.780036e-10 -6.780036e-10   
       151  817.612    20.66   -20.66 -2.639073e-10  6.782752e-10 -6.782752e-10   
       152  858.932    20.66   -20.66  1.126567e-09  6.769903e-10 -6.769903e-10   
       
            FluxPosWithECFErr  FluxNegWithECFErr     Gamma   GammaPos  GammaNeg  \
       0         7.072410e-10      -8.341344e-10  1.255057  18.231662 -2.905123   
       1        -6.234844e-10       6.592560e-10  1.434087  14.358402 -2.226665   
       2         6.156541e-10      -6.159746e-10  1.613118  12.641135 -1.717817   
       3        -6.434107e-10       6.438677e-10  1.792149  13.903136 -1.555094   
       4         7.089117e-10      -7.380901e-10  1.970451  17.500830 -1.831973   
       ..                 ...                ...       ...        ...       ...   
       148       6.849959e-10      -6.903357e-10  3.605447  12.912494 -1.573542   
       149      -6.889048e-10       7.002570e-10  3.579005  13.579461 -1.626548   
       150      -6.787521e-10       6.799830e-10  3.552564  14.321866 -1.696687   
       151      -6.791721e-10       6.806158e-10  3.526123  15.128607 -1.781935   
       152       6.950654e-10      -7.230936e-10  3.499771  15.986948 -1.879888   
       
                     ECF        ECFPos        ECFNeg  BadBin  
       0    2.586909e-07  1.650295e-07 -2.372653e-07    True  
       1    2.710535e-07  1.319556e-07 -1.895668e-07    True  
       2    2.840069e-07  1.039530e-07 -1.486287e-07    True  
       3    2.975793e-07  9.310490e-08 -1.315669e-07    True  
       4    3.117316e-07  1.117859e-07 -1.569862e-07    True  
       ..            ...           ...           ...     ...  
       148  3.738745e-07  4.171458e-08 -7.009796e-08    True  
       149  3.733427e-07  4.406467e-08 -7.259053e-08    True  
       150  3.728117e-07  4.657552e-08 -7.577302e-08    True  
       151  3.722814e-07  4.922022e-08 -7.955638e-08    True  
       152  3.717537e-07  5.196666e-08 -8.383805e-08    True  
       
       [153 rows x 15 columns],
       'Datasets': ['ObservedFlux', 'Density', 'XRTBand', 'BATBand']},
      'SNR7_sinceT0': {'ObservedFlux':         Time  TimePos  TimeNeg          Flux   FluxPos   FluxNeg  \
       0      0.021     0.02    -0.02  6.737252e-03  0.000512 -0.000512   
       1      0.061     0.02    -0.02  5.484209e-03  0.000509 -0.000509   
       2      0.101     0.02    -0.02  7.472067e-03  0.000562 -0.000562   
       3      0.141     0.02    -0.02  6.074374e-03  0.000557 -0.000557   
       4      0.181     0.02    -0.02  7.800982e-03  0.000572 -0.000572   
       ..       ...      ...      ...           ...       ...       ...   
       135  692.821    20.70   -20.70  1.153609e-06  0.000001 -0.000001   
       136  734.221    20.70   -20.70 -1.844581e-06  0.000001 -0.000001   
       137  775.621    20.70   -20.70 -2.930431e-07  0.000001 -0.000001   
       138  817.021    20.70   -20.70 -5.178601e-07  0.000001 -0.000001   
       139  858.421    20.70   -20.70  2.172835e-06  0.000001 -0.000001   
       
            FluxPosWithECFErr  FluxNegWithECFErr     Gamma   GammaPos  GammaNeg  \
       0             0.000543          -0.000519  0.657245   0.333172 -0.274442   
       1             0.000524          -0.000559  0.896075   0.276994 -0.226687   
       2             0.000597          -0.000783  1.003555   0.348898 -0.283475   
       3             0.000558          -0.000596  0.574969   0.317210 -0.262267   
       4             0.000604          -0.000593  0.614495   0.287972 -0.234359   
       ..                 ...                ...       ...        ...       ...   
       135           0.000002          -0.000002  3.605979  12.899938 -1.572665   
       136          -0.000003           0.000002  3.579486  13.566630 -1.625426   
       137          -0.000001           0.000001  3.552993  14.309268 -1.695421   
       138          -0.000002           0.000001  3.526501  15.116661 -1.780619   
       139           0.000004          -0.000003  3.500008  15.978999 -1.878953   
       
                 ECF    ECFPos    ECFNeg  BadBin  
       0    0.002525  0.000068 -0.000033   False  
       1    0.002490  0.000055 -0.000104   False  
       2    0.002457  0.000067 -0.000179   False  
       3    0.002501  0.000015 -0.000087   False  
       4    0.002519  0.000062 -0.000050   False  
       ..        ...       ...       ...     ...  
       135  0.000704  0.001133 -0.000569    True  
       136  0.000718  0.001168 -0.000610    True  
       137  0.000733  0.001224 -0.000656    True  
       138  0.000747  0.001300 -0.000707    True  
       139  0.000763  0.001396 -0.000762    True  
       
       [140 rows x 15 columns],
       'Density':         Time  TimePos  TimeNeg      Flux   FluxPos   FluxNeg  \
       0      0.021     0.02    -0.02  0.005121  0.000389 -0.000389   
       1      0.061     0.02    -0.02  0.006123  0.000568 -0.000568   
       2      0.101     0.02    -0.02  0.009918  0.000745 -0.000745   
       3      0.141     0.02    -0.02  0.004045  0.000371 -0.000371   
       4      0.181     0.02    -0.02  0.005536  0.000406 -0.000406   
       ..       ...      ...      ...       ...       ...       ...   
       135  692.821    20.70   -20.70  0.000101  0.000112 -0.000112   
       136  734.221    20.70   -20.70 -0.000155  0.000110 -0.000110   
       137  775.621    20.70   -20.70 -0.000024  0.000107 -0.000107   
       138  817.021    20.70   -20.70 -0.000040  0.000105 -0.000105   
       139  858.421    20.70   -20.70  0.000160  0.000102 -0.000102   
       
            FluxPosWithECFErr  FluxNegWithECFErr     Gamma   GammaPos  GammaNeg  \
       0             0.003573          -0.001852  0.657245   0.333172 -0.274442   
       1             0.003386          -0.001815  0.896075   0.276994 -0.226687   
       2             0.006526          -0.003446  1.003555   0.348898 -0.283475   
       3             0.002853          -0.001460  0.574969   0.317210 -0.262267   
       4             0.003464          -0.001719  0.614495   0.287972 -0.234359   
       ..                 ...                ...       ...        ...       ...   
       135          10.705107          -0.000133  3.605979  12.899938 -1.572665   
       136         -17.415388           0.000158  3.579486  13.566630 -1.625426   
       137          -2.812735           0.000109  3.552993  14.309268 -1.695421   
       138          -5.046968           0.000110  3.526501  15.116661 -1.780619   
       139          21.468373          -0.000172  3.500008  15.978999 -1.878953   
       
                 ECF       ECFPos    ECFNeg  BadBin  
       0    0.001920     0.001331 -0.000679   False  
       1    0.002780     0.001516 -0.000782   False  
       2    0.003261     0.002132 -0.001106   False  
       3    0.001665     0.001165 -0.000581   False  
       4    0.001787     0.001111 -0.000539   False  
       ..        ...          ...       ...     ...  
       135  0.061560  6529.043109 -0.043223    True  
       136  0.060193  6778.242215 -0.044258    True  
       137  0.058856  7031.426112 -0.045522    True  
       138  0.057549  7284.985401 -0.046957    True  
       139  0.056271  7536.113436 -0.048514    True  
       
       [140 rows x 15 columns],
       'XRTBand':         Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0      0.021     0.02    -0.02  9.377868e-08  7.125183e-09 -7.125183e-09   
       1      0.061     0.02    -0.02  1.362142e-07  1.264528e-08 -1.264528e-08   
       2      0.101     0.02    -0.02  2.432211e-07  1.827992e-08 -1.827992e-08   
       3      0.141     0.02    -0.02  7.072106e-08  6.481935e-09 -6.481935e-09   
       4      0.181     0.02    -0.02  9.860656e-08  7.233019e-09 -7.233019e-09   
       ..       ...      ...      ...           ...           ...           ...   
       135  692.821    20.70   -20.70  4.504675e-07  5.007725e-07 -5.007725e-07   
       136  734.221    20.70   -20.70 -6.385086e-07  4.535422e-07 -4.535422e-07   
       137  775.621    20.70   -20.70 -8.992176e-08  4.087071e-07 -4.087071e-07   
       138  817.021    20.70   -20.70 -1.408672e-07  3.697474e-07 -3.697474e-07   
       139  858.421    20.70   -20.70  5.239482e-07  3.348292e-07 -3.348292e-07   
       
            FluxPosWithECFErr  FluxNegWithECFErr     Gamma   GammaPos  GammaNeg  \
       0         1.209251e-07      -4.307026e-08  0.657245   0.333172 -0.274442   
       1         1.555983e-07      -5.256383e-08  0.896075   0.276994 -0.226687   
       2         3.686918e-07      -1.153110e-07  1.003555   0.348898 -0.283475   
       3         8.516802e-08      -3.131746e-08  0.574969   0.317210 -0.262267   
       4         1.146867e-07      -3.814263e-08  0.614495   0.287972 -0.234359   
       ..                 ...                ...       ...        ...       ...   
       135       3.902152e+20      -6.188536e-07  3.605979  12.899938 -1.572665   
       136      -5.922567e+20       7.062593e-07  3.579486  13.566630 -1.625426   
       137      -8.893624e+19       4.165323e-07  3.552993  14.309268 -1.695421   
       138      -1.480021e+20       3.929204e-07  3.526501  15.116661 -1.780619   
       139       5.828241e+20      -6.206755e-07  3.500008  15.978999 -1.878953   
       
                     ECF        ECFPos        ECFNeg  BadBin  
       0    3.515106e-08  4.524760e-08 -1.592158e-08   False  
       1    6.184749e-08  7.041508e-08 -2.316547e-08   False  
       2    7.997716e-08  1.210860e-07 -3.743765e-08   False  
       3    2.911742e-08  3.496385e-08 -1.261488e-08   False  
       4    3.183665e-08  3.695466e-08 -1.209149e-08   False  
       ..            ...           ...           ...     ...  
       135  2.747401e-04  2.379922e+23 -2.217610e-04    True  
       136  2.485139e-04  2.305122e+23 -2.107138e-04    True  
       137  2.247912e-04  2.223276e+23 -2.008872e-04    True  
       138  2.033331e-04  2.136319e+23 -1.918918e-04    True  
       139  1.839233e-04  2.045906e+23 -1.834556e-04    True  
       
       [140 rows x 15 columns],
       'BATBand':         Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0      0.021     0.02    -0.02  5.427668e-07  4.123872e-08 -4.123872e-08   
       1      0.061     0.02    -0.02  4.963665e-07  4.607958e-08 -4.607958e-08   
       2      0.101     0.02    -0.02  7.143265e-07  5.368707e-08 -5.368707e-08   
       3      0.141     0.02    -0.02  4.724508e-07  4.330246e-08 -4.330246e-08   
       4      0.181     0.02    -0.02  6.166816e-07  4.523502e-08 -4.523502e-08   
       ..       ...      ...      ...           ...           ...           ...   
       135  692.821    20.70   -20.70  6.130273e-10  6.814858e-10 -6.814858e-10   
       136  734.221    20.70   -20.70 -9.592571e-10  6.813748e-10 -6.813748e-10   
       137  775.621    20.70   -20.70 -1.491369e-10  6.778483e-10 -6.778483e-10   
       138  817.021    20.70   -20.70 -2.579183e-10  6.769825e-10 -6.769825e-10   
       139  858.421    20.70   -20.70  1.059041e-09  6.767801e-10 -6.767801e-10   
       
            FluxPosWithECFErr  FluxNegWithECFErr     Gamma   GammaPos  GammaNeg  \
       0         9.136069e-08      -8.014363e-08  0.657245   0.333172 -0.274442   
       1         7.160602e-08      -6.605581e-08  0.896075   0.276994 -0.226687   
       2         1.022432e-07      -9.404761e-08  1.003555   0.348898 -0.283475   
       3         8.762068e-08      -7.593011e-08  0.574969   0.317210 -0.262267   
       4         9.462797e-08      -8.226825e-08  0.614495   0.287972 -0.234359   
       ..                 ...                ...       ...        ...       ...   
       135       6.849019e-10      -6.910981e-10  3.605979  12.899938 -1.572665   
       136      -6.906979e-10       7.064043e-10  3.579486  13.566630 -1.625426   
       137      -6.781038e-10       6.785246e-10  3.552993  14.309268 -1.695421   
       138      -6.778394e-10       6.792191e-10  3.526501  15.116661 -1.780619   
       139       6.927667e-10      -7.176468e-10  3.500008  15.978999 -1.878953   
       
                     ECF        ECFPos        ECFNeg  BadBin  
       0    2.034452e-07  3.055759e-08 -2.575813e-08   False  
       1    2.253731e-07  2.488608e-08 -2.148957e-08   False  
       2    2.348884e-07  2.861225e-08 -2.539127e-08   False  
       3    1.945184e-07  3.136198e-08 -2.567997e-08   False  
       4    1.991052e-07  2.683524e-08 -2.218595e-08   False  
       ..            ...           ...           ...     ...  
       135  3.738852e-07  4.166917e-08 -7.005550e-08    True  
       136  3.733524e-07  4.402044e-08 -7.253881e-08    True  
       137  3.728203e-07  4.653361e-08 -7.571630e-08    True  
       138  3.722890e-07  4.918155e-08 -7.949845e-08    True  
       139  3.717585e-07  5.194148e-08 -8.379744e-08    True  
       
       [140 rows x 15 columns],
       'Datasets': ['ObservedFlux', 'Density', 'XRTBand', 'BATBand']},
      'TimeBins_4ms': {'ObservedFlux':          Time  TimePos  TimeNeg      Flux   FluxPos   FluxNeg  \
       0     -7.7338    0.002   -0.002 -0.000515  0.000676 -0.000676   
       1     -7.7298    0.002   -0.002  0.000510  0.000481 -0.000481   
       2     -7.7258    0.002   -0.002  0.001305  0.000586 -0.000586   
       3     -7.7218    0.002   -0.002  0.000680  0.000510 -0.000510   
       4     -7.7178    0.002   -0.002 -0.001208  0.000590 -0.000590   
       ...       ...      ...      ...       ...       ...       ...   
       5665  14.9262    0.002   -0.002 -0.000696  0.000481 -0.000481   
       5666  14.9302    0.002   -0.002  0.000310  0.000403 -0.000403   
       5667  14.9342    0.002   -0.002  0.000468  0.000534 -0.000534   
       5668  14.9382    0.002   -0.002 -0.000229  0.000400 -0.000400   
       5669  14.9422    0.002   -0.002 -0.000396  0.000555 -0.000555   
       
             FluxPosWithECFErr  FluxNegWithECFErr     Gamma  GammaPos  GammaNeg  \
       0             -0.000677           0.000694  1.235877  5.328021 -0.611289   
       1              0.000483          -0.000506  1.235701  5.325119 -0.611037   
       2              0.000596          -0.000710  1.235525  5.322216 -0.610784   
       3              0.000513          -0.000551  1.235350  5.319314 -0.610531   
       4             -0.000599           0.000697  1.235174  5.316412 -0.610279   
       ...                 ...                ...       ...       ...       ...   
       5665          -0.000484           0.000492  1.530824  0.451665 -0.322449   
       5666           0.000403          -0.000405  1.530701  0.451737 -0.322467   
       5667           0.000536          -0.000539  1.530578  0.451809 -0.322485   
       5668          -0.000401           0.000402  1.530455  0.451881 -0.322504   
       5669          -0.000556           0.000559  1.530331  0.451953 -0.322522   
       
                  ECF    ECFPos    ECFNeg  BadBin  
       0     0.002299  0.000193 -0.000708   False  
       1     0.002299  0.000192 -0.000708   False  
       2     0.002300  0.000192 -0.000707   False  
       3     0.002300  0.000192 -0.000707   False  
       4     0.002300  0.000192 -0.000707   False  
       ...        ...       ...       ...     ...  
       5665  0.002188  0.000178 -0.000327   False  
       5666  0.002188  0.000178 -0.000327   False  
       5667  0.002189  0.000178 -0.000327   False  
       5668  0.002189  0.000178 -0.000327   False  
       5669  0.002189  0.000178 -0.000327   False  
       
       [5670 rows x 15 columns],
       'Density':          Time  TimePos  TimeNeg      Flux   FluxPos   FluxNeg  \
       0     -7.7338    0.002   -0.002 -0.000994  0.001303 -0.001303   
       1     -7.7298    0.002   -0.002  0.000983  0.000928 -0.000928   
       2     -7.7258    0.002   -0.002  0.002517  0.001129 -0.001129   
       3     -7.7218    0.002   -0.002  0.001310  0.000983 -0.000983   
       4     -7.7178    0.002   -0.002 -0.002328  0.001138 -0.001138   
       ...       ...      ...      ...       ...       ...       ...   
       5665  14.9262    0.002   -0.002 -0.002157  0.001491 -0.001491   
       5666  14.9302    0.002   -0.002  0.000960  0.001248 -0.001248   
       5667  14.9342    0.002   -0.002  0.001450  0.001656 -0.001656   
       5668  14.9382    0.002   -0.002 -0.000708  0.001240 -0.001240   
       5669  14.9422    0.002   -0.002 -0.001227  0.001721 -0.001721   
       
             FluxPosWithECFErr  FluxNegWithECFErr     Gamma  GammaPos  GammaNeg  \
       0           -190.661533           0.001367  1.235877  5.328021 -0.611289   
       1            188.477401          -0.001014  1.235701  5.325119 -0.611037   
       2            482.236450          -0.001539  1.235525  5.322216 -0.610784   
       3            250.811436          -0.001124  1.235350  5.319314 -0.610531   
       4           -445.509329           0.001493  1.235174  5.316412 -0.610279   
       ...                 ...                ...       ...       ...       ...   
       5665          -0.002636           0.001652  1.530824  0.451665 -0.322449   
       5666           0.001580          -0.001288  1.530701  0.451737 -0.322467   
       5667           0.002209          -0.001724  1.530578  0.451809 -0.322485   
       5668          -0.001431           0.001262  1.530455  0.451881 -0.322504   
       5669          -0.002120           0.001768  1.530331  0.451953 -0.322522   
       
                  ECF      ECFPos    ECFNeg  BadBin  
       0     0.004436  850.837038 -0.001844    True  
       1     0.004435  850.170305 -0.001843    True  
       2     0.004434  849.503819 -0.001843    True  
       3     0.004433  848.837620 -0.001842    True  
       4     0.004431  848.171669 -0.001841    True  
       ...        ...         ...       ...     ...  
       5665  0.006786    0.006837 -0.002236   False  
       5666  0.006785    0.006839 -0.002236   False  
       5667  0.006784    0.006840 -0.002235   False  
       5668  0.006783    0.006842 -0.002235   False  
       5669  0.006782    0.006844 -0.002235   False  
       
       [5670 rows x 15 columns],
       'XRTBand':          Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0     -7.7338    0.002   -0.002 -3.326698e-08  4.361709e-08 -4.361709e-08   
       1     -7.7298    0.002   -0.002  3.289665e-08  3.106857e-08 -3.106857e-08   
       2     -7.7258    0.002   -0.002  8.419661e-08  3.777267e-08 -3.777267e-08   
       3     -7.7218    0.002   -0.002  4.380505e-08  3.289249e-08 -3.289249e-08   
       4     -7.7178    0.002   -0.002 -7.783522e-08  3.804320e-08 -3.804320e-08   
       ...       ...      ...      ...           ...           ...           ...   
       5665  14.9262    0.002   -0.002 -9.671196e-08  6.686047e-08 -6.686047e-08   
       5666  14.9302    0.002   -0.002  4.304651e-08  5.595550e-08 -5.595550e-08   
       5667  14.9342    0.002   -0.002  6.500725e-08  7.422043e-08 -7.422043e-08   
       5668  14.9382    0.002   -0.002 -3.173981e-08  5.558682e-08 -5.558682e-08   
       5669  14.9422    0.002   -0.002 -5.499880e-08  7.711616e-08 -7.711616e-08   
       
             FluxPosWithECFErr  FluxNegWithECFErr     Gamma  GammaPos  GammaNeg  \
       0         -2.053537e+21       4.667316e-08  1.235877  5.328021 -0.611289   
       1          2.029565e+21      -3.514335e-08  1.235701  5.325119 -0.611037   
       2          5.191680e+21      -5.651529e-08  1.235525  5.322216 -0.610784   
       3          2.699600e+21      -3.949965e-08  1.235350  5.319314 -0.610531   
       4         -4.794167e+21       5.438071e-08  1.235174  5.316412 -0.610279   
       ...                 ...                ...       ...       ...       ...   
       5665      -4.956858e-07       8.218201e-08  1.530824  0.451665 -0.322449   
       5666       2.257644e-07      -5.986119e-08  1.530701  0.451737 -0.322467   
       5667       3.386964e-07      -8.087118e-08  1.530578  0.451809 -0.322485   
       5668      -1.707303e-07       5.775598e-08  1.530455  0.451881 -0.322504   
       5669      -2.902893e-07       8.176197e-08  1.530331  0.451953 -0.322522   
       
                      ECF        ECFPos        ECFNeg  BadBin  
       0     1.484556e-07  9.164016e+21 -7.412848e-08    True  
       1     1.483878e-07  9.154816e+21 -7.409123e-08    True  
       2     1.483201e-07  9.145621e+21 -7.405400e-08    True  
       3     1.482523e-07  9.136434e+21 -7.401680e-08    True  
       4     1.481846e-07  9.127253e+21 -7.397963e-08    True  
       ...            ...           ...           ...     ...  
       5665  3.042476e-07  1.545135e-06 -1.503326e-07   False  
       5666  3.041515e-07  1.545400e-06 -1.502750e-07   False  
       5667  3.040555e-07  1.545665e-06 -1.502175e-07   False  
       5668  3.039595e-07  1.545930e-06 -1.501600e-07   False  
       5669  3.038635e-07  1.546195e-06 -1.501026e-07   False  
       
       [5670 rows x 15 columns],
       'BATBand':          Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0     -7.7338    0.002   -0.002 -5.622115e-08  7.371283e-08 -7.371283e-08   
       1     -7.7298    0.002   -0.002  5.561781e-08  5.252711e-08 -5.252711e-08   
       2     -7.7258    0.002   -0.002  1.424074e-07  6.388749e-08 -6.388749e-08   
       3     -7.7218    0.002   -0.002  7.412047e-08  5.565583e-08 -5.565583e-08   
       4     -7.7178    0.002   -0.002 -1.317546e-07  6.439718e-08 -6.439718e-08   
       ...       ...      ...      ...           ...           ...           ...   
       5665  14.9262    0.002   -0.002 -8.856969e-08  6.123143e-08 -6.123143e-08   
       5666  14.9302    0.002   -0.002  3.943337e-08  5.125882e-08 -5.125882e-08   
       5667  14.9342    0.002   -0.002  5.956740e-08  6.800961e-08 -6.800961e-08   
       5668  14.9382    0.002   -0.002 -2.909190e-08  5.094946e-08 -5.094946e-08   
       5669  14.9422    0.002   -0.002 -5.042453e-08  7.070239e-08 -7.070239e-08   
       
             FluxPosWithECFErr  FluxNegWithECFErr     Gamma  GammaPos  GammaNeg  \
       0         -7.428898e-08       7.444711e-08  1.235877  5.328021 -0.611289   
       1          5.331538e-08      -5.353039e-08  1.235701  5.325119 -0.611037   
       2          6.803292e-08      -6.912880e-08  1.235525  5.322216 -0.610784   
       3          5.697093e-08      -5.732649e-08  1.235350  5.319314 -0.610531   
       4         -6.793310e-08       6.886992e-08  1.235174  5.316412 -0.610279   
       ...                 ...                ...       ...       ...       ...   
       5665      -6.211678e-08       6.187859e-08  1.530824  0.451665 -0.322449   
       5666       5.146969e-08      -5.141272e-08  1.530701  0.451737 -0.322467   
       5667       6.837228e-08      -6.827429e-08  1.530578  0.451809 -0.322485   
       5668      -5.106518e-08       5.103386e-08  1.530455  0.451881 -0.322504   
       5669      -7.095292e-08       7.088512e-08  1.530331  0.451953 -0.322522   
       
                      ECF        ECFPos        ECFNeg  BadBin  
       0     2.508898e-07  4.120826e-08 -4.654575e-08   False  
       1     2.508768e-07  4.120170e-08 -4.652955e-08   False  
       2     2.508638e-07  4.119515e-08 -4.651335e-08   False  
       3     2.508508e-07  4.118860e-08 -4.649716e-08   False  
       4     2.508378e-07  4.118206e-08 -4.648098e-08   False  
       ...            ...           ...           ...     ...  
       5665  2.786327e-07  3.287548e-08 -2.808014e-08   False  
       5666  2.786223e-07  3.288493e-08 -2.808569e-08   False  
       5667  2.786119e-07  3.289439e-08 -2.809125e-08   False  
       5668  2.786015e-07  3.290385e-08 -2.809682e-08   False  
       5669  2.785911e-07  3.291332e-08 -2.810239e-08   False  
       
       [5670 rows x 15 columns],
       'Datasets': ['ObservedFlux', 'Density', 'XRTBand', 'BATBand']},
      'TimeBins_64ms': {'ObservedFlux':         Time  TimePos  TimeNeg      Flux   FluxPos   FluxNeg  \
       0    -7.7338    0.032   -0.032 -0.000070  0.000140 -0.000140   
       1    -7.6698    0.032   -0.032 -0.000209  0.000140 -0.000140   
       2    -7.6058    0.032   -0.032  0.000041  0.000141 -0.000141   
       3    -7.5418    0.032   -0.032  0.000137  0.000135 -0.000135   
       4    -7.4778    0.032   -0.032  0.000092  0.000145 -0.000145   
       ..       ...      ...      ...       ...       ...       ...   
       350  14.6662    0.032   -0.032 -0.000082  0.000130 -0.000130   
       351  14.7302    0.032   -0.032 -0.000068  0.000138 -0.000138   
       352  14.7942    0.032   -0.032  0.000139  0.000136 -0.000136   
       353  14.8582    0.032   -0.032  0.000191  0.000129 -0.000129   
       354  14.9222    0.032   -0.032 -0.000102  0.000195 -0.000195   
       
            FluxPosWithECFErr  FluxNegWithECFErr     Gamma  GammaPos  GammaNeg  \
       0            -0.000141           0.000142  1.235877  5.328021 -0.611289   
       1            -0.000141           0.000154  1.233067  5.281586 -0.607252   
       2             0.000141          -0.000141  1.230258  5.235155 -0.603229   
       3             0.000136          -0.000141  1.227448  5.188727 -0.599221   
       4             0.000145          -0.000148  1.224639  5.142302 -0.595227   
       ..                 ...                ...       ...       ...       ...   
       350          -0.000130           0.000130  1.538837  0.447193 -0.321392   
       351          -0.000138           0.000138  1.536865  0.448258 -0.321628   
       352           0.000137          -0.000138  1.534892  0.449346 -0.321880   
       353           0.000130          -0.000133  1.532920  0.450458 -0.322148   
       354          -0.000195           0.000195  1.530948  0.451593 -0.322431   
       
                 ECF    ECFPos    ECFNeg  BadBin  
       0    0.002299  0.000193 -0.000708   False  
       1    0.002301  0.000191 -0.000703   False  
       2    0.002303  0.000190 -0.000697   False  
       3    0.002305  0.000188 -0.000692   False  
       4    0.002306  0.000186 -0.000686   False  
       ..        ...       ...       ...     ...  
       350  0.002184  0.000181 -0.000327   False  
       351  0.002185  0.000180 -0.000327   False  
       352  0.002186  0.000180 -0.000327   False  
       353  0.002187  0.000179 -0.000327   False  
       354  0.002188  0.000178 -0.000327   False  
       
       [355 rows x 15 columns],
       'Density':         Time  TimePos  TimeNeg      Flux   FluxPos   FluxNeg  \
       0    -7.7338    0.032   -0.032 -0.000135  0.000271 -0.000271   
       1    -7.6698    0.032   -0.032 -0.000402  0.000268 -0.000268   
       2    -7.6058    0.032   -0.032  0.000077  0.000269 -0.000269   
       3    -7.5418    0.032   -0.032  0.000260  0.000257 -0.000257   
       4    -7.4778    0.032   -0.032  0.000175  0.000275 -0.000275   
       ..       ...      ...      ...       ...       ...       ...   
       350  14.6662    0.032   -0.032 -0.000257  0.000407 -0.000407   
       351  14.7302    0.032   -0.032 -0.000214  0.000432 -0.000432   
       352  14.7942    0.032   -0.032  0.000434  0.000426 -0.000426   
       353  14.8582    0.032   -0.032  0.000594  0.000403 -0.000403   
       354  14.9222    0.032   -0.032 -0.000317  0.000604 -0.000604   
       
            FluxPosWithECFErr  FluxNegWithECFErr     Gamma  GammaPos  GammaNeg  \
       0           -25.977645           0.000277  1.235877  5.328021 -0.611289   
       1           -76.486542           0.000316  1.233067  5.281586 -0.607252   
       2            14.599251          -0.000271  1.230258  5.235155 -0.603229   
       3            48.604972          -0.000279  1.227448  5.188727 -0.599221   
       4            32.391449          -0.000284  1.224639  5.142302 -0.595227   
       ..                 ...                ...       ...       ...       ...   
       350          -0.000479           0.000416  1.538837  0.447193 -0.321392   
       351          -0.000481           0.000438  1.536865  0.448258 -0.321628   
       352           0.000607          -0.000449  1.534892  0.449346 -0.321880   
       353           0.000718          -0.000448  1.532920  0.450458 -0.322148   
       354          -0.000683           0.000613  1.530948  0.451593 -0.322431   
       
                 ECF      ECFPos    ECFNeg  BadBin  
       0    0.004436  850.837038 -0.001844    True  
       1    0.004419  840.201220 -0.001833    True  
       2    0.004402  829.633552 -0.001823    True  
       3    0.004386  819.133671 -0.001812    True  
       4    0.004369  808.701217 -0.001802    True  
       ..        ...         ...       ...     ...  
       350  0.006861    0.006739 -0.002256   False  
       351  0.006842    0.006763 -0.002251   False  
       352  0.006824    0.006787 -0.002246   False  
       353  0.006806    0.006811 -0.002241   False  
       354  0.006787    0.006836 -0.002236   False  
       
       [355 rows x 15 columns],
       'XRTBand':         Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0    -7.7338    0.032   -0.032 -4.532628e-09  9.063488e-09 -9.063488e-09   
       1    -7.6698    0.032   -0.032 -1.341603e-08  8.952682e-09 -8.952682e-09   
       2    -7.6058    0.032   -0.032  2.574496e-09  8.942196e-09 -8.942196e-09   
       3    -7.5418    0.032   -0.032  8.617862e-09  8.522325e-09 -8.522325e-09   
       4    -7.4778    0.032   -0.032  5.774861e-09  9.060947e-09 -9.060947e-09   
       ..       ...      ...      ...           ...           ...           ...   
       350  14.6662    0.032   -0.032 -1.164790e-08  1.843937e-08 -1.843937e-08   
       351  14.7302    0.032   -0.032 -9.657805e-09  1.952609e-08 -1.952609e-08   
       352  14.7942    0.032   -0.032  1.956761e-08  1.918717e-08 -1.918717e-08   
       353  14.8582    0.032   -0.032  2.670599e-08  1.810997e-08 -1.810997e-08   
       354  14.9222    0.032   -0.032 -1.420759e-08  2.706349e-08 -2.706349e-08   
       
            FluxPosWithECFErr  FluxNegWithECFErr     Gamma  GammaPos  GammaNeg  \
       0        -2.797945e+20       9.341801e-09  1.235877  5.328021 -0.611289   
       1        -8.209032e+20       1.117870e-08  1.233067  5.281586 -0.607252   
       2         1.561367e+20      -9.033871e-09  1.230258  5.235155 -0.603229   
       3         5.179914e+20      -9.543149e-09  1.227448  5.188727 -0.599221   
       4         3.439851e+20      -9.506404e-09  1.224639  5.142302 -0.595227   
       ..                 ...                ...       ...       ...       ...   
       350      -6.018774e-08       1.932472e-08  1.538837  0.447193 -0.321392   
       351      -5.171057e-08       2.010469e-08  1.536865  0.448258 -0.321628   
       352       9.964669e-08      -2.149556e-08  1.534892  0.449346 -0.321880   
       353       1.357192e-07      -2.241663e-08  1.532920  0.450458 -0.322148   
       354      -7.702946e-08       2.795928e-08  1.530948  0.451593 -0.322431   
       
                     ECF        ECFPos        ECFNeg  BadBin  
       0    1.484556e-07  9.164016e+21 -7.412848e-08    True  
       1    1.473745e-07  9.017585e+21 -7.353585e-08    True  
       2    1.463012e-07  8.872800e+21 -7.295060e-08    True  
       3    1.452358e-07  8.729646e+21 -7.237263e-08    True  
       4    1.441781e-07  8.588106e+21 -7.180186e-08    True  
       ..            ...           ...           ...     ...  
       350  3.105571e-07  1.527566e-06 -1.541665e-07   False  
       351  3.089919e-07  1.531947e-06 -1.532059e-07   False  
       352  3.074347e-07  1.536292e-06 -1.522564e-07   False  
       353  3.058853e-07  1.540600e-06 -1.513178e-07   False  
       354  3.043437e-07  1.544869e-06 -1.503902e-07   False  
       
       [355 rows x 15 columns],
       'BATBand':         Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0    -7.7338    0.032   -0.032 -7.660135e-09  1.531728e-08 -1.531728e-08   
       1    -7.6698    0.032   -0.032 -2.282045e-08  1.522836e-08 -1.522836e-08   
       2    -7.6058    0.032   -0.032  4.407639e-09  1.530939e-08 -1.530939e-08   
       3    -7.5418    0.032   -0.032  1.485002e-08  1.468539e-08 -1.468539e-08   
       4    -7.4778    0.032   -0.032  1.001573e-08  1.571502e-08 -1.571502e-08   
       ..       ...      ...      ...           ...           ...           ...   
       350  14.6662    0.032   -0.032 -1.047591e-08  1.658404e-08 -1.658404e-08   
       351  14.7302    0.032   -0.032 -8.724842e-09  1.763983e-08 -1.763983e-08   
       352  14.7942    0.032   -0.032  1.775628e-08  1.741105e-08 -1.741105e-08   
       353  14.8582    0.032   -0.032  2.434208e-08  1.650695e-08 -1.650695e-08   
       354  14.9222    0.032   -0.032 -1.300782e-08  2.477809e-08 -2.477809e-08   
       
            FluxPosWithECFErr  FluxNegWithECFErr     Gamma  GammaPos  GammaNeg  \
       0        -1.536887e-08       1.538307e-08  1.235877  5.328021 -0.611289   
       1        -1.568134e-08       1.580058e-08  1.233067  5.281586 -0.607252   
       2         1.532639e-08      -1.533081e-08  1.230258  5.235155 -0.603229   
       3         1.488459e-08      -1.493449e-08  1.227448  5.188727 -0.599221   
       4         1.579977e-08      -1.582045e-08  1.224639  5.142302 -0.595227   
       ..                 ...                ...       ...       ...       ...   
       350      -1.662815e-08       1.661662e-08  1.538837  0.447193 -0.321392   
       351      -1.766891e-08       1.766124e-08  1.536865  0.448258 -0.321628   
       352       1.753400e-08      -1.750137e-08  1.534892  0.449346 -0.321880   
       353       1.675225e-08      -1.668681e-08  1.532920  0.450458 -0.322148   
       354      -2.482554e-08       2.481272e-08  1.530948  0.451593 -0.322431   
       
                     ECF        ECFPos        ECFNeg  BadBin  
       0    2.508898e-07  4.120826e-08 -4.654575e-08   False  
       1    2.506816e-07  4.110412e-08 -4.628743e-08   False  
       2    2.504735e-07  4.100173e-08 -4.603113e-08   False  
       3    2.502656e-07  4.090110e-08 -4.577687e-08   False  
       4    2.500578e-07  4.080224e-08 -4.552466e-08   False  
       ..            ...           ...           ...     ...  
       350  2.793094e-07  3.227242e-08 -2.773030e-08   False  
       351  2.791427e-07  3.241873e-08 -2.781434e-08   False  
       352  2.789761e-07  3.256645e-08 -2.789975e-08   False  
       353  2.788095e-07  3.271556e-08 -2.798650e-08   False  
       354  2.786431e-07  3.286603e-08 -2.807459e-08   False  
       
       [355 rows x 15 columns],
       'Datasets': ['ObservedFlux', 'Density', 'XRTBand', 'BATBand']},
      'TimeBins_1s': {'ObservedFlux':        Time  TimePos  TimeNeg      Flux   FluxPos   FluxNeg  \
       0   -7.7338      0.5     -0.5  0.000046  0.000035 -0.000035   
       1   -6.7338      0.5     -0.5 -0.000006  0.000034 -0.000034   
       2   -5.7338      0.5     -0.5 -0.000015  0.000035 -0.000035   
       3   -4.7338      0.5     -0.5  0.000029  0.000035 -0.000035   
       4   -3.7338      0.5     -0.5 -0.000019  0.000036 -0.000036   
       5   -2.7338      0.5     -0.5 -0.000013  0.000037 -0.000037   
       6   -1.7338      0.5     -0.5  0.000103  0.000038 -0.000038   
       7   -0.7338      0.5     -0.5  0.003187  0.000079 -0.000079   
       8    0.2662      0.5     -0.5  0.006912  0.000105 -0.000105   
       9    1.2662      0.5     -0.5  0.002293  0.000068 -0.000068   
       10   2.2662      0.5     -0.5  0.001340  0.000051 -0.000051   
       11   3.2662      0.5     -0.5  0.000914  0.000050 -0.000050   
       12   4.2662      0.5     -0.5  0.000563  0.000040 -0.000040   
       13   5.2662      0.5     -0.5  0.002821  0.000064 -0.000064   
       14   6.2662      0.5     -0.5  0.003153  0.000074 -0.000074   
       15   7.2662      0.5     -0.5  0.000783  0.000047 -0.000047   
       16   8.2662      0.5     -0.5  0.000326  0.000037 -0.000037   
       17   9.2662      0.5     -0.5  0.000114  0.000034 -0.000034   
       18  10.2662      0.5     -0.5  0.000156  0.000034 -0.000034   
       19  11.2662      0.5     -0.5  0.000033  0.000033 -0.000033   
       20  12.2662      0.5     -0.5  0.000040  0.000033 -0.000033   
       21  13.2662      0.5     -0.5  0.000053  0.000033 -0.000033   
       22  14.2662      0.5     -0.5  0.000013  0.000040 -0.000040   
       
           FluxPosWithECFErr  FluxNegWithECFErr     Gamma  GammaPos  GammaNeg  \
       0            0.000035          -0.000038  1.235877  5.328021 -0.611289   
       1           -0.000034           0.000034  1.191980  4.602883 -0.549965   
       2           -0.000035           0.000035  1.148083  3.878905 -0.493272   
       3            0.000035          -0.000036  1.104187  3.156887 -0.442991   
       4           -0.000036           0.000037  1.060290  2.438569 -0.401539   
       5           -0.000037           0.000037  1.016394  1.728570 -0.371880   
       6            0.000038          -0.000039  0.972497  1.044003 -0.356965   
       7            0.000085          -0.000249  0.928600  0.502576 -0.358639   
       8            0.000275          -0.000714  1.003007  0.401811 -0.304112   
       9            0.000087          -0.000086  0.626309  0.311880 -0.250262   
       10           0.000154          -0.000242  1.605018  0.474389 -0.365632   
       11           0.000058          -0.000093  1.163939  0.369900 -0.291905   
       12           0.000079          -0.000115  1.653664  0.478428 -0.359308   
       13           0.000288          -0.000481  1.679815  0.447852 -0.337402   
       14           0.000099          -0.000197  1.046960  0.321528 -0.268678   
       15           0.000058          -0.000095  1.194844  0.433646 -0.345016   
       16           0.000045          -0.000055  1.664062  0.340073 -0.266703   
       17           0.000036          -0.000039  1.705250  0.452209 -0.355753   
       18           0.000038          -0.000042  1.674433  0.437022 -0.341857   
       19           0.000033          -0.000034  1.643615  0.428069 -0.331090   
       20           0.000033          -0.000033  1.612798  0.425741 -0.323762   
       21           0.000033          -0.000034  1.581981  0.430148 -0.320111   
       22           0.000040          -0.000040  1.551164  0.441086 -0.320263   
       
                ECF    ECFPos    ECFNeg  BadBin  
       0   0.002299  0.000193 -0.000708   False  
       1   0.002326  0.000168 -0.000623   False  
       2   0.002353  0.000144 -0.000536   False  
       3   0.002381  0.000119 -0.000450   False  
       4   0.002408  0.000093 -0.000365   False  
       5   0.002436  0.000068 -0.000285   False  
       6   0.002465  0.000043 -0.000218   False  
       7   0.002494  0.000025 -0.000184   False  
       8   0.002437  0.000090 -0.000249   False  
       9   0.002520  0.000060 -0.000057   False  
       10  0.002143  0.000232 -0.000379   False  
       11  0.002419  0.000075 -0.000206   False  
       12  0.002091  0.000253 -0.000400   False  
       13  0.002118  0.000210 -0.000358   False  
       14  0.002461  0.000051 -0.000142   False  
       15  0.002408  0.000105 -0.000255   False  
       16  0.002127  0.000168 -0.000267   False  
       17  0.002095  0.000234 -0.000360   False  
       18  0.002111  0.000225 -0.000348   False  
       19  0.002127  0.000215 -0.000338   False  
       20  0.002144  0.000205 -0.000331   False  
       21  0.002161  0.000195 -0.000327   False  
       22  0.002177  0.000185 -0.000326   False  ,
       'Density':        Time  TimePos  TimeNeg      Flux   FluxPos   FluxNeg  \
       0   -7.7338      0.5     -0.5  0.000089  0.000067 -0.000067   
       1   -6.7338      0.5     -0.5 -0.000011  0.000061 -0.000061   
       2   -5.7338      0.5     -0.5 -0.000024  0.000059 -0.000059   
       3   -4.7338      0.5     -0.5  0.000045  0.000055 -0.000055   
       4   -3.7338      0.5     -0.5 -0.000028  0.000053 -0.000053   
       5   -2.7338      0.5     -0.5 -0.000018  0.000050 -0.000050   
       6   -1.7338      0.5     -0.5  0.000130  0.000048 -0.000048   
       7   -0.7338      0.5     -0.5  0.003749  0.000093 -0.000093   
       8    0.2662      0.5     -0.5  0.009166  0.000139 -0.000139   
       9    1.2662      0.5     -0.5  0.001658  0.000049 -0.000049   
       10   2.2662      0.5     -0.5  0.004682  0.000177 -0.000177   
       11   3.2662      0.5     -0.5  0.001570  0.000086 -0.000086   
       12   4.2662      0.5     -0.5  0.002127  0.000150 -0.000150   
       13   5.2662      0.5     -0.5  0.011120  0.000253 -0.000253   
       14   6.2662      0.5     -0.5  0.004488  0.000105 -0.000105   
       15   7.2662      0.5     -0.5  0.001415  0.000085 -0.000085   
       16   8.2662      0.5     -0.5  0.001251  0.000142 -0.000142   
       17   9.2662      0.5     -0.5  0.000469  0.000139 -0.000139   
       18  10.2662      0.5     -0.5  0.000608  0.000132 -0.000132   
       19  11.2662      0.5     -0.5  0.000122  0.000124 -0.000124   
       20  12.2662      0.5     -0.5  0.000140  0.000116 -0.000116   
       21  13.2662      0.5     -0.5  0.000179  0.000110 -0.000110   
       22  14.2662      0.5     -0.5  0.000042  0.000129 -0.000129   
       
           FluxPosWithECFErr  FluxNegWithECFErr     Gamma  GammaPos  GammaNeg  \
       0           17.126553          -0.000077  1.235877  5.328021 -0.611289   
       1           -1.753139           0.000061  1.191980  4.602883 -0.549965   
       2           -3.411058           0.000060  1.148083  3.878905 -0.493272   
       3            5.140743          -0.000058  1.104187  3.156887 -0.442991   
       4           -2.437518           0.000054  1.060290  2.438569 -0.401539   
       5           -1.073694           0.000050  1.016394  1.728570 -0.371880   
       6            4.456464          -0.000072  0.972497  1.044003 -0.356965   
       7           30.104140          -0.001620  0.928600  0.502576 -0.358639   
       8            0.007386          -0.003135  1.003007  0.401811 -0.304112   
       9            0.001157          -0.000528  0.626309  0.311880 -0.250262   
       10           0.003675          -0.001780  1.605018  0.474389 -0.365632   
       11           0.001113          -0.000537  1.163939  0.369900 -0.291905   
       12           0.001676          -0.000777  1.653664  0.478428 -0.359308   
       13           0.008405          -0.003825  1.679815  0.447852 -0.337402   
       14           0.002657          -0.001498  1.046960  0.321528 -0.268678   
       15           0.001142          -0.000570  1.194844  0.433646 -0.345016   
       16           0.000706          -0.000378  1.664062  0.340073 -0.266703   
       17           0.000366          -0.000223  1.705250  0.452209 -0.355753   
       18           0.000457          -0.000253  1.674433  0.437022 -0.341857   
       19           0.000153          -0.000131  1.643615  0.428069 -0.331090   
       20           0.000161          -0.000125  1.612798  0.425741 -0.323762   
       21           0.000189          -0.000125  1.581981  0.430148 -0.320111   
       22           0.000135          -0.000130  1.551164  0.441086 -0.320263   
       
                ECF      ECFPos    ECFNeg  BadBin  
       0   0.004436  850.837038 -0.001844    True  
       1   0.004181  692.253674 -0.001692    True  
       2   0.003941  549.063307 -0.001568    True  
       3   0.003715  420.021836 -0.001470    True  
       4   0.003502  303.977234 -0.001394    True  
       5   0.003301  199.863085 -0.001337    True  
       6   0.003112  106.692547 -0.001295    True  
       7   0.002933   23.552735 -0.001265    True  
       8   0.003232    0.002604 -0.001104   False  
       9   0.001823    0.001271 -0.000578   False  
       10  0.007489    0.005872 -0.002833   False  
       11  0.004156    0.002937 -0.001403   False  
       12  0.007904    0.006204 -0.002833   False  
       13  0.008347    0.006306 -0.002865   False  
       14  0.003503    0.002072 -0.001166   False  
       15  0.004348    0.003500 -0.001731   False  
       16  0.008174    0.004518 -0.002285   False  
       17  0.008601    0.006218 -0.003186   False  
       18  0.008249    0.005935 -0.002933   False  
       19  0.007910    0.005878 -0.002718   False  
       20  0.007586    0.006003 -0.002541   False  
       21  0.007275    0.006257 -0.002400   False  
       22  0.006976    0.006591 -0.002291   False  ,
       'XRTBand':        Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0   -7.7338      0.5     -0.5  2.988273e-09  2.253240e-09 -2.253240e-09   
       1   -6.7338      0.5     -0.5 -3.353887e-10  1.929993e-09 -1.929993e-09   
       2   -5.7338      0.5     -0.5 -7.339470e-10  1.770408e-09 -1.770408e-09   
       3   -4.7338      0.5     -0.5  1.289890e-09  1.557999e-09 -1.557999e-09   
       4   -3.7338      0.5     -0.5 -7.538866e-10  1.424345e-09 -1.424345e-09   
       5   -2.7338      0.5     -0.5 -4.505549e-10  1.258223e-09 -1.258223e-09   
       6   -1.7338      0.5     -0.5  3.125049e-09  1.152511e-09 -1.152511e-09   
       7   -0.7338      0.5     -0.5  8.530726e-08  2.117793e-09 -2.117793e-09   
       8    0.2662      0.5     -0.5  2.280932e-07  3.462764e-09 -3.462764e-09   
       9    1.2662      0.5     -0.5  2.976779e-08  8.829498e-10 -8.829498e-10   
       10   2.2662      0.5     -0.5  2.299791e-07  8.689633e-09 -8.689633e-09   
       11   3.2662      0.5     -0.5  4.438831e-08  2.437017e-09 -2.437017e-09   
       12   4.2662      0.5     -0.5  1.148845e-07  8.091245e-09 -8.091245e-09   
       13   5.2662      0.5     -0.5  5.889478e-07  1.339230e-08 -1.339230e-08   
       14   6.2662      0.5     -0.5  1.134020e-07  2.656299e-09 -2.656299e-09   
       15   7.2662      0.5     -0.5  4.119126e-08  2.460878e-09 -2.460878e-09   
       16   8.2662      0.5     -0.5  6.493691e-08  7.382740e-09 -7.382740e-09   
       17   9.2662      0.5     -0.5  2.592106e-08  7.711415e-09 -7.711415e-09   
       18  10.2662      0.5     -0.5  3.240829e-08  7.016968e-09 -7.016968e-09   
       19  11.2662      0.5     -0.5  6.266765e-09  6.351897e-09 -6.351897e-09   
       20  12.2662      0.5     -0.5  6.920742e-09  5.758319e-09 -5.758319e-09   
       21  13.2662      0.5     -0.5  8.547823e-09  5.242140e-09 -5.242140e-09   
       22  14.2662      0.5     -0.5  1.907846e-09  5.921244e-09 -5.921244e-09   
       
           FluxPosWithECFErr  FluxNegWithECFErr     Gamma  GammaPos  GammaNeg  \
       0        1.844631e+20      -2.702510e-09  1.235877  5.328021 -0.611289   
       1       -1.786940e+19       1.937144e-09  1.191980  4.602883 -0.549965   
       2       -3.290311e+19       1.807580e-09  1.148083  3.878905 -0.493272   
       3        4.692754e+19      -1.687427e-09  1.104187  3.156887 -0.442991   
       4       -2.105736e+19       1.475795e-09  1.060290  2.438569 -0.401539   
       5       -8.777901e+18       1.280384e-09  1.016394  1.728570 -0.371880   
       6        3.447902e+19      -2.054586e-09  0.972497  1.044003 -0.356965   
       7        2.204169e+20      -4.829320e-08  0.928600  0.502576 -0.358639   
       8        5.535079e-07      -1.047661e-07  1.003007  0.401811 -0.304112   
       9        3.895098e-08      -1.186646e-08  0.626309  0.311880 -0.250262   
       10       7.308950e-07      -1.369334e-07  1.605018  0.474389 -0.365632   
       11       8.028276e-08      -2.072978e-08  1.163939  0.369900 -0.291905   
       12       4.460844e-07      -6.608023e-08  1.653664  0.478428 -0.359308   
       13       1.974566e-06      -3.129534e-07  1.679815  0.447852 -0.337402   
       14       1.417738e-07      -5.234137e-08  1.046960  0.321528 -0.268678   
       15       8.607769e-08      -2.307266e-08  1.194844  0.433646 -0.345016   
       16       1.364116e-07      -2.981314e-08  1.664062  0.340073 -0.266703   
       17       7.406778e-08      -1.737075e-08  1.705250  0.452209 -0.355753   
       18       9.533371e-08      -1.989147e-08  1.674433  0.437022 -0.341857   
       19       2.104697e-08      -7.229412e-09  1.643615  0.428069 -0.331090   
       20       2.562185e-08      -6.829269e-09  1.612798  0.425741 -0.323762   
       21       3.551975e-08      -6.837769e-09  1.581981  0.430148 -0.320111   
       22       1.071069e-08      -5.997750e-09  1.551164  0.441086 -0.320263   
       
                    ECF        ECFPos        ECFNeg  BadBin  
       0   1.484556e-07  9.164016e+21 -7.412848e-08    True  
       1   1.324333e-07  7.056005e+21 -6.566587e-08    True  
       2   1.181403e-07  5.296271e+21 -5.870293e-08    True  
       3   1.053898e-07  3.834192e+21 -5.295364e-08    True  
       4   9.401545e-08  2.626015e+21 -4.817198e-08    True  
       5   8.386869e-08  1.633965e+21 -4.415105e-08    True  
       6   7.481704e-08  8.254647e+20 -4.072122e-08    True  
       7   6.674229e-08  1.724487e+20 -3.774706e-08    True  
       8   8.043180e-08  1.951779e-07 -3.692316e-08   False  
       9   3.272213e-08  4.280571e-08 -1.300800e-08   False  
       10  3.678602e-07  1.169011e-06 -2.185887e-07   False  
       11  1.174739e-07  2.123709e-07 -5.448105e-08   False  
       12  4.268622e-07  1.657189e-06 -2.436787e-07   False  
       13  4.420563e-07  1.482049e-06 -2.346834e-07   False  
       14  8.850906e-08  1.106335e-07 -4.079925e-08   False  
       15  1.265897e-07  2.644273e-07 -7.050282e-08   False  
       16  4.243347e-07  8.900848e-07 -1.887482e-07   False  
       17  4.756472e-07  1.351745e-06 -2.856197e-07   False  
       18  4.395407e-07  1.289466e-06 -2.524366e-07   False  
       19  4.061751e-07  1.300535e-06 -2.237525e-07   False  
       20  3.753422e-07  1.354037e-06 -1.991272e-07   False  
       21  3.468499e-07  1.425522e-06 -1.781492e-07   False  
       22  3.205205e-07  1.499431e-06 -1.604278e-07   False  ,
       'BATBand':        Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0   -7.7338      0.5     -0.5  5.050177e-09  3.807972e-09 -3.807972e-09   
       1   -6.7338      0.5     -0.5 -6.271901e-10  3.609163e-09 -3.609163e-09   
       2   -5.7338      0.5     -0.5 -1.518727e-09  3.663435e-09 -3.663435e-09   
       3   -4.7338      0.5     -0.5  2.953466e-09  3.567357e-09 -3.567357e-09   
       4   -3.7338      0.5     -0.5 -1.910072e-09  3.608769e-09 -3.608769e-09   
       5   -2.7338      0.5     -0.5 -1.263152e-09  3.527490e-09 -3.527490e-09   
       6   -1.7338      0.5     -0.5  9.694585e-09  3.575342e-09 -3.575342e-09   
       7   -0.7338      0.5     -0.5  2.928348e-07  7.269762e-09 -7.269762e-09   
       8    0.2662      0.5     -0.5  6.625693e-07  1.005870e-08 -1.005870e-08   
       9    1.2662      0.5     -0.5  1.822238e-07  5.404987e-09 -5.404987e-09   
       10   2.2662      0.5     -0.5  1.778548e-07  6.720146e-09 -6.720146e-09   
       11   3.2662      0.5     -0.5  9.469965e-08  5.199221e-09 -5.199221e-09   
       12   4.2662      0.5     -0.5  7.712477e-08  5.431853e-09 -5.431853e-09   
       13   5.2662      0.5     -0.5  3.893857e-07  8.854381e-09 -8.854381e-09   
       14   6.2662      0.5     -0.5  3.075332e-07  7.203579e-09 -7.203579e-09   
       15   7.2662      0.5     -0.5  8.247405e-08  4.927225e-09 -4.927225e-09   
       16   8.2662      0.5     -0.5  4.453519e-08  5.063249e-09 -5.063249e-09   
       17   9.2662      0.5     -0.5  1.600788e-08  4.762281e-09 -4.762281e-09   
       18  10.2662      0.5     -0.5  2.145710e-08  4.645841e-09 -4.645841e-09   
       19  11.2662      0.5     -0.5  4.448281e-09  4.508709e-09 -4.508709e-09   
       20  12.2662      0.5     -0.5  5.266661e-09  4.382061e-09 -4.382061e-09   
       21  13.2662      0.5     -0.5  6.973843e-09  4.276862e-09 -4.276862e-09   
       22  14.2662      0.5     -0.5  1.668760e-09  5.179210e-09 -5.179210e-09   
       
           FluxPosWithECFErr  FluxNegWithECFErr     Gamma  GammaPos  GammaNeg  \
       0        3.897268e-09      -3.921540e-09  1.235877  5.328021 -0.611289   
       1       -3.610569e-09       3.610786e-09  1.191980  4.602883 -0.549965   
       2       -3.671355e-09       3.671652e-09  1.148083  3.878905 -0.493272   
       3        3.597936e-09      -3.595880e-09  1.104187  3.156887 -0.442991   
       4       -3.621688e-09       3.619706e-09  1.060290  2.438569 -0.401539   
       5       -3.533510e-09       3.532207e-09  1.016394  1.728570 -0.371880   
       6        3.928944e-09      -3.841831e-09  0.972497  1.044003 -0.356965   
       7        5.155336e-08      -4.418030e-08  0.928600  0.502576 -0.358639   
       8        8.732617e-08      -7.613771e-08  1.003007  0.401811 -0.304112   
       9        2.732922e-08      -2.232397e-08  0.626309  0.311880 -0.250262   
       10       1.948271e-08      -1.879422e-08  1.605018  0.474389 -0.365632   
       11       1.268597e-08      -1.148999e-08  1.163939  0.369900 -0.291905   
       12       9.054098e-09      -8.876651e-09  1.653664  0.478428 -0.359308   
       13       3.776560e-08      -3.639503e-08  1.679815  0.447852 -0.337402   
       14       3.693468e-08      -3.323285e-08  1.046960  0.321528 -0.268678   
       15       1.242563e-08      -1.135395e-08  1.194844  0.433646 -0.345016   
       16       6.059650e-09      -5.991638e-09  1.664062  0.340073 -0.266703   
       17       5.001418e-09      -4.987258e-09  1.705250  0.452209 -0.355753   
       18       5.063124e-09      -5.030820e-09  1.674433  0.437022 -0.341857   
       19       4.528385e-09      -4.526110e-09  1.643615  0.428069 -0.331090   
       20       4.412564e-09      -4.407688e-09  1.612798  0.425741 -0.323762   
       21       4.338143e-09      -4.325589e-09  1.581981  0.430148 -0.320111   
       22       5.182580e-09      -5.181747e-09  1.551164  0.441086 -0.320263   
       
                    ECF        ECFPos        ECFNeg  BadBin  
       0   2.508898e-07  4.120826e-08 -4.654575e-08   False  
       1   2.476555e-07  3.978350e-08 -4.275010e-08   False  
       2   2.444629e-07  3.879634e-08 -3.951848e-08   False  
       3   2.413115e-07  3.824525e-08 -3.693157e-08   False  
       4   2.382007e-07  3.811542e-08 -3.506454e-08   False  
       5   2.351299e-07  3.837930e-08 -3.396981e-08   False  
       6   2.320988e-07  3.899921e-08 -3.365916e-08   False  
       7   2.291067e-07  3.993104e-08 -3.409442e-08   False  
       8   2.336397e-07  3.058859e-08 -2.661287e-08   False  
       9   2.003088e-07  2.944815e-08 -2.380942e-08   False  
       10  2.844855e-07  2.925079e-08 -2.807461e-08   False  
       11  2.506232e-07  3.062431e-08 -2.711706e-08   False  
       12  2.865631e-07  2.691465e-08 -2.608587e-08   False  
       13  2.922676e-07  2.755625e-08 -2.649685e-08   False  
       14  2.400265e-07  2.827354e-08 -2.532122e-08   False  
       15  2.534607e-07  3.505605e-08 -3.143629e-08   False  
       16  2.910183e-07  2.175420e-08 -2.093433e-08   False  
       17  2.937419e-07  2.803901e-08 -2.717649e-08   False  
       18  2.910140e-07  2.729885e-08 -2.617724e-08   False  
       19  2.883116e-07  2.733059e-08 -2.569871e-08   False  
       20  2.856342e-07  2.809018e-08 -2.574022e-08   False  
       21  2.829816e-07  2.948343e-08 -2.627126e-08   False  
       22  2.803537e-07  3.139176e-08 -2.723719e-08   False  ,
       'Datasets': ['ObservedFlux', 'Density', 'XRTBand', 'BATBand']},
      'TimeBins_10s': {'ObservedFlux':       Time  TimePos  TimeNeg      Flux   FluxPos   FluxNeg  FluxPosWithECFErr  \
       0  -7.7338      5.0     -5.0  0.001167  0.000017 -0.000017           0.000099   
       1   2.2662      5.0     -5.0  0.000966  0.000015 -0.000015           0.000106   
       2  12.2662      5.0     -5.0  0.000038  0.000020 -0.000020           0.000020   
       
          FluxNegWithECFErr     Gamma  GammaPos  GammaNeg       ECF    ECFPos  \
       0          -0.000360  1.235877  5.328021 -0.611289  0.002299  0.000193   
       1          -0.000171  1.605018  0.474389 -0.365632  0.002143  0.000232   
       2          -0.000021  1.612798  0.425741 -0.323762  0.002144  0.000205   
       
            ECFNeg  BadBin  
       0 -0.000708   False  
       1 -0.000379   False  
       2 -0.000331   False  ,
       'Density':       Time  TimePos  TimeNeg      Flux   FluxPos   FluxNeg  FluxPosWithECFErr  \
       0  -7.7338      5.0     -5.0  0.002251  0.000032 -0.000032         431.862232   
       1   2.2662      5.0     -5.0  0.003376  0.000051 -0.000051           0.002647   
       2  12.2662      5.0     -5.0  0.000133  0.000071 -0.000071           0.000127   
       
          FluxNegWithECFErr     Gamma  GammaPos  GammaNeg       ECF      ECFPos  \
       0          -0.000936  1.235877  5.328021 -0.611289  0.004436  850.837038   
       1          -0.001278  1.605018  0.474389 -0.365632  0.007489    0.005872   
       2          -0.000084  1.612798  0.425741 -0.323762  0.007586    0.006003   
       
            ECFNeg  BadBin  
       0 -0.001844    True  
       1 -0.002833   False  
       2 -0.002541   False  ,
       'XRTBand':       Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0  -7.7338      5.0     -5.0  7.535213e-08  1.067043e-09 -1.067043e-09   
       1   2.2662      5.0     -5.0  1.658238e-07  2.497401e-09 -2.497401e-09   
       2  12.2662      5.0     -5.0  6.601385e-09  3.491765e-09 -3.491765e-09   
       
          FluxPosWithECFErr  FluxNegWithECFErr     Gamma  GammaPos  GammaNeg  \
       0       4.651411e+21      -3.764077e-08  1.235877  5.328021 -0.611289   
       1       5.269722e-07      -9.856695e-08  1.605018  0.474389 -0.365632   
       2       2.406895e-08      -4.945471e-09  1.612798  0.425741 -0.323762   
       
                   ECF        ECFPos        ECFNeg  BadBin  
       0  1.484556e-07  9.164016e+21 -7.412848e-08    True  
       1  3.678602e-07  1.169011e-06 -2.185887e-07   False  
       2  3.753422e-07  1.354037e-06 -1.991272e-07   False  ,
       'BATBand':       Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0  -7.7338      5.0     -5.0  1.273450e-07  1.803301e-09 -1.803301e-09   
       1   2.2662      5.0     -5.0  1.282402e-07  1.931370e-09 -1.931370e-09   
       2  12.2662      5.0     -5.0  5.023632e-09  2.657222e-09 -2.657222e-09   
       
          FluxPosWithECFErr  FluxNegWithECFErr     Gamma  GammaPos  GammaNeg  \
       0       2.099381e-08      -2.369411e-08  1.235877  5.328021 -0.611289   
       1       1.332636e-08      -1.280198e-08  1.605018  0.474389 -0.365632   
       2       2.702758e-09      -2.695510e-09  1.612798  0.425741 -0.323762   
       
                   ECF        ECFPos        ECFNeg  BadBin  
       0  2.508898e-07  4.120826e-08 -4.654575e-08   False  
       1  2.844855e-07  2.925079e-08 -2.807461e-08   False  
       2  2.856342e-07  2.809018e-08 -2.574022e-08   False  ,
       'Datasets': ['ObservedFlux', 'Density', 'XRTBand', 'BATBand']},
      'Binning': ['SNR4',
       'SNR4_sinceT0',
       'SNR5',
       'SNR5_sinceT0',
       'SNR6',
       'SNR6_sinceT0',
       'SNR7',
       'SNR7_sinceT0',
       'TimeBins_4ms',
       'TimeBins_64ms',
       'TimeBins_1s',
       'TimeBins_10s']},
     'BAT_NoEvolution': {'ECFs': {'ObservedFlux': 0.00243424007095474,
       'Density': 0.00231776220799315,
       'XRTBand': 4.70354458026304e-08,
       'BATBand': 6.85253672780114e-07},
      'SNR4': {'ObservedFlux':         Time  TimePos  TimeNeg          Flux   FluxPos   FluxNeg  BadBin
       0   -167.808    23.88   -23.88 -3.831272e-06  0.000005 -0.000005    True
       1   -120.048    23.88   -23.88  4.552976e-07  0.000005 -0.000005    True
       2    -72.288    23.88   -23.88 -6.351962e-07  0.000005 -0.000005    True
       3    -24.528    23.88   -23.88  3.165754e-06  0.000005 -0.000005    True
       4     -0.588     0.06    -0.06  5.506982e-04  0.000136 -0.000136   False
       ..       ...      ...      ...           ...       ...       ...     ...
       216  775.732    20.74   -20.74 -9.372256e-07  0.000004 -0.000004    True
       217  817.212    20.74   -20.74 -2.185479e-06  0.000004 -0.000004    True
       218  858.692    20.74   -20.74  7.409107e-06  0.000004 -0.000004    True
       219  900.172    20.74   -20.74 -2.445578e-06  0.000004 -0.000004    True
       220  941.772    20.86   -20.86  4.121429e-07  0.000004 -0.000004    True
       
       [221 rows x 7 columns],
       'Density':         Time  TimePos  TimeNeg          Flux   FluxPos   FluxNeg  BadBin
       0   -167.808    23.88   -23.88 -3.647946e-06  0.000005 -0.000005    True
       1   -120.048    23.88   -23.88  4.335117e-07  0.000005 -0.000005    True
       2    -72.288    23.88   -23.88 -6.048022e-07  0.000005 -0.000005    True
       3    -24.528    23.88   -23.88  3.014273e-06  0.000005 -0.000005    True
       4     -0.588     0.06    -0.06  5.243474e-04  0.000130 -0.000130   False
       ..       ...      ...      ...           ...       ...       ...     ...
       216  775.732    20.74   -20.74 -8.923795e-07  0.000004 -0.000004    True
       217  817.212    20.74   -20.74 -2.080905e-06  0.000004 -0.000004    True
       218  858.692    20.74   -20.74  7.054583e-06  0.000004 -0.000004    True
       219  900.172    20.74   -20.74 -2.328557e-06  0.000004 -0.000004    True
       220  941.772    20.86   -20.86  3.924220e-07  0.000004 -0.000004    True
       
       [221 rows x 7 columns],
       'XRTBand':         Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0   -167.808    23.88   -23.88 -7.402950e-11  1.020133e-10 -1.020133e-10   
       1   -120.048    23.88   -23.88  8.797458e-12  1.019099e-10 -1.019099e-10   
       2    -72.288    23.88   -23.88 -1.227354e-11  1.016251e-10 -1.016251e-10   
       3    -24.528    23.88   -23.88  6.117007e-11  1.022816e-10 -1.022816e-10   
       4     -0.588     0.06    -0.06  1.064083e-08  2.628124e-09 -2.628124e-09   
       ..       ...      ...      ...           ...           ...           ...   
       216  775.732    20.74   -20.74 -1.810948e-11  8.541949e-11 -8.541949e-11   
       217  817.212    20.74   -20.74 -4.222878e-11  8.547517e-11 -8.547517e-11   
       218  858.692    20.74   -20.74  1.431620e-10  8.553423e-11 -8.553423e-11   
       219  900.172    20.74   -20.74 -4.725452e-11  8.554475e-11 -8.554475e-11   
       220  941.772    20.86   -20.86  7.963605e-12  8.536782e-11 -8.536782e-11   
       
            BadBin  
       0      True  
       1      True  
       2      True  
       3      True  
       4     False  
       ..      ...  
       216    True  
       217    True  
       218    True  
       219    True  
       220    True  
       
       [221 rows x 7 columns],
       'BATBand':         Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0   -215.568    23.88   -23.88  1.777774e-09  1.491150e-09 -1.491150e-09   
       1   -167.808    23.88   -23.88 -1.078527e-09  1.486219e-09 -1.486219e-09   
       2   -120.048    23.88   -23.88  1.281691e-10  1.484713e-09 -1.484713e-09   
       3    -72.288    23.88   -23.88 -1.788117e-10  1.480564e-09 -1.480564e-09   
       4    -24.528    23.88   -23.88  8.911793e-10  1.490128e-09 -1.490128e-09   
       ..       ...      ...      ...           ...           ...           ...   
       217  775.732    20.74   -20.74 -2.638348e-10  1.244466e-09 -1.244466e-09   
       218  817.212    20.74   -20.74 -6.152260e-10  1.245277e-09 -1.245277e-09   
       219  858.692    20.74   -20.74  2.085709e-09  1.246138e-09 -1.246138e-09   
       220  900.172    20.74   -20.74 -6.884453e-10  1.246291e-09 -1.246291e-09   
       221  941.772    20.86   -20.86  1.160208e-10  1.243713e-09 -1.243713e-09   
       
            BadBin  
       0      True  
       1      True  
       2      True  
       3      True  
       4      True  
       ..      ...  
       217    True  
       218    True  
       219    True  
       220    True  
       221    True  
       
       [222 rows x 7 columns],
       'Datasets': ['ObservedFlux', 'Density', 'XRTBand', 'BATBand']},
      'SNR4_sinceT0': {'ObservedFlux':         Time  TimePos  TimeNeg          Flux   FluxPos   FluxNeg  BadBin
       0      0.061     0.02    -0.02  5.361221e-03  0.000498 -0.000498   False
       1      0.101     0.02    -0.02  7.402844e-03  0.000556 -0.000556   False
       2      0.141     0.02    -0.02  5.912338e-03  0.000542 -0.000542   False
       3      0.181     0.02    -0.02  7.539487e-03  0.000553 -0.000553   False
       4      0.221     0.02    -0.02  7.634854e-03  0.000570 -0.000570   False
       ..       ...      ...      ...           ...       ...       ...     ...
       195  773.581    20.98   -20.98 -3.732727e-07  0.000004 -0.000004    True
       196  815.541    20.98   -20.98 -1.927412e-06  0.000004 -0.000004    True
       197  857.501    20.98   -20.98  7.066800e-06  0.000004 -0.000004    True
       198  899.461    20.98   -20.98 -3.284559e-06  0.000004 -0.000004    True
       199  941.541    21.10   -21.10  7.941329e-07  0.000004 -0.000004    True
       
       [200 rows x 7 columns],
       'Density':         Time  TimePos  TimeNeg          Flux   FluxPos   FluxNeg  BadBin
       0      0.061     0.02    -0.02  5.104688e-03  0.000474 -0.000474   False
       1      0.101     0.02    -0.02  7.048619e-03  0.000530 -0.000530   False
       2      0.141     0.02    -0.02  5.629434e-03  0.000516 -0.000516   False
       3      0.181     0.02    -0.02  7.178724e-03  0.000527 -0.000527   False
       4      0.221     0.02    -0.02  7.269528e-03  0.000543 -0.000543   False
       ..       ...      ...      ...           ...       ...       ...     ...
       195  773.581    20.98   -20.98 -3.554117e-07  0.000004 -0.000004    True
       196  815.541    20.98   -20.98 -1.835186e-06  0.000004 -0.000004    True
       197  857.501    20.98   -20.98  6.728655e-06  0.000004 -0.000004    True
       198  899.461    20.98   -20.98 -3.127394e-06  0.000004 -0.000004    True
       199  941.541    21.10   -21.10  7.561338e-07  0.000004 -0.000004    True
       
       [200 rows x 7 columns],
       'XRTBand':         Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0      0.061     0.02    -0.02  1.035919e-07  9.616825e-09 -9.616825e-09   
       1      0.101     0.02    -0.02  1.430410e-07  1.075062e-08 -1.075062e-08   
       2      0.141     0.02    -0.02  1.142408e-07  1.047073e-08 -1.047073e-08   
       3      0.181     0.02    -0.02  1.456813e-07  1.068606e-08 -1.068606e-08   
       4      0.221     0.02    -0.02  1.475240e-07  1.100945e-08 -1.100945e-08   
       ..       ...      ...      ...           ...           ...           ...   
       195  773.581    20.98   -20.98 -7.212538e-12  8.493468e-11 -8.493468e-11   
       196  815.541    20.98   -20.98 -3.724230e-11  8.493435e-11 -8.493435e-11   
       197  857.501    20.98   -20.98  1.365478e-10  8.508375e-11 -8.508375e-11   
       198  899.461    20.98   -20.98 -6.346568e-11  8.506434e-11 -8.506434e-11   
       199  941.541    21.10   -21.10  1.534458e-11  8.487557e-11 -8.487557e-11   
       
            BadBin  
       0     False  
       1     False  
       2     False  
       3     False  
       4     False  
       ..      ...  
       195    True  
       196    True  
       197    True  
       198    True  
       199    True  
       
       [200 rows x 7 columns],
       'BATBand':         Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0      0.021     0.02    -0.02  1.828172e-06  1.389022e-07 -1.389022e-07   
       1      0.061     0.02    -0.02  1.509217e-06  1.401063e-07 -1.401063e-07   
       2      0.101     0.02    -0.02  2.083946e-06  1.566244e-07 -1.566244e-07   
       3      0.141     0.02    -0.02  1.664360e-06  1.525468e-07 -1.525468e-07   
       4      0.181     0.02    -0.02  2.122412e-06  1.556839e-07 -1.556839e-07   
       ..       ...      ...      ...           ...           ...           ...   
       196  773.581    20.98   -20.98 -1.050786e-10  1.237403e-09 -1.237403e-09   
       197  815.541    20.98   -20.98 -5.425786e-10  1.237398e-09 -1.237398e-09   
       198  857.501    20.98   -20.98  1.989348e-09  1.239575e-09 -1.239575e-09   
       199  899.461    20.98   -20.98 -9.246238e-10  1.239292e-09 -1.239292e-09   
       200  941.541    21.10   -21.10  2.235533e-10  1.236542e-09 -1.236542e-09   
       
            BadBin  
       0     False  
       1     False  
       2     False  
       3     False  
       4     False  
       ..      ...  
       196    True  
       197    True  
       198    True  
       199    True  
       200    True  
       
       [201 rows x 7 columns],
       'Datasets': ['ObservedFlux', 'Density', 'XRTBand', 'BATBand']},
      'SNR5': {'ObservedFlux':         Time  TimePos  TimeNeg          Flux   FluxPos   FluxNeg  BadBin
       0   -167.808    23.88   -23.88 -3.831272e-06  0.000005 -0.000005    True
       1   -120.048    23.88   -23.88  4.552976e-07  0.000005 -0.000005    True
       2    -72.288    23.88   -23.88 -6.351962e-07  0.000005 -0.000005    True
       3    -24.488    23.92   -23.92  3.879594e-06  0.000005 -0.000005    True
       4     -0.528     0.04    -0.04  1.000045e-03  0.000179 -0.000179   False
       ..       ...      ...      ...           ...       ...       ...     ...
       188  776.152    20.68   -20.68 -1.327876e-06  0.000004 -0.000004    True
       189  817.512    20.68   -20.68 -1.970482e-06  0.000004 -0.000004    True
       190  858.872    20.68   -20.68  7.468324e-06  0.000004 -0.000004    True
       191  900.232    20.68   -20.68 -2.515430e-06  0.000004 -0.000004    True
       192  941.772    20.86   -20.86  4.121429e-07  0.000004 -0.000004    True
       
       [193 rows x 7 columns],
       'Density':         Time  TimePos  TimeNeg          Flux   FluxPos   FluxNeg  BadBin
       0   -167.808    23.88   -23.88 -3.647946e-06  0.000005 -0.000005    True
       1   -120.048    23.88   -23.88  4.335117e-07  0.000005 -0.000005    True
       2    -72.288    23.88   -23.88 -6.048022e-07  0.000005 -0.000005    True
       3    -24.488    23.92   -23.92  3.693956e-06  0.000005 -0.000005    True
       4     -0.528     0.04    -0.04  9.521930e-04  0.000170 -0.000170   False
       ..       ...      ...      ...           ...       ...       ...     ...
       188  776.152    20.68   -20.68 -1.264337e-06  0.000004 -0.000004    True
       189  817.512    20.68   -20.68 -1.876195e-06  0.000004 -0.000004    True
       190  858.872    20.68   -20.68  7.110967e-06  0.000004 -0.000004    True
       191  900.232    20.68   -20.68 -2.395067e-06  0.000004 -0.000004    True
       192  941.772    20.86   -20.86  3.924220e-07  0.000004 -0.000004    True
       
       [193 rows x 7 columns],
       'XRTBand':         Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0   -167.808    23.88   -23.88 -7.402950e-11  1.020133e-10 -1.020133e-10   
       1   -120.048    23.88   -23.88  8.797458e-12  1.019099e-10 -1.019099e-10   
       2    -72.288    23.88   -23.88 -1.227354e-11  1.016251e-10 -1.016251e-10   
       3    -24.488    23.92   -23.92  7.496321e-11  1.022383e-10 -1.022383e-10   
       4     -0.528     0.04    -0.04  1.932330e-08  3.455912e-09 -3.455912e-09   
       ..       ...      ...      ...           ...           ...           ...   
       188  776.152    20.68   -20.68 -2.565779e-11  8.550728e-11 -8.550728e-11   
       189  817.512    20.68   -20.68 -3.807451e-11  8.563676e-11 -8.563676e-11   
       190  858.872    20.68   -20.68  1.443062e-10  8.563371e-11 -8.563371e-11   
       191  900.232    20.68   -20.68 -4.860423e-11  8.566599e-11 -8.566599e-11   
       192  941.772    20.86   -20.86  7.963605e-12  8.536782e-11 -8.536782e-11   
       
            BadBin  
       0      True  
       1      True  
       2      True  
       3      True  
       4     False  
       ..      ...  
       188    True  
       189    True  
       190    True  
       191    True  
       192    True  
       
       [193 rows x 7 columns],
       'BATBand':         Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0   -215.568    23.88   -23.88  1.777774e-09  1.491150e-09 -1.491150e-09   
       1   -167.808    23.88   -23.88 -1.078527e-09  1.486219e-09 -1.486219e-09   
       2   -120.048    23.88   -23.88  1.281691e-10  1.484713e-09 -1.484713e-09   
       3    -72.288    23.88   -23.88 -1.788117e-10  1.480564e-09 -1.480564e-09   
       4    -24.488    23.92   -23.92  1.092130e-09  1.489497e-09 -1.489497e-09   
       ..       ...      ...      ...           ...           ...           ...   
       189  776.152    20.68   -20.68 -3.738052e-10  1.245745e-09 -1.245745e-09   
       190  817.512    20.68   -20.68 -5.547028e-10  1.247631e-09 -1.247631e-09   
       191  858.872    20.68   -20.68  2.102380e-09  1.247587e-09 -1.247587e-09   
       192  900.232    20.68   -20.68 -7.081091e-10  1.248057e-09 -1.248057e-09   
       193  941.772    20.86   -20.86  1.160208e-10  1.243713e-09 -1.243713e-09   
       
            BadBin  
       0      True  
       1      True  
       2      True  
       3      True  
       4      True  
       ..      ...  
       189    True  
       190    True  
       191    True  
       192    True  
       193    True  
       
       [194 rows x 7 columns],
       'Datasets': ['ObservedFlux', 'Density', 'XRTBand', 'BATBand']},
      'SNR5_sinceT0': {'ObservedFlux':         Time  TimePos  TimeNeg          Flux   FluxPos   FluxNeg  BadBin
       0      0.061     0.02    -0.02  5.361221e-03  0.000498 -0.000498   False
       1      0.101     0.02    -0.02  7.402844e-03  0.000556 -0.000556   False
       2      0.141     0.02    -0.02  5.912338e-03  0.000542 -0.000542   False
       3      0.181     0.02    -0.02  7.539487e-03  0.000553 -0.000553   False
       4      0.221     0.02    -0.02  7.634854e-03  0.000570 -0.000570   False
       ..       ...      ...      ...           ...       ...       ...     ...
       176  776.441    20.64   -20.64 -2.102213e-06  0.000004 -0.000004    True
       177  817.721    20.64   -20.64 -1.660601e-06  0.000004 -0.000004    True
       178  859.001    20.64   -20.64  7.174780e-06  0.000004 -0.000004    True
       179  900.281    20.64   -20.64 -1.908578e-06  0.000004 -0.000004    True
       180  941.781    20.86   -20.86  2.573776e-07  0.000004 -0.000004    True
       
       [181 rows x 7 columns],
       'Density':         Time  TimePos  TimeNeg          Flux   FluxPos   FluxNeg  BadBin
       0      0.061     0.02    -0.02  5.104688e-03  0.000474 -0.000474   False
       1      0.101     0.02    -0.02  7.048619e-03  0.000530 -0.000530   False
       2      0.141     0.02    -0.02  5.629434e-03  0.000516 -0.000516   False
       3      0.181     0.02    -0.02  7.178724e-03  0.000527 -0.000527   False
       4      0.221     0.02    -0.02  7.269528e-03  0.000543 -0.000543   False
       ..       ...      ...      ...           ...       ...       ...     ...
       176  776.441    20.64   -20.64 -2.001623e-06  0.000004 -0.000004    True
       177  817.721    20.64   -20.64 -1.581142e-06  0.000004 -0.000004    True
       178  859.001    20.64   -20.64  6.831468e-06  0.000004 -0.000004    True
       179  900.281    20.64   -20.64 -1.817253e-06  0.000004 -0.000004    True
       180  941.781    20.86   -20.86  2.450621e-07  0.000004 -0.000004    True
       
       [181 rows x 7 columns],
       'XRTBand':         Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0      0.061     0.02    -0.02  1.035919e-07  9.616825e-09 -9.616825e-09   
       1      0.101     0.02    -0.02  1.430410e-07  1.075062e-08 -1.075062e-08   
       2      0.141     0.02    -0.02  1.142408e-07  1.047073e-08 -1.047073e-08   
       3      0.181     0.02    -0.02  1.456813e-07  1.068606e-08 -1.068606e-08   
       4      0.221     0.02    -0.02  1.475240e-07  1.100945e-08 -1.100945e-08   
       ..       ...      ...      ...           ...           ...           ...   
       176  776.441    20.64   -20.64 -4.061988e-11  8.559593e-11 -8.559593e-11   
       177  817.721    20.64   -20.64 -3.208686e-11  8.573011e-11 -8.573011e-11   
       178  859.001    20.64   -20.64  1.386342e-10  8.569538e-11 -8.569538e-11   
       179  900.281    20.64   -20.64 -3.687838e-11  8.576301e-11 -8.576301e-11   
       180  941.781    20.86   -20.86  4.973162e-12  8.536868e-11 -8.536868e-11   
       
            BadBin  
       0     False  
       1     False  
       2     False  
       3     False  
       4     False  
       ..      ...  
       176    True  
       177    True  
       178    True  
       179    True  
       180    True  
       
       [181 rows x 7 columns],
       'BATBand':         Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0      0.021     0.02    -0.02  1.828172e-06  1.389022e-07 -1.389022e-07   
       1      0.061     0.02    -0.02  1.509217e-06  1.401063e-07 -1.401063e-07   
       2      0.101     0.02    -0.02  2.083946e-06  1.566244e-07 -1.566244e-07   
       3      0.141     0.02    -0.02  1.664360e-06  1.525468e-07 -1.525468e-07   
       4      0.181     0.02    -0.02  2.122412e-06  1.556839e-07 -1.556839e-07   
       ..       ...      ...      ...           ...           ...           ...   
       177  776.441    20.64   -20.64 -5.917861e-10  1.247037e-09 -1.247037e-09   
       178  817.721    20.64   -20.64 -4.674696e-10  1.248992e-09 -1.248992e-09   
       179  859.001    20.64   -20.64  2.019745e-09  1.248486e-09 -1.248486e-09   
       180  900.281    20.64   -20.64 -5.372767e-10  1.249471e-09 -1.249471e-09   
       181  941.781    20.86   -20.86  7.245339e-11  1.243726e-09 -1.243726e-09   
       
            BadBin  
       0     False  
       1     False  
       2     False  
       3     False  
       4     False  
       ..      ...  
       177    True  
       178    True  
       179    True  
       180    True  
       181    True  
       
       [182 rows x 7 columns],
       'Datasets': ['ObservedFlux', 'Density', 'XRTBand', 'BATBand']},
      'SNR6': {'ObservedFlux':         Time  TimePos  TimeNeg          Flux   FluxPos   FluxNeg  BadBin
       0   -167.808    23.88   -23.88 -3.831272e-06  0.000005 -0.000005    True
       1   -120.048    23.88   -23.88  4.552976e-07  0.000005 -0.000005    True
       2    -72.288    23.88   -23.88 -6.351962e-07  0.000005 -0.000005    True
       3    -24.468    23.94   -23.94  4.538016e-06  0.000005 -0.000005    True
       4     -0.468     0.06    -0.06  1.049127e-03  0.000146 -0.000146   False
       ..       ...      ...      ...           ...       ...       ...     ...
       169  775.792    20.72   -20.72 -1.072040e-06  0.000004 -0.000004    True
       170  817.232    20.72   -20.72 -1.912702e-06  0.000004 -0.000004    True
       171  858.672    20.72   -20.72  7.377108e-06  0.000004 -0.000004    True
       172  900.112    20.72   -20.72 -2.494752e-06  0.000004 -0.000004    True
       173  941.732    20.90   -20.90  4.965771e-07  0.000004 -0.000004    True
       
       [174 rows x 7 columns],
       'Density':         Time  TimePos  TimeNeg          Flux   FluxPos   FluxNeg  BadBin
       0   -167.808    23.88   -23.88 -3.647946e-06  0.000005 -0.000005    True
       1   -120.048    23.88   -23.88  4.335117e-07  0.000005 -0.000005    True
       2    -72.288    23.88   -23.88 -6.048022e-07  0.000005 -0.000005    True
       3    -24.468    23.94   -23.94  4.320872e-06  0.000005 -0.000005    True
       4     -0.468     0.06    -0.06  9.989262e-04  0.000139 -0.000139   False
       ..       ...      ...      ...           ...       ...       ...     ...
       169  775.792    20.72   -20.72 -1.020743e-06  0.000004 -0.000004    True
       170  817.232    20.72   -20.72 -1.821180e-06  0.000004 -0.000004    True
       171  858.672    20.72   -20.72  7.024115e-06  0.000004 -0.000004    True
       172  900.112    20.72   -20.72 -2.375378e-06  0.000004 -0.000004    True
       173  941.732    20.90   -20.90  4.728160e-07  0.000004 -0.000004    True
       
       [174 rows x 7 columns],
       'XRTBand':         Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0   -167.808    23.88   -23.88 -7.402950e-11  1.020133e-10 -1.020133e-10   
       1   -120.048    23.88   -23.88  8.797458e-12  1.019099e-10 -1.019099e-10   
       2    -72.288    23.88   -23.88 -1.227354e-11  1.016251e-10 -1.016251e-10   
       3    -24.468    23.94   -23.94  8.768551e-11  1.022377e-10 -1.022377e-10   
       4     -0.468     0.06    -0.06  2.027168e-08  2.816899e-09 -2.816899e-09   
       ..       ...      ...      ...           ...           ...           ...   
       169  775.792    20.72   -20.72 -2.071442e-11  8.546262e-11 -8.546262e-11   
       170  817.232    20.72   -20.72 -3.695807e-11  8.551828e-11 -8.551828e-11   
       171  858.672    20.72   -20.72  1.425437e-10  8.557610e-11 -8.557610e-11   
       172  900.112    20.72   -20.72 -4.820468e-11  8.558221e-11 -8.558221e-11   
       173  941.732    20.90   -20.90  9.595079e-12  8.528912e-11 -8.528912e-11   
       
            BadBin  
       0      True  
       1      True  
       2      True  
       3      True  
       4     False  
       ..      ...  
       169    True  
       170    True  
       171    True  
       172    True  
       173    True  
       
       [174 rows x 7 columns],
       'BATBand':         Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0   -215.568    23.88   -23.88  1.777774e-09  1.491150e-09 -1.491150e-09   
       1   -167.808    23.88   -23.88 -1.078527e-09  1.486219e-09 -1.486219e-09   
       2   -120.048    23.88   -23.88  1.281691e-10  1.484713e-09 -1.484713e-09   
       3    -72.288    23.88   -23.88 -1.788117e-10  1.480564e-09 -1.480564e-09   
       4    -24.468    23.94   -23.94  1.277480e-09  1.489488e-09 -1.489488e-09   
       ..       ...      ...      ...           ...           ...           ...   
       170  775.792    20.72   -20.72 -3.017858e-10  1.245094e-09 -1.245094e-09   
       171  817.232    20.72   -20.72 -5.384375e-10  1.245905e-09 -1.245905e-09   
       172  858.672    20.72   -20.72  2.076702e-09  1.246748e-09 -1.246748e-09   
       173  900.112    20.72   -20.72 -7.022880e-10  1.246837e-09 -1.246837e-09   
       174  941.732    20.90   -20.90  1.397895e-10  1.242567e-09 -1.242567e-09   
       
            BadBin  
       0      True  
       1      True  
       2      True  
       3      True  
       4      True  
       ..      ...  
       170    True  
       171    True  
       172    True  
       173    True  
       174    True  
       
       [175 rows x 7 columns],
       'Datasets': ['ObservedFlux', 'Density', 'XRTBand', 'BATBand']},
      'SNR6_sinceT0': {'ObservedFlux':         Time  TimePos  TimeNeg          Flux   FluxPos   FluxNeg  BadBin
       0      0.061     0.02    -0.02  5.361221e-03  0.000498 -0.000498   False
       1      0.101     0.02    -0.02  7.402844e-03  0.000556 -0.000556   False
       2      0.141     0.02    -0.02  5.912338e-03  0.000542 -0.000542   False
       3      0.181     0.02    -0.02  7.539487e-03  0.000553 -0.000553   False
       4      0.221     0.02    -0.02  7.634854e-03  0.000570 -0.000570   False
       ..       ...      ...      ...           ...       ...       ...     ...
       152  775.921    20.72   -20.72 -1.115724e-06  0.000004 -0.000004    True
       153  817.361    20.72   -20.72 -1.939992e-06  0.000004 -0.000004    True
       154  858.801    20.72   -20.72  7.549437e-06  0.000004 -0.000004    True
       155  900.241    20.72   -20.72 -2.448197e-06  0.000004 -0.000004    True
       156  941.801    20.84   -20.84  1.909305e-07  0.000004 -0.000004    True
       
       [157 rows x 7 columns],
       'Density':         Time  TimePos  TimeNeg          Flux   FluxPos   FluxNeg  BadBin
       0      0.061     0.02    -0.02  5.104688e-03  0.000474 -0.000474   False
       1      0.101     0.02    -0.02  7.048619e-03  0.000530 -0.000530   False
       2      0.141     0.02    -0.02  5.629434e-03  0.000516 -0.000516   False
       3      0.181     0.02    -0.02  7.178724e-03  0.000527 -0.000527   False
       4      0.221     0.02    -0.02  7.269528e-03  0.000543 -0.000543   False
       ..       ...      ...      ...           ...       ...       ...     ...
       152  775.921    20.72   -20.72 -1.062337e-06  0.000004 -0.000004    True
       153  817.361    20.72   -20.72 -1.847164e-06  0.000004 -0.000004    True
       154  858.801    20.72   -20.72  7.188198e-06  0.000004 -0.000004    True
       155  900.241    20.72   -20.72 -2.331051e-06  0.000004 -0.000004    True
       156  941.801    20.84   -20.84  1.817945e-07  0.000004 -0.000004    True
       
       [157 rows x 7 columns],
       'XRTBand':         Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0      0.061     0.02    -0.02  1.035919e-07  9.616825e-09 -9.616825e-09   
       1      0.101     0.02    -0.02  1.430410e-07  1.075062e-08 -1.075062e-08   
       2      0.141     0.02    -0.02  1.142408e-07  1.047073e-08 -1.047073e-08   
       3      0.181     0.02    -0.02  1.456813e-07  1.068606e-08 -1.068606e-08   
       4      0.221     0.02    -0.02  1.475240e-07  1.100945e-08 -1.100945e-08   
       ..       ...      ...      ...           ...           ...           ...   
       152  775.921    20.72   -20.72 -2.155851e-11  8.544726e-11 -8.544726e-11   
       153  817.361    20.72   -20.72 -3.748537e-11  8.553896e-11 -8.553896e-11   
       154  858.801    20.72   -20.72  1.458735e-10  8.555927e-11 -8.555927e-11   
       155  900.241    20.72   -20.72 -4.730513e-11  8.559106e-11 -8.559106e-11   
       156  941.801    20.84   -20.84  3.689242e-12  8.540317e-11 -8.540317e-11   
       
            BadBin  
       0     False  
       1     False  
       2     False  
       3     False  
       4     False  
       ..      ...  
       152    True  
       153    True  
       154    True  
       155    True  
       156    True  
       
       [157 rows x 7 columns],
       'BATBand':         Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0      0.021     0.02    -0.02  1.828172e-06  1.389022e-07 -1.389022e-07   
       1      0.061     0.02    -0.02  1.509217e-06  1.401063e-07 -1.401063e-07   
       2      0.101     0.02    -0.02  2.083946e-06  1.566244e-07 -1.566244e-07   
       3      0.141     0.02    -0.02  1.664360e-06  1.525468e-07 -1.525468e-07   
       4      0.181     0.02    -0.02  2.122412e-06  1.556839e-07 -1.556839e-07   
       ..       ...      ...      ...           ...           ...           ...   
       153  775.921    20.72   -20.72 -3.140832e-10  1.244871e-09 -1.244871e-09   
       154  817.361    20.72   -20.72 -5.461198e-10  1.246207e-09 -1.246207e-09   
       155  858.801    20.72   -20.72  2.125213e-09  1.246503e-09 -1.246503e-09   
       156  900.241    20.72   -20.72 -6.891826e-10  1.246966e-09 -1.246966e-09   
       157  941.801    20.84   -20.84  5.374812e-11  1.244228e-09 -1.244228e-09   
       
            BadBin  
       0     False  
       1     False  
       2     False  
       3     False  
       4     False  
       ..      ...  
       153    True  
       154    True  
       155    True  
       156    True  
       157    True  
       
       [158 rows x 7 columns],
       'Datasets': ['ObservedFlux', 'Density', 'XRTBand', 'BATBand']},
      'SNR7': {'ObservedFlux':         Time  TimePos  TimeNeg          Flux   FluxPos   FluxNeg  BadBin
       0   -167.808    23.88   -23.88 -3.831272e-06  0.000005 -0.000005    True
       1   -120.048    23.88   -23.88  4.552976e-07  0.000005 -0.000005    True
       2    -72.288    23.88   -23.88 -6.351962e-07  0.000005 -0.000005    True
       3    -24.468    23.94   -23.94  4.538016e-06  0.000005 -0.000005    True
       4     -0.468     0.06    -0.06  1.049127e-03  0.000146 -0.000146   False
       ..       ...      ...      ...           ...       ...       ...     ...
       149  776.292    20.66   -20.66 -1.665562e-06  0.000004 -0.000004    True
       150  817.612    20.66   -20.66 -1.725613e-06  0.000004 -0.000004    True
       151  858.932    20.66   -20.66  7.376748e-06  0.000004 -0.000004    True
       152  900.252    20.66   -20.66 -2.373138e-06  0.000004 -0.000004    True
       153  941.772    20.86   -20.86  4.121429e-07  0.000004 -0.000004    True
       
       [154 rows x 7 columns],
       'Density':         Time  TimePos  TimeNeg          Flux   FluxPos   FluxNeg  BadBin
       0   -167.808    23.88   -23.88 -3.647946e-06  0.000005 -0.000005    True
       1   -120.048    23.88   -23.88  4.335117e-07  0.000005 -0.000005    True
       2    -72.288    23.88   -23.88 -6.048022e-07  0.000005 -0.000005    True
       3    -24.468    23.94   -23.94  4.320872e-06  0.000005 -0.000005    True
       4     -0.468     0.06    -0.06  9.989262e-04  0.000139 -0.000139   False
       ..       ...      ...      ...           ...       ...       ...     ...
       149  776.292    20.66   -20.66 -1.585865e-06  0.000004 -0.000004    True
       150  817.612    20.66   -20.66 -1.643043e-06  0.000004 -0.000004    True
       151  858.932    20.66   -20.66  7.023773e-06  0.000004 -0.000004    True
       152  900.252    20.66   -20.66 -2.259584e-06  0.000004 -0.000004    True
       153  941.772    20.86   -20.86  3.924220e-07  0.000004 -0.000004    True
       
       [154 rows x 7 columns],
       'XRTBand':         Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0   -167.808    23.88   -23.88 -7.402950e-11  1.020133e-10 -1.020133e-10   
       1   -120.048    23.88   -23.88  8.797458e-12  1.019099e-10 -1.019099e-10   
       2    -72.288    23.88   -23.88 -1.227354e-11  1.016251e-10 -1.016251e-10   
       3    -24.468    23.94   -23.94  8.768551e-11  1.022377e-10 -1.022377e-10   
       4     -0.468     0.06    -0.06  2.027168e-08  2.816899e-09 -2.816899e-09   
       ..       ...      ...      ...           ...           ...           ...   
       149  776.292    20.66   -20.66 -3.218271e-11  8.553970e-11 -8.553970e-11   
       150  817.612    20.66   -20.66 -3.334304e-11  8.569586e-11 -8.569586e-11   
       151  858.932    20.66   -20.66  1.425367e-10  8.565494e-11 -8.565494e-11   
       152  900.252    20.66   -20.66 -4.585481e-11  8.571570e-11 -8.571570e-11   
       153  941.772    20.86   -20.86  7.963605e-12  8.536782e-11 -8.536782e-11   
       
            BadBin  
       0      True  
       1      True  
       2      True  
       3      True  
       4     False  
       ..      ...  
       149    True  
       150    True  
       151    True  
       152    True  
       153    True  
       
       [154 rows x 7 columns],
       'BATBand':         Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0   -215.568    23.88   -23.88  1.777774e-09  1.491150e-09 -1.491150e-09   
       1   -167.808    23.88   -23.88 -1.078527e-09  1.486219e-09 -1.486219e-09   
       2   -120.048    23.88   -23.88  1.281691e-10  1.484713e-09 -1.484713e-09   
       3    -72.288    23.88   -23.88 -1.788117e-10  1.480564e-09 -1.480564e-09   
       4    -24.468    23.94   -23.94  1.277480e-09  1.489488e-09 -1.489488e-09   
       ..       ...      ...      ...           ...           ...           ...   
       150  776.292    20.66   -20.66 -4.688659e-10  1.246217e-09 -1.246217e-09   
       151  817.612    20.66   -20.66 -4.857707e-10  1.248492e-09 -1.248492e-09   
       152  858.932    20.66   -20.66  2.076600e-09  1.247896e-09 -1.247896e-09   
       153  900.252    20.66   -20.66 -6.680531e-10  1.248782e-09 -1.248782e-09   
       154  941.772    20.86   -20.86  1.160208e-10  1.243713e-09 -1.243713e-09   
       
            BadBin  
       0      True  
       1      True  
       2      True  
       3      True  
       4      True  
       ..      ...  
       150    True  
       151    True  
       152    True  
       153    True  
       154    True  
       
       [155 rows x 7 columns],
       'Datasets': ['ObservedFlux', 'Density', 'XRTBand', 'BATBand']},
      'SNR7_sinceT0': {'ObservedFlux':         Time  TimePos  TimeNeg          Flux   FluxPos   FluxNeg  BadBin
       0      0.061     0.02    -0.02  5.361221e-03  0.000498 -0.000498   False
       1      0.101     0.02    -0.02  7.402844e-03  0.000556 -0.000556   False
       2      0.141     0.02    -0.02  5.912338e-03  0.000542 -0.000542   False
       3      0.181     0.02    -0.02  7.539487e-03  0.000553 -0.000553   False
       4      0.221     0.02    -0.02  7.634854e-03  0.000570 -0.000570   False
       ..       ...      ...      ...           ...       ...       ...     ...
       136  775.621    20.70   -20.70 -9.737531e-07  0.000004 -0.000004    True
       137  817.021    20.70   -20.70 -1.686418e-06  0.000004 -0.000004    True
       138  858.421    20.70   -20.70  6.934499e-06  0.000004 -0.000004    True
       139  899.821    20.70   -20.70 -2.743431e-06  0.000004 -0.000004    True
       140  941.581    21.06   -21.06  7.679826e-07  0.000004 -0.000004    True
       
       [141 rows x 7 columns],
       'Density':         Time  TimePos  TimeNeg          Flux   FluxPos   FluxNeg  BadBin
       0      0.061     0.02    -0.02  5.104688e-03  0.000474 -0.000474   False
       1      0.101     0.02    -0.02  7.048619e-03  0.000530 -0.000530   False
       2      0.141     0.02    -0.02  5.629434e-03  0.000516 -0.000516   False
       3      0.181     0.02    -0.02  7.178724e-03  0.000527 -0.000527   False
       4      0.221     0.02    -0.02  7.269528e-03  0.000543 -0.000543   False
       ..       ...      ...      ...           ...       ...       ...     ...
       136  775.621    20.70   -20.70 -9.271593e-07  0.000004 -0.000004    True
       137  817.021    20.70   -20.70 -1.605723e-06  0.000004 -0.000004    True
       138  858.421    20.70   -20.70  6.602685e-06  0.000004 -0.000004    True
       139  899.821    20.70   -20.70 -2.612158e-06  0.000004 -0.000004    True
       140  941.581    21.06   -21.06  7.312348e-07  0.000004 -0.000004    True
       
       [141 rows x 7 columns],
       'XRTBand':         Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0      0.061     0.02    -0.02  1.035919e-07  9.616825e-09 -9.616825e-09   
       1      0.101     0.02    -0.02  1.430410e-07  1.075062e-08 -1.075062e-08   
       2      0.141     0.02    -0.02  1.142408e-07  1.047073e-08 -1.047073e-08   
       3      0.181     0.02    -0.02  1.456813e-07  1.068606e-08 -1.068606e-08   
       4      0.221     0.02    -0.02  1.475240e-07  1.100945e-08 -1.100945e-08   
       ..       ...      ...      ...           ...           ...           ...   
       136  775.621    20.70   -20.70 -1.881528e-11  8.551813e-11 -8.551813e-11   
       137  817.021    20.70   -20.70 -3.258570e-11  8.553078e-11 -8.553078e-11   
       138  858.421    20.70   -20.70  1.339914e-10  8.562725e-11 -8.562725e-11   
       139  899.821    20.70   -20.70 -5.300976e-11  8.563019e-11 -8.563019e-11   
       140  941.581    21.06   -21.06  1.483929e-11  8.496031e-11 -8.496031e-11   
       
            BadBin  
       0     False  
       1     False  
       2     False  
       3     False  
       4     False  
       ..      ...  
       136    True  
       137    True  
       138    True  
       139    True  
       140    True  
       
       [141 rows x 7 columns],
       'BATBand':         Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0      0.021     0.02    -0.02  1.828172e-06  1.389022e-07 -1.389022e-07   
       1      0.061     0.02    -0.02  1.509217e-06  1.401063e-07 -1.401063e-07   
       2      0.101     0.02    -0.02  2.083946e-06  1.566244e-07 -1.566244e-07   
       3      0.141     0.02    -0.02  1.664360e-06  1.525468e-07 -1.525468e-07   
       4      0.181     0.02    -0.02  2.122412e-06  1.556839e-07 -1.556839e-07   
       ..       ...      ...      ...           ...           ...           ...   
       137  775.621    20.70   -20.70 -2.741175e-10  1.245903e-09 -1.245903e-09   
       138  817.021    20.70   -20.70 -4.747371e-10  1.246088e-09 -1.246088e-09   
       139  858.421    20.70   -20.70  1.952105e-09  1.247493e-09 -1.247493e-09   
       140  899.821    20.70   -20.70 -7.722928e-10  1.247536e-09 -1.247536e-09   
       141  941.581    21.06   -21.06  2.161919e-10  1.237776e-09 -1.237776e-09   
       
            BadBin  
       0     False  
       1     False  
       2     False  
       3     False  
       4     False  
       ..      ...  
       137    True  
       138    True  
       139    True  
       140    True  
       141    True  
       
       [142 rows x 7 columns],
       'Datasets': ['ObservedFlux', 'Density', 'XRTBand', 'BATBand']},
      'TimeBins_4ms': {'ObservedFlux':          Time  TimePos  TimeNeg      Flux   FluxPos   FluxNeg  BadBin
       0     -7.7298    0.002   -0.002  0.000540  0.000510 -0.000510   False
       1     -7.7258    0.002   -0.002  0.001382  0.000620 -0.000620   False
       2     -7.7218    0.002   -0.002  0.000719  0.000540 -0.000540   False
       3     -7.7178    0.002   -0.002 -0.001279  0.000625 -0.000625   False
       4     -7.7138    0.002   -0.002  0.000224  0.000605 -0.000605   False
       ...       ...      ...      ...       ...       ...       ...     ...
       5664  14.9262    0.002   -0.002 -0.000774  0.000535 -0.000535   False
       5665  14.9302    0.002   -0.002  0.000345  0.000448 -0.000448   False
       5666  14.9342    0.002   -0.002  0.000520  0.000594 -0.000594   False
       5667  14.9382    0.002   -0.002 -0.000254  0.000445 -0.000445   False
       5668  14.9422    0.002   -0.002 -0.000441  0.000618 -0.000618   False
       
       [5669 rows x 7 columns],
       'Density':          Time  TimePos  TimeNeg      Flux   FluxPos   FluxNeg  BadBin
       0     -7.7298    0.002   -0.002  0.000514  0.000485 -0.000485   False
       1     -7.7258    0.002   -0.002  0.001316  0.000590 -0.000590   False
       2     -7.7218    0.002   -0.002  0.000685  0.000514 -0.000514   False
       3     -7.7178    0.002   -0.002 -0.001217  0.000595 -0.000595   False
       4     -7.7138    0.002   -0.002  0.000213  0.000576 -0.000576   False
       ...       ...      ...      ...       ...       ...       ...     ...
       5664  14.9262    0.002   -0.002 -0.000737  0.000509 -0.000509   False
       5665  14.9302    0.002   -0.002  0.000328  0.000426 -0.000426   False
       5666  14.9342    0.002   -0.002  0.000496  0.000566 -0.000566   False
       5667  14.9382    0.002   -0.002 -0.000242  0.000424 -0.000424   False
       5668  14.9422    0.002   -0.002 -0.000420  0.000588 -0.000588   False
       
       [5669 rows x 7 columns],
       'XRTBand':          Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0     -7.7298    0.002   -0.002  1.042746e-08  9.848005e-09 -9.848005e-09   
       1     -7.7258    0.002   -0.002  2.670053e-08  1.197852e-08 -1.197852e-08   
       2     -7.7218    0.002   -0.002  1.389786e-08  1.043567e-08 -1.043567e-08   
       3     -7.7178    0.002   -0.002 -2.470576e-08  1.207534e-08 -1.207534e-08   
       4     -7.7138    0.002   -0.002  4.327486e-09  1.168522e-08 -1.168522e-08   
       ...       ...      ...      ...           ...           ...           ...   
       5664  14.9262    0.002   -0.002 -1.495128e-08  1.033636e-08 -1.033636e-08   
       5665  14.9302    0.002   -0.002  6.656919e-09  8.653226e-09 -8.653226e-09   
       5666  14.9342    0.002   -0.002  1.005621e-08  1.148143e-08 -1.148143e-08   
       5667  14.9382    0.002   -0.002 -4.911497e-09  8.601642e-09 -8.601642e-09   
       5668  14.9422    0.002   -0.002 -8.513339e-09  1.193691e-08 -1.193691e-08   
       
             BadBin  
       0      False  
       1      False  
       2      False  
       3      False  
       4      False  
       ...      ...  
       5664   False  
       5665   False  
       5666   False  
       5667   False  
       5668   False  
       
       [5669 rows x 7 columns],
       'BATBand':          Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0     -7.7338    0.002   -0.002 -1.535565e-07  2.013313e-07 -2.013313e-07   
       1     -7.7298    0.002   -0.002  1.519164e-07  1.434744e-07 -1.434744e-07   
       2     -7.7258    0.002   -0.002  3.889968e-07  1.745136e-07 -1.745136e-07   
       3     -7.7218    0.002   -0.002  2.024762e-07  1.520361e-07 -1.520361e-07   
       4     -7.7178    0.002   -0.002 -3.599353e-07  1.759241e-07 -1.759241e-07   
       ...       ...      ...      ...           ...           ...           ...   
       5665  14.9262    0.002   -0.002 -2.178233e-07  1.505892e-07 -1.505892e-07   
       5666  14.9302    0.002   -0.002  9.698384e-08  1.260678e-07 -1.260678e-07   
       5667  14.9342    0.002   -0.002  1.465077e-07  1.672715e-07 -1.672715e-07   
       5668  14.9382    0.002   -0.002 -7.155500e-08  1.253163e-07 -1.253163e-07   
       5669  14.9422    0.002   -0.002 -1.240298e-07  1.739075e-07 -1.739075e-07   
       
             BadBin  
       0      False  
       1      False  
       2      False  
       3      False  
       4      False  
       ...      ...  
       5665   False  
       5666   False  
       5667   False  
       5668   False  
       5669   False  
       
       [5670 rows x 7 columns],
       'Datasets': ['ObservedFlux', 'Density', 'XRTBand', 'BATBand']},
      'TimeBins_64ms': {'ObservedFlux':         Time  TimePos  TimeNeg      Flux   FluxPos   FluxNeg  BadBin
       0    -7.6698    0.032   -0.032 -0.000222  0.000148 -0.000148   False
       1    -7.6058    0.032   -0.032  0.000043  0.000149 -0.000149   False
       2    -7.5418    0.032   -0.032  0.000144  0.000143 -0.000143   False
       3    -7.4778    0.032   -0.032  0.000098  0.000153 -0.000153   False
       4    -7.4138    0.032   -0.032  0.000170  0.000150 -0.000150   False
       ..       ...      ...      ...       ...       ...       ...     ...
       349  14.6662    0.032   -0.032 -0.000091  0.000145 -0.000145   False
       350  14.7302    0.032   -0.032 -0.000076  0.000154 -0.000154   False
       351  14.7942    0.032   -0.032  0.000155  0.000152 -0.000152   False
       352  14.8582    0.032   -0.032  0.000213  0.000144 -0.000144   False
       353  14.9222    0.032   -0.032 -0.000114  0.000216 -0.000216   False
       
       [354 rows x 7 columns],
       'Density':         Time  TimePos  TimeNeg      Flux   FluxPos   FluxNeg  BadBin
       0    -7.6698    0.032   -0.032 -0.000211  0.000141 -0.000141   False
       1    -7.6058    0.032   -0.032  0.000041  0.000142 -0.000142   False
       2    -7.5418    0.032   -0.032  0.000138  0.000136 -0.000136   False
       3    -7.4778    0.032   -0.032  0.000093  0.000146 -0.000146   False
       4    -7.4138    0.032   -0.032  0.000162  0.000143 -0.000143   False
       ..       ...      ...      ...       ...       ...       ...     ...
       349  14.6662    0.032   -0.032 -0.000087  0.000138 -0.000138   False
       350  14.7302    0.032   -0.032 -0.000072  0.000146 -0.000146   False
       351  14.7942    0.032   -0.032  0.000148  0.000145 -0.000145   False
       352  14.8582    0.032   -0.032  0.000202  0.000137 -0.000137   False
       353  14.9222    0.032   -0.032 -0.000108  0.000206 -0.000206   False
       
       [354 rows x 7 columns],
       'XRTBand':         Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0    -7.6698    0.032   -0.032 -4.281806e-09  2.857302e-09 -2.857302e-09   
       1    -7.6058    0.032   -0.032  8.276935e-10  2.874892e-09 -2.874892e-09   
       2    -7.5418    0.032   -0.032  2.790944e-09  2.760004e-09 -2.760004e-09   
       3    -7.4778    0.032   -0.032  1.883942e-09  2.955967e-09 -2.955967e-09   
       4    -7.4138    0.032   -0.032  3.287263e-09  2.901058e-09 -2.901058e-09   
       ..       ...      ...      ...           ...           ...           ...   
       349  14.6662    0.032   -0.032 -1.764133e-09  2.792737e-09 -2.792737e-09   
       350  14.7302    0.032   -0.032 -1.470133e-09  2.972305e-09 -2.972305e-09   
       351  14.7942    0.032   -0.032  2.993714e-09  2.935508e-09 -2.935508e-09   
       352  14.8582    0.032   -0.032  4.106534e-09  2.784738e-09 -2.784738e-09   
       353  14.9222    0.032   -0.032 -2.195743e-09  4.182585e-09 -4.182585e-09   
       
            BadBin  
       0     False  
       1     False  
       2     False  
       3     False  
       4     False  
       ..      ...  
       349   False  
       350   False  
       351   False  
       352   False  
       353   False  
       
       [354 rows x 7 columns],
       'BATBand':         Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0    -7.7338    0.032   -0.032 -2.092208e-08  4.183599e-08 -4.183599e-08   
       1    -7.6698    0.032   -0.032 -6.238111e-08  4.162768e-08 -4.162768e-08   
       2    -7.6058    0.032   -0.032  1.205857e-08  4.188395e-08 -4.188395e-08   
       3    -7.5418    0.032   -0.032  4.066093e-08  4.021016e-08 -4.021016e-08   
       4    -7.4778    0.032   -0.032  2.744692e-08  4.306513e-08 -4.306513e-08   
       ..       ...      ...      ...           ...           ...           ...   
       350  14.6662    0.032   -0.032 -2.570144e-08  4.068704e-08 -4.068704e-08   
       351  14.7302    0.032   -0.032 -2.141819e-08  4.330315e-08 -4.330315e-08   
       352  14.7942    0.032   -0.032  4.361505e-08  4.276705e-08 -4.276705e-08   
       353  14.8582    0.032   -0.032  5.982759e-08  4.057051e-08 -4.057051e-08   
       354  14.9222    0.032   -0.032 -3.198950e-08  6.093556e-08 -6.093556e-08   
       
            BadBin  
       0     False  
       1     False  
       2     False  
       3     False  
       4     False  
       ..      ...  
       350   False  
       351   False  
       352   False  
       353   False  
       354   False  
       
       [355 rows x 7 columns],
       'Datasets': ['ObservedFlux', 'Density', 'XRTBand', 'BATBand']},
      'TimeBins_1s': {'ObservedFlux':        Time  TimePos  TimeNeg      Flux   FluxPos   FluxNeg  BadBin
       0   -6.7338      0.5     -0.5 -0.000006  0.000035 -0.000035   False
       1   -5.7338      0.5     -0.5 -0.000015  0.000036 -0.000036   False
       2   -4.7338      0.5     -0.5  0.000030  0.000036 -0.000036   False
       3   -3.7338      0.5     -0.5 -0.000020  0.000037 -0.000037   False
       4   -2.7338      0.5     -0.5 -0.000013  0.000037 -0.000037   False
       5   -1.7338      0.5     -0.5  0.000102  0.000037 -0.000037   False
       6   -0.7338      0.5     -0.5  0.003111  0.000077 -0.000077   False
       7    0.2662      0.5     -0.5  0.006903  0.000105 -0.000105   False
       8    1.2662      0.5     -0.5  0.002214  0.000066 -0.000066   False
       9    2.2662      0.5     -0.5  0.001522  0.000058 -0.000058   False
       10   3.2662      0.5     -0.5  0.000920  0.000050 -0.000050   False
       11   4.2662      0.5     -0.5  0.000655  0.000046 -0.000046   False
       12   5.2662      0.5     -0.5  0.003243  0.000074 -0.000074   False
       13   6.2662      0.5     -0.5  0.003119  0.000073 -0.000073   False
       14   7.2662      0.5     -0.5  0.000792  0.000047 -0.000047   False
       15   8.2662      0.5     -0.5  0.000373  0.000042 -0.000042   False
       16   9.2662      0.5     -0.5  0.000133  0.000039 -0.000039   False
       17  10.2662      0.5     -0.5  0.000179  0.000039 -0.000039   False
       18  11.2662      0.5     -0.5  0.000038  0.000038 -0.000038   False
       19  12.2662      0.5     -0.5  0.000045  0.000037 -0.000037   False
       20  13.2662      0.5     -0.5  0.000060  0.000037 -0.000037   False
       21  14.2662      0.5     -0.5  0.000014  0.000045 -0.000045   False,
       'Density':        Time  TimePos  TimeNeg      Flux   FluxPos   FluxNeg  BadBin
       0   -6.7338      0.5     -0.5 -0.000006  0.000034 -0.000034   False
       1   -5.7338      0.5     -0.5 -0.000014  0.000035 -0.000035   False
       2   -4.7338      0.5     -0.5  0.000028  0.000034 -0.000034   False
       3   -3.7338      0.5     -0.5 -0.000019  0.000035 -0.000035   False
       4   -2.7338      0.5     -0.5 -0.000012  0.000035 -0.000035   False
       5   -1.7338      0.5     -0.5  0.000097  0.000036 -0.000036   False
       6   -0.7338      0.5     -0.5  0.002962  0.000074 -0.000074   False
       7    0.2662      0.5     -0.5  0.006573  0.000100 -0.000100   False
       8    1.2662      0.5     -0.5  0.002109  0.000063 -0.000063   False
       9    2.2662      0.5     -0.5  0.001449  0.000055 -0.000055   False
       10   3.2662      0.5     -0.5  0.000876  0.000048 -0.000048   False
       11   4.2662      0.5     -0.5  0.000624  0.000044 -0.000044   False
       12   5.2662      0.5     -0.5  0.003088  0.000070 -0.000070   False
       13   6.2662      0.5     -0.5  0.002970  0.000070 -0.000070   False
       14   7.2662      0.5     -0.5  0.000754  0.000045 -0.000045   False
       15   8.2662      0.5     -0.5  0.000355  0.000040 -0.000040   False
       16   9.2662      0.5     -0.5  0.000126  0.000038 -0.000038   False
       17  10.2662      0.5     -0.5  0.000171  0.000037 -0.000037   False
       18  11.2662      0.5     -0.5  0.000036  0.000036 -0.000036   False
       19  12.2662      0.5     -0.5  0.000043  0.000036 -0.000036   False
       20  13.2662      0.5     -0.5  0.000057  0.000035 -0.000035   False
       21  14.2662      0.5     -0.5  0.000014  0.000043 -0.000043   False,
       'XRTBand':        Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0   -6.7338      0.5     -0.5 -1.191177e-10  6.854625e-10 -6.854625e-10   
       1   -5.7338      0.5     -0.5 -2.922079e-10  7.048566e-10 -7.048566e-10   
       2   -4.7338      0.5     -0.5  5.756775e-10  6.953346e-10 -6.953346e-10   
       3   -3.7338      0.5     -0.5 -3.771656e-10  7.125927e-10 -7.125927e-10   
       4   -2.7338      0.5     -0.5 -2.526813e-10  7.056399e-10 -7.056399e-10   
       5   -1.7338      0.5     -0.5  1.964634e-09  7.245526e-10 -7.245526e-10   
       6   -0.7338      0.5     -0.5  6.011878e-08  1.492477e-09 -1.492477e-09   
       7    0.2662      0.5     -0.5  1.333859e-07  2.024978e-09 -2.024978e-09   
       8    1.2662      0.5     -0.5  4.278882e-08  1.269170e-09 -1.269170e-09   
       9    2.2662      0.5     -0.5  2.940565e-08  1.111076e-09 -1.111076e-09   
       10   3.2662      0.5     -0.5  1.777266e-08  9.757584e-10 -9.757584e-10   
       11   4.2662      0.5     -0.5  1.265899e-08  8.915649e-10 -8.915649e-10   
       12   5.2662      0.5     -0.5  6.266492e-08  1.424960e-09 -1.424960e-09   
       13   6.2662      0.5     -0.5  6.026402e-08  1.411609e-09 -1.411609e-09   
       14   7.2662      0.5     -0.5  1.530495e-08  9.143598e-10 -9.143598e-10   
       15   8.2662      0.5     -0.5  7.197942e-09  8.183409e-10 -8.183409e-10   
       16   9.2662      0.5     -0.5  2.563263e-09  7.625607e-10 -7.625607e-10   
       17  10.2662      0.5     -0.5  3.468026e-09  7.508889e-10 -7.508889e-10   
       18  11.2662      0.5     -0.5  7.256972e-10  7.355555e-10 -7.355555e-10   
       19  12.2662      0.5     -0.5  8.672624e-10  7.215951e-10 -7.215951e-10   
       20  13.2662      0.5     -0.5  1.159149e-09  7.108734e-10 -7.108734e-10   
       21  14.2662      0.5     -0.5  2.799709e-10  8.689254e-10 -8.689254e-10   
       
           BadBin  
       0    False  
       1    False  
       2    False  
       3    False  
       4    False  
       5    False  
       6    False  
       7    False  
       8    False  
       9    False  
       10   False  
       11   False  
       12   False  
       13   False  
       14   False  
       15   False  
       16   False  
       17   False  
       18   False  
       19   False  
       20   False  
       21   False  ,
       'BATBand':        Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  \
       0   -7.7338      0.5     -0.5  1.379351e-08  1.040069e-08 -1.040069e-08   
       1   -6.7338      0.5     -0.5 -1.735412e-09  9.986419e-09 -9.986419e-09   
       2   -5.7338      0.5     -0.5 -4.257142e-09  1.026897e-08 -1.026897e-08   
       3   -4.7338      0.5     -0.5  8.386976e-09  1.013025e-08 -1.013025e-08   
       4   -3.7338      0.5     -0.5 -5.494879e-09  1.038168e-08 -1.038168e-08   
       5   -2.7338      0.5     -0.5 -3.681283e-09  1.028038e-08 -1.028038e-08   
       6   -1.7338      0.5     -0.5  2.862251e-08  1.055592e-08 -1.055592e-08   
       7   -0.7338      0.5     -0.5  8.758631e-07  2.174371e-08 -2.174371e-08   
       8    0.2662      0.5     -0.5  1.943283e-06  2.950166e-08 -2.950166e-08   
       9    1.2662      0.5     -0.5  6.233851e-07  1.849038e-08 -1.849038e-08   
       10   2.2662      0.5     -0.5  4.284074e-07  1.618713e-08 -1.618713e-08   
       11   3.2662      0.5     -0.5  2.589277e-07  1.421571e-08 -1.421571e-08   
       12   4.2662      0.5     -0.5  1.844272e-07  1.298910e-08 -1.298910e-08   
       13   5.2662      0.5     -0.5  9.129576e-07  2.076007e-08 -2.076007e-08   
       14   6.2662      0.5     -0.5  8.779792e-07  2.056556e-08 -2.056556e-08   
       15   7.2662      0.5     -0.5  2.229760e-07  1.332120e-08 -1.332120e-08   
       16   8.2662      0.5     -0.5  1.048659e-07  1.192231e-08 -1.192231e-08   
       17   9.2662      0.5     -0.5  3.734386e-08  1.110965e-08 -1.110965e-08   
       18  10.2662      0.5     -0.5  5.052525e-08  1.093961e-08 -1.093961e-08   
       19  11.2662      0.5     -0.5  1.057259e-08  1.071622e-08 -1.071622e-08   
       20  12.2662      0.5     -0.5  1.263504e-08  1.051283e-08 -1.051283e-08   
       21  13.2662      0.5     -0.5  1.688750e-08  1.035663e-08 -1.035663e-08   
       22  14.2662      0.5     -0.5  4.078862e-09  1.265927e-08 -1.265927e-08   
       
           BadBin  
       0    False  
       1    False  
       2    False  
       3    False  
       4    False  
       5    False  
       6    False  
       7    False  
       8    False  
       9    False  
       10   False  
       11   False  
       12   False  
       13   False  
       14   False  
       15   False  
       16   False  
       17   False  
       18   False  
       19   False  
       20   False  
       21   False  
       22   False  ,
       'Datasets': ['ObservedFlux', 'Density', 'XRTBand', 'BATBand']},
      'TimeBins_10s': {'ObservedFlux':       Time  TimePos  TimeNeg      Flux   FluxPos   FluxNeg  BadBin
       0   2.2662      5.0     -5.0  0.001097  0.000017 -0.000017   False
       1  12.2662      5.0     -5.0  0.000043  0.000023 -0.000023   False,
       'Density':       Time  TimePos  TimeNeg      Flux   FluxPos   FluxNeg  BadBin
       0   2.2662      5.0     -5.0  0.001045  0.000016 -0.000016   False
       1  12.2662      5.0     -5.0  0.000041  0.000022 -0.000022   False,
       'XRTBand':       Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  BadBin
       0   2.2662      5.0     -5.0  2.120261e-08  3.193234e-10 -3.193234e-10   False
       1  12.2662      5.0     -5.0  8.272427e-10  4.375653e-10 -4.375653e-10   False,
       'BATBand':       Time  TimePos  TimeNeg          Flux       FluxPos       FluxNeg  BadBin
       0  -7.7338      5.0     -5.0  3.478165e-07  4.925343e-09 -4.925343e-09   False
       1   2.2662      5.0     -5.0  3.088983e-07  4.652184e-09 -4.652184e-09   False
       2  12.2662      5.0     -5.0  1.205200e-08  6.374836e-09 -6.374836e-09   False,
       'Datasets': ['ObservedFlux', 'Density', 'XRTBand', 'BATBand']},
      'Binning': ['SNR4',
       'SNR4_sinceT0',
       'SNR5',
       'SNR5_sinceT0',
       'SNR6',
       'SNR6_sinceT0',
       'SNR7',
       'SNR7_sinceT0',
       'TimeBins_4ms',
       'TimeBins_64ms',
       'TimeBins_1s',
       'TimeBins_10s']},
     'XRT': {'ObservedFlux_PC_incbad':           Time   TimePos    TimeNeg          Flux       FluxPos       FluxNeg  \
      0       98.141    11.448     -8.610  3.767024e-09  8.497318e-10 -8.497318e-10   
      1      124.376    12.795    -14.786  3.672690e-09  8.070243e-10 -8.070243e-10   
      2      151.556    15.702    -14.386  3.975908e-09  8.724380e-10 -8.724380e-10   
      3      199.129    23.289    -31.871  2.771658e-09  6.098835e-10 -6.098835e-10   
      4      245.091    27.474    -22.672  3.685128e-09  8.120176e-10 -8.120176e-10   
      5      293.881    23.816    -21.315  4.846421e-09  1.063456e-09 -1.063456e-09   
      6      336.711    31.132    -19.014  4.656117e-09  1.058029e-09 -1.058029e-09   
      7      385.434    17.511    -17.591  7.967462e-09  1.745883e-09 -1.745883e-09   
      8      436.679    21.427    -33.733  5.694954e-09  1.251389e-09 -1.251389e-09   
      9      493.437    32.366    -35.331  5.169388e-09  1.140665e-09 -1.140665e-09   
      10     566.799    26.702    -40.995  6.198870e-09  1.328615e-09 -1.328615e-09   
      11     632.505    41.230    -39.004  5.460725e-09  1.206638e-09 -1.206638e-09   
      12     719.643    61.906    -45.908  4.401926e-09  9.944029e-10 -9.944029e-10   
      13     831.681    35.117    -50.132  6.330448e-09  1.430059e-09 -1.430059e-09   
      14     933.210    46.417    -66.412  5.323497e-09  1.199071e-09 -1.199071e-09   
      15    1038.259    51.689    -58.632  6.023929e-09  1.354857e-09 -1.354857e-09   
      16    1156.741    81.139    -66.793  4.907478e-09  1.116793e-09 -1.116793e-09   
      17    1290.877    77.383    -52.997  6.241564e-09  1.403806e-09 -1.403806e-09   
      18    1418.981    59.600    -50.722  7.958164e-09  1.800403e-09 -1.800403e-09   
      19    1622.771   179.246   -144.190  4.687677e-09  8.621085e-10 -8.621085e-10   
      20    5128.211    61.811    -56.033  7.876320e-09  1.727452e-09 -1.727452e-09   
      21    5250.377    85.070    -60.355  6.073990e-09  1.375638e-09 -1.375638e-09   
      22    5418.039    82.890    -82.593  5.495312e-09  1.239271e-09 -1.239271e-09   
      23    5602.630   103.900   -101.700  4.567630e-09  1.028969e-09 -1.028969e-09   
      24    5791.243    90.798    -84.714  5.526170e-09  1.251567e-09 -1.251567e-09   
      25    5990.211    87.401   -108.170  3.831486e-09  9.991447e-10 -9.991447e-10   
      26    6159.463    91.154    -81.851  5.969859e-09  1.341996e-09 -1.341996e-09   
      27    6339.775   123.963    -89.158  4.923989e-09  1.116380e-09 -1.116380e-09   
      28    6540.716   106.055    -76.978  5.903845e-09  1.338537e-09 -1.338537e-09   
      29    6733.254    81.508    -86.482  6.652287e-09  1.500186e-09 -1.500186e-09   
      30    6919.921    97.933   -105.160  4.167779e-09  1.105727e-09 -1.105727e-09   
      31    7101.220   127.248    -83.366  5.557430e-09  1.259996e-09 -1.259996e-09   
      32    7385.907   150.947   -157.440  5.865019e-09  1.084561e-09 -1.084561e-09   
      33   11729.988   148.045   -177.904  5.193678e-09  1.305768e-09 -1.305768e-09   
      34   25208.251  4424.959  -2076.327  3.432452e-09  8.046835e-10 -8.046835e-10   
      35   40295.514   963.536   -844.227  4.427515e-09  8.751870e-10 -8.751870e-10   
      36   48622.227  4535.501  -3132.456  4.123184e-09  7.143516e-10 -7.143516e-10   
      37  114520.802  7400.553 -11229.443  1.234842e-09  3.339580e-10 -3.339580e-10   
      
          FluxPosWithECFErr  FluxNegWithECFErr     Gamma  GammaPos  GammaNeg  \
      0        3.920239e-09      -2.291701e-09 -0.709013  0.796733 -0.612578   
      1        3.630074e-09      -2.131023e-09 -0.482790  0.747759 -0.576065   
      2        3.762225e-09      -2.221593e-09 -0.294056  0.707369 -0.545949   
      3        2.464476e-09      -1.469197e-09 -0.033366  0.652436 -0.504982   
      4        3.119503e-09      -1.874641e-09  0.164947  0.611460 -0.474412   
      5        3.923483e-09      -2.374246e-09  0.338307  0.576347 -0.448201   
      6        3.653811e-09      -2.235014e-09  0.468223  0.550545 -0.428928   
      7        6.023257e-09      -3.689310e-09  0.597275  0.525420 -0.410144   
      8        4.169649e-09      -2.570751e-09  0.716475  0.502726 -0.393160   
      9        3.667165e-09      -2.276800e-09  0.833163  0.481057 -0.376921   
      10       4.226555e-09      -2.631900e-09  0.965523  0.457228 -0.359031   
      11       3.627014e-09      -2.283849e-09  1.070261  0.439021 -0.345327   
      12       2.831707e-09      -1.803895e-09  1.193509  0.418441 -0.329790   
      13       3.917570e-09      -2.518498e-09  1.331679  0.396619 -0.313237   
      14       3.193360e-09      -2.067118e-09  1.441667  0.380341 -0.300812   
      15       3.511977e-09      -2.288671e-09  1.543528  0.366250 -0.289980   
      16       2.786391e-09      -1.833336e-09  1.646717  0.353063 -0.279748   
      17       3.438791e-09      -2.273424e-09  1.751486  0.340921 -0.270210   
      18       4.285955e-09      -2.854693e-09  1.841837  0.331566 -0.262744   
      19       2.364664e-09      -1.521174e-09  1.969983  0.320254 -0.253487   
      20       3.499188e-09      -2.390397e-09  3.068727  0.337518 -0.254801   
      21       2.721063e-09      -1.873963e-09  3.091208  0.339920 -0.256351   
      22       2.460798e-09      -1.690451e-09  3.121225  0.343227 -0.258500   
      23       2.046931e-09      -1.403578e-09  3.153217  0.346875 -0.260889   
      24       2.483132e-09      -1.702507e-09  3.184835  0.350602 -0.263346   
      25       1.794225e-09      -1.279976e-09  3.217092  0.354525 -0.265949   
      26       2.686277e-09      -1.831711e-09  3.243698  0.357850 -0.268168   
      27       2.224633e-09      -1.518077e-09  3.271251  0.361374 -0.270531   
      28       2.673480e-09      -1.820848e-09  3.301048  0.365277 -0.273161   
      29       3.015562e-09      -2.046799e-09  3.328751  0.368988 -0.275672   
      30       1.981473e-09      -1.409132e-09  3.354864  0.372557 -0.278097   
      31       2.535074e-09      -1.717058e-09  3.379561  0.375993 -0.280440   
      32       2.573880e-09      -1.643171e-09  3.417095  0.381326 -0.284091   
      33       2.623494e-09      -1.754426e-09  3.858814  0.452379 -0.333919   
      34       2.048974e-09      -1.247415e-09  4.589345  0.591602 -0.434608   
      35       2.939543e-09      -1.666574e-09  5.037265  0.684334 -0.502629   
      36       2.853683e-09      -1.569253e-09  5.216637  0.722441 -0.530699   
      37       8.182046e-10      -5.039718e-10  4.889789  0.653380 -0.479872   
      
                   ECF        ECFPos        ECFNeg  
      0   9.464198e-10  9.614977e-10 -5.347212e-10  
      1   1.176206e-09  1.133464e-09 -6.316440e-10  
      2   1.410067e-09  1.297913e-09 -7.245971e-10  
      3   1.811430e-09  1.560570e-09 -8.735616e-10  
      4   2.191669e-09  1.791315e-09 -1.004889e-09  
      5   2.588902e-09  2.017421e-09 -1.133953e-09  
      6   2.933105e-09  2.203095e-09 -1.240189e-09  
      7   3.320314e-09  2.402339e-09 -1.354412e-09  
      8   3.723229e-09  2.600356e-09 -1.468131e-09  
      9   4.164968e-09  2.808063e-09 -1.587594e-09  
      10  4.729810e-09  3.061432e-09 -1.733511e-09  
      11  5.230575e-09  3.276259e-09 -1.857345e-09  
      12  5.888152e-09  3.546545e-09 -2.013212e-09  
      13  6.724119e-09  3.874040e-09 -2.202025e-09  
      14  7.473635e-09  4.155099e-09 -2.363889e-09  
      15  8.242083e-09  4.433202e-09 -2.523761e-09  
      16  9.101152e-09  4.734275e-09 -2.696371e-09  
      17  1.006502e-08  5.062222e-09 -2.883673e-09  
      18  1.097784e-08  5.365304e-09 -3.055966e-09  
      19  1.241625e-08  5.832197e-09 -3.319594e-09  
      20  3.568459e-08  1.378695e-08 -7.485680e-09  
      21  3.646380e-08  1.409401e-08 -7.639397e-09  
      22  3.753077e-08  1.451949e-08 -7.852052e-09  
      23  3.870234e-08  1.499333e-08 -8.088465e-09  
      24  3.989614e-08  1.548328e-08 -8.332523e-09  
      25  4.115202e-08  1.600640e-08 -8.592720e-09  
      26  4.221762e-08  1.645638e-08 -8.816272e-09  
      27  4.335020e-08  1.694075e-08 -9.056671e-09  
      28  4.460924e-08  1.748649e-08 -9.327281e-09  
      29  4.581263e-08  1.801521e-08 -9.589237e-09  
      30  4.697662e-08  1.853312e-08 -9.845674e-09  
      31  4.810466e-08  1.904107e-08 -1.009704e-08  
      32  4.987121e-08  1.984825e-08 -1.049629e-08  
      33  7.623825e-08  3.340150e-08 -1.720005e-08  
      34  1.538200e-07  8.444425e-08 -4.271473e-08  
      35  2.365503e-07  1.499297e-07 -7.577487e-08  
      36  2.810430e-07  1.883188e-07 -9.523759e-08  
      37  2.052976e-07  1.241831e-07 -6.275065e-08  ,
      'Density_PC_incbad':           Time   TimePos    TimeNeg          Flux       FluxPos       FluxNeg  \
      0       98.141    11.448     -8.610  5.659597e-04  1.276641e-04 -1.276641e-04   
      1      124.376    12.795    -14.786  3.277544e-04  7.201962e-05 -7.201962e-05   
      2      151.556    15.702    -14.386  2.297554e-04  5.041549e-05 -5.041549e-05   
      3      199.129    23.289    -31.871  8.787795e-05  1.933691e-05 -1.933691e-05   
      4      245.091    27.474    -22.672  7.400815e-05  1.630769e-05 -1.630769e-05   
      5      293.881    23.816    -21.315  6.529621e-05  1.432802e-05 -1.432802e-05   
      6      336.711    31.132    -19.014  4.651303e-05  1.056935e-05 -1.056935e-05   
      7      385.434    17.511    -17.591  5.913151e-05  1.295729e-05 -1.295729e-05   
      8      436.679    21.427    -33.733  3.212099e-05  7.058155e-06 -7.058155e-06   
      9      493.437    32.366    -35.331  2.228694e-05  4.917785e-06 -4.917785e-06   
      10     566.799    26.702    -40.995  1.970442e-05  4.223285e-06 -4.223285e-06   
      11     632.505    41.230    -39.004  1.363840e-05  3.013630e-06 -3.013630e-06   
      12     719.643    61.906    -45.908  8.277664e-06  1.869939e-06 -1.869939e-06   
      13     831.681    35.117    -50.132  8.660232e-06  1.956362e-06 -1.956362e-06   
      14     933.210    46.417    -66.412  5.653324e-06  1.273362e-06 -1.273362e-06   
      15    1038.259    51.689    -58.632  5.059712e-06  1.137993e-06 -1.137993e-06   
      16    1156.741    81.139    -66.793  3.250238e-06  7.396556e-07 -7.396556e-07   
      17    1290.877    77.383    -52.997  3.247742e-06  7.304581e-07 -7.304581e-07   
      18    1418.981    59.600    -50.722  3.363178e-06  7.608633e-07 -7.608633e-07   
      19    1622.771   179.246   -144.190  1.474854e-06  2.712396e-07 -2.712396e-07   
      20    5128.211    61.811    -56.033  1.974105e-07  4.329651e-08 -4.329651e-08   
      21    5250.377    85.070    -60.355  1.445571e-07  3.273932e-08 -3.273932e-08   
      22    5418.039    82.890    -82.593  1.220509e-07  2.752421e-08 -2.752421e-08   
      23    5602.630   103.900   -101.700  9.424274e-08  2.123045e-08 -2.123045e-08   
      24    5791.243    90.798    -84.714  1.060140e-07  2.401006e-08 -2.401006e-08   
      25    5990.211    87.401   -108.170  6.824165e-08  1.779552e-08 -1.779552e-08   
      26    6159.463    91.154    -81.851  1.000091e-07  2.248157e-08 -2.248157e-08   
      27    6339.775   123.963    -89.158  7.741763e-08  1.755234e-08 -1.755234e-08   
      28    6540.716   106.055    -76.978  8.666849e-08  1.964973e-08 -1.964973e-08   
      29    6733.254    81.508    -86.482  9.162066e-08  2.066177e-08 -2.066177e-08   
      30    6919.921    97.933   -105.160  5.405230e-08  1.434027e-08 -1.434027e-08   
      31    7101.220   127.248    -83.366  6.809063e-08  1.543770e-08 -1.543770e-08   
      32    7385.907   150.947   -157.440  6.590947e-08  1.218800e-08 -1.218800e-08   
      33   11729.988   148.045   -177.904  2.110738e-08  5.306712e-09 -5.306712e-09   
      34   25208.251  4424.959  -2076.327  2.594379e-09  6.082105e-10 -6.082105e-10   
      35   40295.514   963.536   -844.227  1.193078e-09  2.358357e-10 -2.358357e-10   
      36   48622.227  4535.501  -3132.456  7.351397e-10  1.273647e-10 -1.273647e-10   
      37  114520.802  7400.553 -11229.443  4.673005e-10  1.263795e-10 -1.263795e-10   
      
          FluxPosWithECFErr  FluxNegWithECFErr     Gamma  GammaPos  GammaNeg  \
      0        6.047195e-04      -4.465586e-04 -0.709013  0.796733 -0.612578   
      1        3.246673e-04      -2.430883e-04 -0.482790  0.747759 -0.576065   
      2        2.130558e-04      -1.617686e-04 -0.294056  0.707369 -0.545949   
      3        7.396474e-05      -5.744147e-05 -0.033366  0.652436 -0.504982   
      4        5.757704e-05      -4.561260e-05  0.164947  0.611460 -0.474412   
      5        4.722850e-05      -3.814375e-05  0.338307  0.576347 -0.448201   
      6        3.191084e-05      -2.623635e-05  0.468223  0.550545 -0.428928   
      7        3.813577e-05      -3.183823e-05  0.597275  0.525420 -0.410144   
      8        1.961571e-05      -1.665841e-05  0.716475  0.502726 -0.393160   
      9        1.289284e-05      -1.114431e-05  0.833163  0.481057 -0.376921   
      10       1.065543e-05      -9.389811e-06  0.965523  0.457228 -0.359031   
      11       7.052379e-06      -6.328031e-06  1.070261  0.439021 -0.345327   
      12       4.059342e-06      -3.717332e-06  1.193509  0.418441 -0.329790   
      13       3.993886e-06      -3.733246e-06  1.331679  0.396619 -0.313237   
      14       2.489355e-06      -2.360530e-06  1.441667  0.380341 -0.300812   
      15       2.143696e-06      -2.055056e-06  1.543528  0.366250 -0.289980   
      16       1.336571e-06      -1.291628e-06  1.646717  0.353063 -0.279748   
      17       1.295156e-06      -1.255691e-06  1.751486  0.340921 -0.270210   
      18       1.321223e-06      -1.279625e-06  1.841837  0.331566 -0.262744   
      19       5.382698e-07      -5.137254e-07  1.969983  0.320254 -0.253487   
      20       1.072472e-07      -7.745461e-08  3.068727  0.337518 -0.254801   
      21       7.979772e-08      -5.761001e-08  3.091208  0.339920 -0.256351   
      22       6.828557e-08      -4.893154e-08  3.121225  0.343227 -0.258500   
      23       5.351901e-08      -3.807466e-08  3.153217  0.346875 -0.260889   
      24       6.115574e-08      -4.325063e-08  3.184835  0.350602 -0.263346   
      25       4.092729e-08      -2.942990e-08  3.217092  0.354525 -0.265949   
      26       5.923782e-08      -4.134833e-08  3.243698  0.357850 -0.268168   
      27       4.650555e-08      -3.232989e-08  3.271251  0.361374 -0.270531   
      28       5.278666e-08      -3.649125e-08  3.301048  0.365277 -0.273161   
      29       5.648038e-08      -3.881702e-08  3.328751  0.368988 -0.275672   
      30       3.455951e-08      -2.427585e-08  3.354864  0.372557 -0.278097   
      31       4.299557e-08      -2.931256e-08  3.379561  0.375993 -0.280440   
      32       4.144298e-08      -2.734975e-08  3.417095  0.381326 -0.284091   
      33       1.656238e-08      -1.076719e-08  3.858814  0.452379 -0.333919   
      34       2.643509e-09      -1.629126e-09  4.589345  0.591602 -0.434608   
      35       1.389799e-09      -8.379556e-10  5.037265  0.684334 -0.502629   
      36       8.994349e-10      -5.382675e-10  5.216637  0.722441 -0.530699   
      37       5.276442e-10      -3.261832e-10  4.889789  0.653380 -0.479872   
      
                   ECF        ECFPos        ECFNeg  
      0   1.421906e-04  1.485043e-04 -1.075101e-04  
      1   1.049657e-04  1.013866e-04 -7.435566e-05  
      2   8.148340e-05  7.341489e-05 -5.451438e-05  
      3   5.743304e-05  4.665880e-05 -3.535004e-05  
      4   4.401511e-05  3.284077e-05 -2.533430e-05  
      5   3.488048e-05  2.403989e-05 -1.888379e-05  
      6   2.930073e-05  1.896747e-05 -1.512705e-05  
      7   2.464212e-05  1.494703e-05 -1.211960e-05  
      8   2.099996e-05  1.196534e-05 -9.864994e-06  
      9   1.795655e-05  9.602384e-06 -8.057433e-06  
      10  1.503470e-05  7.464342e-06 -6.398953e-06  
      11  1.306359e-05  6.107327e-06 -5.329834e-06  
      12  1.107246e-05  4.819479e-06 -4.297499e-06  
      13  9.198785e-06  3.698451e-06 -3.377316e-06  
      14  7.936678e-06  3.002971e-06 -2.790418e-06  
      15  6.922819e-06  2.485655e-06 -2.341313e-06  
      16  6.027721e-06  2.064580e-06 -1.963730e-06  
      17  5.237246e-06  1.724678e-06 -1.647037e-06  
      18  4.639317e-06  1.490002e-06 -1.419237e-06  
      19  3.906445e-06  1.231470e-06 -1.155583e-06  
      20  8.943915e-07  4.445406e-07 -2.909711e-07  
      21  8.678154e-07  4.368720e-07 -2.845733e-07  
      22  8.335586e-07  4.268000e-07 -2.763004e-07  
      23  7.985353e-07  4.162695e-07 -2.678043e-07  
      24  7.653672e-07  4.060630e-07 -2.597146e-07  
      25  7.329485e-07  3.958510e-07 -2.517581e-07  
      26  7.072441e-07  3.875768e-07 -2.454090e-07  
      27  6.815754e-07  3.791479e-07 -2.390277e-07  
      28  6.548639e-07  3.701897e-07 -2.323381e-07  
      29  6.309685e-07  3.620049e-07 -2.263062e-07  
      30  6.092440e-07  3.544157e-07 -2.207792e-07  
      31  5.893869e-07  3.473490e-07 -2.156877e-07  
      32  5.604390e-07  3.368125e-07 -2.081906e-07  
      33  3.098363e-07  2.303026e-07 -1.375225e-07  
      34  1.162630e-07  1.152866e-07 -6.772812e-08  
      35  6.374296e-08  7.317641e-08 -4.296007e-08  
      36  5.010832e-08  6.068917e-08 -3.564730e-08  
      37  7.769062e-08  8.516960e-08 -4.999349e-08  ,
      'XRTBand_PC_incbad':           Time   TimePos    TimeNeg          Flux       FluxPos       FluxNeg  \
      0       98.141    11.448     -8.610  5.148962e-11  1.161457e-11 -1.161457e-11   
      1      124.376    12.795    -14.786  5.403937e-11  1.187442e-11 -1.187442e-11   
      2      151.556    15.702    -14.386  6.221045e-11  1.365091e-11 -1.365091e-11   
      3      199.129    23.289    -31.871  4.721147e-11  1.038855e-11 -1.038855e-11   
      4      245.091    27.474    -22.672  6.696020e-11  1.475467e-11 -1.475467e-11   
      5      293.881    23.816    -21.315  9.317755e-11  2.044606e-11 -2.044606e-11   
      6      336.711    31.132    -19.014  9.338859e-11  2.122108e-11 -2.122108e-11   
      7      385.434    17.511    -17.591  1.666661e-10  3.652099e-11 -3.652099e-11   
      8      436.679    21.427    -33.733  1.238458e-10  2.721346e-11 -2.721346e-11   
      9      493.437    32.366    -35.331  1.167720e-10  2.576663e-11 -2.576663e-11   
      10     566.799    26.702    -40.995  1.461967e-10  3.133461e-11 -3.133461e-11   
      11     632.505    41.230    -39.004  1.332579e-10  2.944555e-11 -2.944555e-11   
      12     719.643    61.906    -45.908  1.118206e-10  2.526048e-11 -2.526048e-11   
      13     831.681    35.117    -50.132  1.682136e-10  3.799975e-11 -3.799975e-11   
      14     933.210    46.417    -66.412  1.466170e-10  3.302420e-11 -3.302420e-11   
      15    1038.259    51.689    -58.632  1.715054e-10  3.857372e-11 -3.857372e-11   
      16    1156.741    81.139    -66.793  1.444957e-10  3.288284e-11 -3.288284e-11   
      17    1290.877    77.383    -52.997  1.901569e-10  4.276866e-11 -4.276866e-11   
      18    1418.981    59.600    -50.722  2.496973e-10  5.648987e-11 -5.648987e-11   
      19    1622.771   179.246   -144.190  1.533515e-10  2.820280e-11 -2.820280e-11   
      20    5128.211    61.811    -56.033  3.685511e-10  8.083143e-11 -8.083143e-11   
      21    5250.377    85.070    -60.355  2.863050e-10  6.484240e-11 -6.484240e-11   
      22    5418.039    82.890    -82.593  2.615736e-10  5.898856e-11 -5.898856e-11   
      23    5602.630   103.900   -101.700  2.196941e-10  4.949141e-11 -4.949141e-11   
      24    5791.243    90.798    -84.714  2.685498e-10  6.082119e-11 -6.082119e-11   
      25    5990.211    87.401   -108.170  1.881618e-10  4.906734e-11 -4.906734e-11   
      26    6159.463    91.154    -81.851  2.957279e-10  6.647822e-11 -6.647822e-11   
      27    6339.775   123.963    -89.158  2.461180e-10  5.580056e-11 -5.580056e-11   
      28    6540.716   106.055    -76.978  2.979729e-10  6.755726e-11 -6.755726e-11   
      29    6733.254    81.508    -86.482  3.387912e-10  7.640226e-11 -7.640226e-11   
      30    6919.921    97.933   -105.160  2.140721e-10  5.679410e-11 -5.679410e-11   
      31    7101.220   127.248    -83.366  2.877553e-10  6.524069e-11 -6.524069e-11   
      32    7385.907   150.947   -157.440  3.074178e-10  5.684779e-11 -5.684779e-11   
      33   11729.988   148.045   -177.904  3.143594e-10  7.903466e-11 -7.903466e-11   
      34   25208.251  4424.959  -2076.327  2.635769e-10  6.179137e-11 -6.179137e-11   
      35   40295.514   963.536   -844.227  3.933978e-10  7.776296e-11 -7.776296e-11   
      36   48622.227  4535.501  -3132.456  3.884017e-10  6.729154e-11 -6.729154e-11   
      37  114520.802  7400.553 -11229.443  1.045730e-10  2.828133e-11 -2.828133e-11   
      
          FluxPosWithECFErr  FluxNegWithECFErr     Gamma  GammaPos  GammaNeg  \
      0        4.717530e-11      -2.588227e-11 -0.709013  0.796733 -0.612578   
      1        4.565264e-11      -2.518572e-11 -0.482790  0.747759 -0.576065   
      2        4.895917e-11      -2.725880e-11 -0.294056  0.707369 -0.545949   
      3        3.345988e-11      -1.894941e-11 -0.033366  0.652436 -0.504982   
      4        4.355451e-11      -2.507566e-11  0.164947  0.611460 -0.474412   
      5        5.593459e-11      -3.273177e-11  0.338307  0.576347 -0.448201   
      6        5.294710e-11      -3.177164e-11  0.468223  0.550545 -0.428928   
      7        8.808691e-11      -5.324168e-11  0.597275  0.525420 -0.410144   
      8        6.158603e-11      -3.794869e-11  0.716475  0.502726 -0.393160   
      9        5.465364e-11      -3.441726e-11  0.833163  0.481057 -0.376921   
      10       6.329193e-11      -4.048259e-11  0.965523  0.457228 -0.359031   
      11       5.496982e-11      -3.635134e-11  1.070261  0.439021 -0.345327   
      12       4.355590e-11      -2.987838e-11  1.193509  0.418441 -0.329790   
      13       6.123471e-11      -4.341554e-11  1.331679  0.396619 -0.313237   
      14       5.077020e-11      -3.689487e-11  1.441667  0.380341 -0.300812   
      15       5.706578e-11      -4.237461e-11  1.543528  0.366250 -0.289980   
      16       4.683450e-11      -3.560606e-11  1.646717  0.353063 -0.279748   
      17       5.991201e-11      -4.603864e-11  1.751486  0.340921 -0.270210   
      18       7.809954e-11      -6.063053e-11  1.841837  0.331566 -0.262744   
      19       4.354760e-11      -3.145606e-11  1.969983  0.320254 -0.253487   
      20       1.818247e-10      -1.168751e-10  3.068727  0.337518 -0.254801   
      21       1.438301e-10      -9.295510e-11  3.091208  0.339920 -0.256351   
      22       1.333344e-10      -8.565559e-11  3.121225  0.343227 -0.258500   
      23       1.138093e-10      -7.272769e-11  3.153217  0.346875 -0.260889   
      24       1.415078e-10      -9.012564e-11  3.184835  0.350602 -0.263346   
      25       1.036636e-10      -6.834811e-11  3.217092  0.354525 -0.265949   
      26       1.602875e-10      -1.010127e-10  3.243698  0.357850 -0.268168   
      27       1.354330e-10      -8.520881e-11  3.271251  0.361374 -0.270531   
      28       1.663891e-10      -1.042572e-10  3.301048  0.365277 -0.273161   
      29       1.915950e-10      -1.194460e-10  3.328751  0.368988 -0.275672   
      30       1.262048e-10      -8.184200e-11  3.354864  0.372557 -0.278097   
      31       1.669186e-10      -1.035196e-10  3.379561  0.375993 -0.280440   
      32       1.770106e-10      -1.045611e-10  3.417095  0.381326 -0.284091   
      33       2.284299e-10      -1.377086e-10  3.858814  0.452379 -0.333919   
      34       2.486759e-10      -1.412540e-10  4.589345  0.591602 -0.434608   
      35       4.235001e-10      -2.329121e-10  5.037265  0.684334 -0.502629   
      36       4.387557e-10      -2.383341e-10  5.216637  0.722441 -0.530699   
      37       1.093979e-10      -6.249882e-11  4.889789  0.653380 -0.479872   
      
                   ECF        ECFPos        ECFNeg  
      0   1.293615e-11  1.148741e-11 -5.811118e-12  
      1   1.730650e-11  1.411736e-11 -7.113163e-12  
      2   2.206311e-11  1.667492e-11 -8.367814e-12  
      3   3.085528e-11  2.078717e-11 -1.035751e-11  
      4   3.982346e-11  2.437170e-11 -1.205840e-11  
      5   4.977436e-11  2.781186e-11 -1.365400e-11  
      6   5.882983e-11  3.055768e-11 -1.489531e-11  
      7   6.945549e-11  3.340514e-11 -1.614485e-11  
      8   8.096754e-11  3.611942e-11 -1.729151e-11  
      9   9.408300e-11  3.883351e-11 -1.838385e-11  
      10  1.115498e-10  4.195878e-11 -1.955725e-11  
      11  1.276416e-10  4.446175e-11 -2.041778e-11  
      12  1.495747e-10  4.746280e-11 -2.134458e-11  
      13  1.786743e-10  5.100387e-11 -2.230410e-11  
      14  2.058349e-10  5.413681e-11 -2.309541e-11  
      15  2.346577e-10  5.753982e-11 -2.399960e-11  
      16  2.679741e-10  6.184823e-11 -2.532732e-11  
      17  3.066432e-10  6.765712e-11 -2.748009e-11  
      18  3.444435e-10  7.439327e-11 -3.037771e-11  
      19  4.061821e-10  8.788717e-11 -3.690027e-11  
      20  1.669764e-09  7.378997e-10 -3.824570e-10  
      21  1.718766e-09  7.707265e-10 -3.998427e-10  
      22  1.786442e-09  8.166556e-10 -4.241631e-10  
      23  1.861507e-09  8.683731e-10 -4.515430e-10  
      24  1.938794e-09  9.224365e-10 -4.801594e-10  
      25  2.020949e-09  9.807744e-10 -5.110328e-10  
      26  2.091328e-09  1.031433e-09 -5.378383e-10  
      27  2.166793e-09  1.086428e-09 -5.669341e-10  
      28  2.251472e-09  1.148937e-09 -6.000013e-10  
      29  2.333170e-09  1.210018e-09 -6.323089e-10  
      30  2.412888e-09  1.270324e-09 -6.642031e-10  
      31  2.490786e-09  1.329902e-09 -6.957094e-10  
      32  2.614023e-09  1.425417e-09 -7.462146e-10  
      33  4.614497e-09  3.146037e-09 -1.655363e-09  
      34  1.181179e-08  1.079451e-08 -5.692280e-09  
      35  2.101820e-08  2.224177e-08 -1.172982e-08  
      36  2.647410e-08  2.955249e-08 -1.558429e-08  
      37  1.738568e-08  1.756958e-08 -9.265992e-09  ,
      'BATBand_PC_incbad':           Time   TimePos    TimeNeg          Flux       FluxPos       FluxNeg  \
      0       98.141    11.448     -8.610  1.462713e-07  3.299457e-08 -3.299457e-08   
      1      124.376    12.795    -14.786  7.000804e-08  1.538333e-08 -1.538333e-08   
      2      151.556    15.702    -14.386  4.186082e-08  9.185567e-09 -9.185567e-09   
      3      199.129    23.289    -31.871  1.285395e-08  2.828420e-09 -2.828420e-09   
      4      245.091    27.474    -22.672  9.159551e-09  2.018306e-09 -2.018306e-09   
      5      293.881    23.816    -21.315  6.983140e-09  1.532318e-09 -1.532318e-09   
      6      336.711    31.132    -19.014  4.458632e-09  1.013153e-09 -1.013153e-09   
      7      385.434    17.511    -17.591  5.084243e-09  1.114093e-09 -1.114093e-09   
      8      436.679    21.427    -33.733  2.497936e-09  5.488877e-10 -5.488877e-10   
      9      493.437    32.366    -35.331  1.570895e-09  3.466301e-10 -3.466301e-10   
      10     566.799    26.702    -40.995  1.242311e-09  2.662669e-10 -2.662669e-10   
      11     632.505    41.230    -39.004  7.872392e-10  1.739535e-10 -1.739535e-10   
      12     719.643    61.906    -45.908  4.306805e-10  9.729149e-11 -9.729149e-11   
      13     831.681    35.117    -50.132  4.010708e-10  9.060259e-11 -9.060259e-11   
      14     933.210    46.417    -66.412  2.386443e-10  5.375256e-11 -5.375256e-11   
      15    1038.259    51.689    -58.632  1.960209e-10  4.408758e-11 -4.408758e-11   
      16    1156.741    81.139    -66.793  1.154344e-10  2.626937e-11 -2.626937e-11   
      17    1290.877    77.383    -52.997  1.056008e-10  2.375095e-11 -2.375095e-11   
      18    1418.981    59.600    -50.722  1.013389e-10  2.292625e-11 -2.292625e-11   
      19    1622.771   179.246   -144.190  3.989213e-11  7.336544e-12 -7.336544e-12   
      20    5128.211    61.811    -56.033  2.115836e-12  4.640498e-13 -4.640498e-13   
      21    5250.377    85.070    -60.355  1.520286e-12  3.443146e-13 -3.443146e-13   
      22    5418.039    82.890    -82.593  1.251537e-12  2.822394e-13 -2.822394e-13   
      23    5602.630   103.900   -101.700  9.406866e-13  2.119124e-13 -2.119124e-13   
      24    5791.243    90.798    -84.714  1.030366e-12  2.333573e-13 -2.333573e-13   
      25    5990.211    87.401   -108.170  6.454685e-13  1.683202e-13 -1.683202e-13   
      26    6159.463    91.154    -81.851  9.249747e-13  2.079299e-13 -2.079299e-13   
      27    6339.775   123.963    -89.158  6.995982e-13  1.586148e-13 -1.586148e-13   
      28    6540.716   106.055    -76.978  7.637788e-13  1.731661e-13 -1.731661e-13   
      29    6733.254    81.508    -86.482  7.887929e-13  1.778841e-13 -1.778841e-13   
      30    6919.921    97.933   -105.160  4.552282e-13  1.207737e-13 -1.207737e-13   
      31    7101.220   127.248    -83.366  5.616504e-13  1.273390e-13 -1.273390e-13   
      32    7385.907   150.947   -157.440  5.267356e-13  9.740412e-14 -9.740412e-14   
      33   11729.988   148.045   -177.904  1.162668e-13  2.923122e-14 -2.923122e-14   
      34   25208.251  4424.959  -2076.327  7.722469e-15  1.810409e-15 -1.810409e-15   
      35   40295.514   963.536   -844.227  2.435001e-15  4.813267e-16 -4.813267e-16   
      36   48622.227  4535.501  -3132.456  1.289938e-15  2.234849e-16 -2.234849e-16   
      37  114520.802  7400.553 -11229.443  1.079910e-15  2.920572e-16 -2.920572e-16   
      
          FluxPosWithECFErr  FluxNegWithECFErr     Gamma  GammaPos  GammaNeg  \
      0        3.014120e-07      -1.638978e-07 -0.709013  0.796733 -0.612578   
      1        1.343579e-07      -7.415372e-08 -0.482790  0.747759 -0.576065   
      2        7.547468e-08      -4.226460e-08 -0.294056  0.707369 -0.545949   
      3        2.114665e-08      -1.211584e-08 -0.033366  0.652436 -0.504982   
      4        1.399133e-08      -8.175922e-09  0.164947  0.611460 -0.474412   
      5        9.962811e-09      -5.932475e-09  0.338307  0.576347 -0.448201   
      6        6.037698e-09      -3.656987e-09  0.468223  0.550545 -0.428928   
      7        6.513610e-09      -4.003078e-09  0.597275  0.525420 -0.410144   
      8        3.039349e-09      -1.898006e-09  0.716475  0.502726 -0.393160   
      9        1.815402e-09      -1.152459e-09  0.833163  0.481057 -0.376921   
      10       1.351041e-09      -8.727296e-10  0.965523  0.457228 -0.359031   
      11       8.173647e-10      -5.370455e-10  1.070261  0.439021 -0.345327   
      12       4.233434e-10      -2.835786e-10  1.193509  0.418441 -0.329790   
      13       3.707805e-10      -2.532000e-10  1.331679  0.396619 -0.313237   
      14       2.104693e-10      -1.457079e-10  1.441667  0.380341 -0.300812   
      15       1.659209e-10      -1.161248e-10  1.543528  0.366250 -0.289980   
      16       9.414673e-11      -6.651582e-11  1.646717  0.353063 -0.279748   
      17       8.318185e-11      -5.901474e-11  1.751486  0.340921 -0.270210   
      18       7.793673e-11      -5.536492e-11  1.841837  0.331566 -0.262744   
      19       2.944205e-11      -2.046263e-11  1.969983  0.320254 -0.253487   
      20       2.021052e-12      -1.039051e-12  3.068727  0.337518 -0.254801   
      21       1.469384e-12      -7.537637e-13  3.091208  0.339920 -0.256351   
      22       1.225741e-12      -6.226103e-13  3.121225  0.343227 -0.258500   
      23       9.346198e-13      -4.701405e-13  3.153217  0.346875 -0.260889   
      24       1.038736e-12      -5.181493e-13  3.184835  0.350602 -0.263346   
      25       6.655372e-13      -3.368742e-13  3.217092  0.354525 -0.265949   
      26       9.573536e-13      -4.692421e-13  3.243698  0.357850 -0.268168   
      27       7.334912e-13      -3.573314e-13  3.271251  0.361374 -0.270531   
      28       8.116749e-13      -3.923660e-13  3.301048  0.365277 -0.273161   
      29       8.486461e-13      -4.070570e-13  3.328751  0.368988 -0.275672   
      30       4.996615e-13      -2.446151e-13  3.354864  0.372557 -0.278097   
      31       6.184567e-13      -2.932515e-13  3.379561  0.375993 -0.280440   
      32       5.858426e-13      -2.685586e-13  3.417095  0.381326 -0.284091   
      33       1.582266e-13      -6.985792e-14  3.858814  0.452379 -0.333919   
      34       1.380919e-14      -5.711318e-15  4.589345  0.591602 -0.434608   
      35       5.019242e-15      -2.032051e-15  5.037265  0.684334 -0.502629   
      36       2.801800e-15      -1.127080e-15  5.216637  0.722441 -0.530699   
      37       2.135850e-15      -8.853723e-16  4.889789  0.653380 -0.479872   
      
                   ECF        ECFPos        ECFNeg  
      0   3.674891e-08  7.527107e-08 -4.033435e-08  
      1   2.242059e-08  4.274615e-08 -2.323163e-08  
      2   1.484606e-08  2.656833e-08 -1.463097e-08  
      3   8.400760e-09  1.369631e-08 -7.699573e-09  
      4   5.447490e-09  8.234074e-09 -4.712005e-09  
      5   3.730312e-09  5.258693e-09 -3.061522e-09  
      6   2.808700e-09  3.749496e-09 -2.213532e-09  
      7   2.118778e-09  2.674444e-09 -1.602311e-09  
      8   1.633092e-09  1.954384e-09 -1.187851e-09  
      9   1.265668e-09  1.435756e-09 -8.855391e-10  
      10  9.478979e-10  1.010642e-09 -6.341535e-10  
      11  7.540598e-10  7.649797e-10 -4.866783e-10  
      12  5.760915e-10  5.511201e-10 -3.563002e-10  
      13  4.260121e-10  3.818992e-10 -2.511379e-10  
      14  3.350317e-10  2.856780e-10 -1.901304e-10  
      15  2.682005e-10  2.188560e-10 -1.469885e-10  
      16  2.140786e-10  1.676651e-10 -1.133290e-10  
      17  1.702898e-10  1.285532e-10 -8.711863e-11  
      18  1.397914e-10  1.027526e-10 -6.951717e-11  
      19  1.056623e-10  7.552324e-11 -5.059603e-11  
      20  9.586043e-12  8.911975e-12 -4.211976e-12  
      21  9.126686e-12  8.575511e-12 -4.025357e-12  
      22  8.547495e-12  8.146374e-12 -3.790178e-12  
      23  7.970603e-12  7.712952e-12 -3.555962e-12  
      24  7.438717e-12  7.307453e-12 -3.339926e-12  
      25  6.932646e-12  6.915806e-12 -3.134171e-12  
      26  6.541232e-12  6.608597e-12 -2.974809e-12  
      27  6.159178e-12  6.304774e-12 -2.818989e-12  
      28  5.771084e-12  5.991786e-12 -2.660349e-12  
      29  5.432219e-12  5.714580e-12 -2.521459e-12  
      30  5.131050e-12  5.464880e-12 -2.397661e-12  
      31  4.861600e-12  5.238607e-12 -2.286559e-12  
      32  4.478919e-12  4.912179e-12 -2.128105e-12  
      33  1.706686e-12  2.282637e-12 -9.313582e-13  
      34  3.460705e-13  6.134963e-13 -2.427449e-13  
      35  1.300956e-13  2.669289e-13 -1.054775e-13  
      36  8.792428e-14  1.903668e-13 -7.529823e-14  
      37  1.795395e-13  3.517584e-13 -1.389577e-13  ,
      'HRData_PC':        Time   TimePos   TimeNeg         HR    HRPos    HRNeg   ECF_XRTBand  \
      0  1299.585  6237.269 -1210.053  25.816354  5.46367 -5.46367  3.091866e-10   
      
         ECF_XRTBandPos  ECF_XRTBandNeg   ECF_BATBand  ...  ECF_BATBandNeg  \
      0    6.807572e-11   -2.764928e-11  1.679185e-10  ...   -8.572934e-11   
      
            Gamma  GammaPos  GammaNeg  ECF_Density  ECF_DensityPos  ECF_DensityNeg  \
      0  1.757906  0.340221 -0.269655     0.000005        0.000002       -0.000002   
      
         ECF_ObservedDensity  ECF_ObservedDensityPos  ECF_ObservedDensityNeg  
      0         1.012730e-08            5.083110e-09           -2.895573e-09  
      
      [1 rows x 21 columns],
      'Datasets': ['ObservedFlux_PC_incbad',
       'Density_PC_incbad',
       'XRTBand_PC_incbad',
       'BATBand_PC_incbad']},
     'UVOT': {'white':           Time   TimePos   TimeNeg  FluxDensity  FluxDensityPos  \
      0   148.560310  74.88050 -74.88050     0.000425        0.000058   
      1   575.458469   9.88695  -9.88695     0.000476        0.000069   
      2   749.861379   9.88150  -9.88150     0.000428        0.000063   
      3   939.912940  74.88600 -74.88600     0.000452        0.000062   
      4  1178.556729   9.88175  -9.88175     0.000451        0.000066   
      5  1351.442249   9.87040  -9.87040     0.000420        0.000062   
      6  1525.045399   9.88160  -9.88160     0.000413        0.000062   
      7  1702.344269   9.88150  -9.88150     0.000442        0.000066   
      8  5586.023850  99.89200 -99.89200     0.000420        0.000057   
      9  7022.504340  99.88650 -99.88650     0.000408        0.000056   
      
         FluxDensityNeg  
      0       -0.000058  
      1       -0.000069  
      2       -0.000063  
      3       -0.000062  
      4       -0.000066  
      5       -0.000062  
      6       -0.000062  
      7       -0.000066  
      8       -0.000057  
      9       -0.000056  ,
      'b':           Time   TimePos   TimeNeg  FluxDensity  FluxDensityPos  \
      0   551.225769   9.88255  -9.88255     0.000958        0.000085   
      1   724.238489   9.86600  -9.86600     0.000979        0.000085   
      2  1154.245619   9.87615  -9.87615     0.001110        0.000094   
      3  1327.148519   9.88220  -9.88220     0.000988        0.000091   
      4  1500.442269   9.84880  -9.84880     0.000957        0.000094   
      5  1676.510769   9.87605  -9.87605     0.000821        0.000094   
      6  5381.247350  99.88650 -99.88650     0.000954        0.000033   
      7  6817.766470  99.88650 -99.88650     0.000951        0.000034   
      
         FluxDensityNeg  
      0       -0.000085  
      1       -0.000085  
      2       -0.000094  
      3       -0.000091  
      4       -0.000094  
      5       -0.000094  
      6       -0.000033  
      7       -0.000034  ,
      'u':           Time    TimePos    TimeNeg  FluxDensity  FluxDensityPos  \
      0   410.553500  124.88700 -124.88700     0.000348        0.000016   
      1   699.436419    9.87695   -9.87695     0.000270        0.000037   
      2  1129.455369    9.87685   -9.87685     0.000344        0.000043   
      3  1302.258219    9.87110   -9.87110     0.000362        0.000046   
      4  1475.160129    9.87615   -9.87615     0.000324        0.000046   
      5  1651.741649    9.87585   -9.87585     0.000339        0.000050   
      6  5176.106780   99.89200  -99.89200     0.000328        0.000016   
      7  6612.499020   99.88650  -99.88650     0.000327        0.000016   
      
         FluxDensityNeg  
      0       -0.000016  
      1       -0.000037  
      2       -0.000043  
      3       -0.000046  
      4       -0.000046  
      5       -0.000050  
      6       -0.000016  
      7       -0.000016  ,
      'v':           Time   TimePos   TimeNeg  FluxDensity  FluxDensityPos  \
      0   625.349419   9.87600  -9.87600     0.000864        0.000135   
      1   799.570209   9.87595  -9.87595     0.001219        0.000157   
      2  1055.142459   9.88170  -9.88170     0.001050        0.000148   
      3  1228.276539   9.87620  -9.87620     0.000895        0.000145   
      4  1401.796519   9.87045  -9.87045     0.001096        0.000162   
      5  1576.646989   9.88225  -9.88225     0.001163        0.000170   
      6  1753.101609   9.87640  -9.87640     0.001291        0.000188   
      7  5997.888230  99.88650 -99.88650     0.001051        0.000051   
      8  7433.480550  99.88650 -99.88650     0.001076        0.000064   
      
         FluxDensityNeg  
      0       -0.000135  
      1       -0.000157  
      2       -0.000148  
      3       -0.000145  
      4       -0.000162  
      5       -0.000170  
      6       -0.000188  
      7       -0.000051  
      8       -0.000064  ,
      'uvw1':            Time    TimePos    TimeNeg  FluxDensity  FluxDensityPos  \
      0    675.141669    9.87670   -9.87670     0.000138        0.000032   
      1    849.025569    9.88180   -9.88180     0.000126        0.000030   
      2   1105.149299    9.87630   -9.87630     0.000124        0.000030   
      3   1277.704769    9.87695   -9.87695     0.000179        0.000037   
      4   1450.843389    9.87600   -9.87600     0.000142        0.000033   
      5   1625.963399    9.88150   -9.88150     0.000179        0.000038   
      6   1798.352829    5.47945   -5.47945     0.000114        0.000043   
      7   6407.788730   99.88100  -99.88100     0.000143        0.000012   
      8  29415.864430  219.99100 -219.99100     0.000133        0.000009   
      
         FluxDensityNeg  
      0       -0.000032  
      1       -0.000030  
      2       -0.000030  
      3       -0.000037  
      4       -0.000033  
      5       -0.000038  
      6       -0.000043  
      7       -0.000012  
      8       -0.000009  ,
      'uvw2':           Time   TimePos   TimeNeg  FluxDensity  FluxDensityPos  \
      0   600.873559   9.88220  -9.88220     0.000092        0.000025   
      1   775.199179   9.87665  -9.87665     0.000099        0.000026   
      2  1030.705019   9.88220  -9.88220     0.000086        0.000024   
      3  1203.993559   9.87665  -9.87665     0.000073        0.000023   
      4  1376.845889   9.87625  -9.87625     0.000062        0.000021   
      5  1552.087999   9.88255  -9.88255     0.000062        0.000021   
      6  1727.781089   9.88745  -9.88745     0.000065        0.000023   
      7  5793.089660  99.88100 -99.88100     0.000058        0.000007   
      8  7228.830940  99.88650 -99.88650     0.000066        0.000007   
      
         FluxDensityNeg  
      0       -0.000025  
      1       -0.000026  
      2       -0.000024  
      3       -0.000023  
      4       -0.000021  
      5       -0.000021  
      6       -0.000023  
      7       -0.000007  
      8       -0.000007  ,
      'uvm2':            Time    TimePos    TimeNeg  FluxDensity  FluxDensityPos  \
      0    650.323099    9.88220   -9.88220     0.000099        0.000032   
      1   1080.320059    9.88220   -9.88220     0.000127        0.000036   
      2   1601.299979    9.87665   -9.87665     0.000105        0.000032   
      3   6202.576450   99.89200  -99.89200     0.000076        0.000009   
      4  11718.445460  161.48350 -161.48350     0.000087        0.000008   
      5  23510.119850  374.35250 -374.35250     0.000081        0.000005   
      
         FluxDensityNeg  
      0       -0.000032  
      1       -0.000036  
      2       -0.000032  
      3       -0.000009  
      4       -0.000008  
      5       -0.000005  ,
      'Datasets': ['white', 'b', 'u', 'v', 'uvw1', 'uvw2', 'uvm2']}}




```python

```
